<?php

/**
 * The settings page functionalities of the plugin.
 *
 * @link       https://usergrowth.io/
 * @since      1.0.0
 * @package    Evergreen_Content_Poster
 * @subpackage Evergreen_Content_Poster/Content_Library
 * @author     usergrowth <info@usergrowth.io>
 */

class Evergreen_Content_Poster_Content_Library {

    private $buffer;
    private $common;

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     *
     * @since 1.0.0
     * Evergreen_Content_Poster_Content_Library constructor.
     * @param Evergreen_Content_Poster_Buffer $buffer
     */
    public function __construct(Evergreen_Content_Poster_Buffer $buffer, Evergreen_Content_Poster_Common $common)
    {
        $this->buffer = $buffer;
        $this->common = $common;

        $this->buffer_profiles = $this->buffer->profiles();

        add_action('wp_ajax_ajaxChangePostContent', [$this, 'ajaxChangePostContent']);
        add_action('wp_ajax_ajaxChangePostImage', [$this, 'ajaxChangePostImage']);

        add_action( 'admin_enqueue_scripts', [$this, 'load_media_files'] );
        add_action( 'wp_ajax_ajaxDeleteMedia', [$this, 'ajaxDeleteMedia'] );
        add_action('wp_ajax_ajaxPostsSearch', [$this, 'ajaxPostsSearch']);
        add_action('wp_ajax_ajaxAddCategory', [$this, 'ajaxAddCategory']);
        add_action('wp_ajax_ajaxChangeCategoryStatus', [$this, 'ajaxChangeCategoryStatus']);
        add_action('wp_ajax_ajaxChangeCategoryRandom', [$this, 'ajaxChangeCategoryRandom']);
        add_action('wp_ajax_ajaxChangeCategoryName', [$this, 'ajaxChangeCategoryName']);
        add_action('wp_ajax_ajaxMoveToDefault', [$this, 'ajaxMoveToDefault']);
        add_action('wp_ajax_ajaxDeleteCategory', [$this, 'ajaxDeleteCategory']);
        add_action('wp_ajax_ajaxShareNow', [$this, 'ajaxShareNow']);
        add_action('wp_ajax_ajaxAddToQueue', [$this, 'ajaxAddToQueue']);
    }

    public function ajaxShareNow(): void {
        $setting = $this->common->general_settings();

        $post_id = absint($_POST['post_id']);
        $post_meta = get_post_meta($post_id);
        $profile_id = $post_meta['ecp-post-profile'][0];

        $profile_selected = new stdClass();
        $profiles = $this->buffer->profiles();
        foreach ($profiles as $service => $profile) {
            foreach ($profile as $single_profile) {
                if($single_profile->id == $profile_id) {
                    $profile_selected = $single_profile;
                }
            }
        }

        // Post to buffer
        $params = array();
        $params['profile_ids'][] = sanitize_text_field($profile_id);
        $params['text'] = sanitize_text_field($_POST['content']);

        // Get the link
        if(isset($post_meta['ecp-post-ref'][0]) && $post_meta['ecp-post-ref'][0] > 0) {
            if(isset($setting['utm_tags']) && $setting['utm_tags'] == 'Y') {
                $link = trim(get_permalink($post_meta['ecp-post-ref'][0]), '/') . '?utm_source=' . str_replace(' ', '', $profile_selected->formatted_service) . '&utm_medium=social&utm_campaign=Evergreen%20Content%20Poster';
            } else {
                $link = trim(get_permalink($post_meta['ecp-post-ref'][0]), '/');
            }
        } else {
            $link = '';
        }

        $service = $profile_selected->service;

        if(strtolower($service) != 'twitter') {
            if(isset($_POST['image']) && $_POST['image'] != '') {
                $params['media'] = array(
                    'photo' => $_POST['image'],
                );
                $params['text'] = $_POST['content'] . ' ' . $link;
            } else {
                $params['media'] = array(
                    'link' => $link,
                    'picture' => $_POST['image'],
                    'thumbnail' => $_POST['image']
                );
            }
        } else {
            if(isset($_POST['image']) && $_POST['image'] != '') {
                $params['media'] = array(
                    'photo' => $_POST['image'],
                );
                $params['text'] = $_POST['content'] . ' ' . $link;
            } else {

                $params['text'] = $_POST['content'] . ' ' . $link;

            }
        }
        $params['top'] = true;

        // Send request update create
        $resultPost = $this->buffer->updates_create( $params );

        $log = new Evergreen_Content_Poster_Log();

        $today_now = date('Y-m-d H:i:s');
        if ( is_wp_error( $resultPost ) ) {
            // Error
            $errors = true;
            $row = array(
                'action'            => 'share',
                'request_sent'      => $today_now,
                'profile_id'        => $profile_id,
                'profile_name'      => $profile_selected->formatted_service . ': ' . $profile_selected->formatted_username,
                'result'            => 'error',
                'result_message'    => $resultPost->get_error_message(),
                'status_text'       => $params['text'],
                'status_image'      => $params['media']['photo'] ?? null,
                'status_link'       => $params['media']['link'] ?? null,
            );

            $log->add( $post_id, $row );

            wp_send_json_success([
                'message' => $resultPost->get_error_message(),
                'error' => 0
            ]);
        } else {

            // update API statistics
            $token = evergreenGetStatisticsToken();
            // Get data
            $data['statistics'] = array(
                'token' => $token,
                $profile_selected->service . '_' . $profile_selected->service_type . '_name' => $profile_selected->formatted_username,
                $profile_selected->service . '_' . $profile_selected->service_type . '_posts' => 1
            );

            updateApiStatistics($data);

            // Share request
            $resultShare = $this->buffer->updates_share($resultPost['id']);

            $row = array(
                'action'            => 'share',
                'request_sent'      => $today_now,
                'profile_id'        => $profile_id,
                'profile_name'      => $profile_selected->formatted_service . ': ' . $profile_selected->formatted_username,
                'result'            => 'success',
                'status_text'       => $params['text'],
                'status_image'      => $params['media']['photo'] ?? null,
                'status_link'       => $params['media']['link'] ?? null,
            );

            if ( is_wp_error( $resultShare ) ) {
                $row['result'] = 'error';
                $row['result_message'] = $resultShare->get_error_message();
                $log->add( $post_id, $row );
                wp_send_json_success([
                    'message' => __($resultShare->get_error_message(), 'evergreen-content-poster'),
                    'error' => 0
                ]);
            } else {
                $row['result'] = 'success';
                $row['result_message'] = $resultShare['message'];
                $row['status_created_at'] = isset($resultShare['status_created_at']) ? date('Y-m-d H:i:s', $resultShare['status_created_at']) : date('Y-m-d H:i:s');
                $row['status_due_at'] = isset($resultShare['status_due_at']) ? date('Y-m-d H:i:s', $resultShare['status_due_at']) : date('Y-m-d H:i:s');
                $log->add( $post_id, $row );

                wp_send_json_success([
                    'timestamp' => current_time('timestamp'),
                    'message' => __($resultShare['message'], 'evergreen-content-poster'),
                    'error' => 200
                ]);
            }
        }
    }

    public function ajaxAddToQueue(): void {
        $setting = $this->common->general_settings();

        $post_id = absint($_POST['post_id']);
        $post_meta = get_post_meta($post_id);
        $profile_id = $post_meta['ecp-post-profile'][0];

        $profile_selected = new stdClass();
        $profiles = $this->buffer->profiles();
        foreach ($profiles as $service => $profile) {
            foreach ($profile as $single_profile) {
                if($single_profile->id == $profile_id) {
                    $profile_selected = $single_profile;
                }
            }
        }

        // Post to buffer
        $params = array();
        $params['profile_ids'][] = sanitize_text_field($profile_id);
        $params['text'] = sanitize_text_field($_POST['content']);

        // get the link
        if(isset($post_meta['ecp-post-ref'][0]) && $post_meta['ecp-post-ref'][0] > 0) {
            if(isset($setting['utm_tags']) && $setting['utm_tags'] == 'Y') {
                $link = trim(get_permalink($post_meta['ecp-post-ref'][0]), '/') . '?utm_source=' . str_replace(' ', '', $profile_selected->formatted_service) . '&utm_medium=social&utm_campaign=Evergreen%20Content%20Poster';
            } else {
                $link = trim(get_permalink($post_meta['ecp-post-ref'][0]), '/');
            }
        } else {
            $link = '';
        }

        $service = $profile_selected->service;

        if(strtolower($service) != 'twitter') {
            if(isset($_POST['image']) && $_POST['image'] != '') {
                $params['media'] = array(
                    'photo' => $_POST['image'],
                );
                $params['text'] = $_POST['content'] . ' ' . $link;
            } else {
                $params['media'] = array(
                    'link' => $link,
                    'picture' => $_POST['image'],
                    'thumbnail' => $_POST['image']
                );
            }
        } else {
            if(isset($_POST['image']) && $_POST['image'] != '') {
                $params['media'] = array(
                    'photo' => $_POST['image'],
                );
                $params['text'] = $_POST['content'] . ' ' . $link;
            } else {

                $params['text'] = $_POST['content'] . ' ' . $link;

            }
        }
        $params['top'] = true;

        // Send request update create
        $resultPost = $this->buffer->updates_create( $params );

        $log = new Evergreen_Content_Poster_Log();

        $today_now = date('Y-m-d H:i:s');
        if ( is_wp_error( $resultPost ) ) {
            // Error
            $row = array(
                'action'            => 'add_queue',
                'request_sent'      => $today_now,
                'profile_id'        => $profile_id,
                'profile_name'      => $profile_selected->formatted_service . ': ' . $profile_selected->formatted_username,
                'result'            => 'error',
                'result_message'    => $resultPost->get_error_message(),
                'status_text'       => $params['text'],
                'status_image'      => $params['media']['photo'] ?? null,
                'status_link'       => $params['media']['link'] ?? null,
            );

            $log->add( $post_id, $row );

            wp_send_json_success([
                'message' => $resultPost->get_error_message(),
                'error' => 0
            ]);
        } else {
            // update API statistics
            $token = evergreenGetStatisticsToken();
            $data['statistics'] = array(
                'token' => $token,
                $profile_selected->service . '_' . $profile_selected->service_type . '_name' => $profile_selected->formatted_username,
                $profile_selected->service . '_' . $profile_selected->service_type . '_posts' => 1
            );

            updateApiStatistics($data);

            $row = array(
                'action'            => 'add_queue',
                'request_sent'      => $today_now,
                'profile_id'        => $profile_id,
                'profile_name'      => $profile_selected->formatted_service . ': ' . $profile_selected->formatted_username,
                'result'            => 'success',
                'result_message'    => $resultPost['message'],
                'status_text'       => $params['text'],
                'status_image'      => $params['media']['photo'] ?? null,
                'status_link'       => $params['media']['link'] ?? null,
            );
            $log->add( $post_id, $row );
            wp_send_json_success([
                'message' => __('Success', 'evergreen-content-poster'),
                'error' => 200
            ]);
        }
    }

    public function ajaxDeleteCategory(): void {
        global $wpdb;

        $category_id = absint($_POST['category_id']);

        // Check if the category exists in the database
        $category = $wpdb->get_row("SELECT * FROM wp_evergreen_categories WHERE id = ${category_id}");
        if(empty((array)$category)) {
            wp_send_json_error([
                'message' => __('The category doesn\'t exist', 'evergreen-content-poster'),
                'error' => 0
            ]);
        } else {

            // Get all posts in category
            $strSql = "SELECT p.* FROM wp_posts p JOIN wp_postmeta pm ON pm.post_id = p.ID WHERE pm.meta_key = 'ecp-post-category' AND meta_value = " . $category_id . " AND p.post_type = 'ecp-posts'";

            $posts = $wpdb->get_results($strSql);

            foreach ($posts as $post) {
                wp_delete_post($post->ID, true);

                $wpdb->delete('wp_postmeta', ['post_id' => $post->ID]);
            }

            // Delete schedule
            $schedules_setting = get_option('ecp_schedule_settings');
            if(!empty($schedules_setting)) {
                $schedules = $schedules_setting['schedules'];

                $this->deleteSchedule($category_id, $schedules);
            }

            $wpdb->delete('wp_evergreen_categories', ['id' => $category_id]);
            wp_send_json_success([
                'timestamp' => current_time('timestamp'),
                'category_id' => $category_id,
                'message' => __('Success', 'evergreen-content-poster'),
                'error' => 200
            ]);
        }
    }

    public function ajaxMoveToDefault(): void {
        global $wpdb;

        $category_id = absint($_POST['category_id']);

        // Check if the category exists in the database
        $category = $wpdb->get_row("SELECT * FROM wp_evergreen_categories WHERE id = ${category_id}");
        if(empty((array)$category)) {
            wp_send_json_error([
                'message' => __('The category doesn\'t exist', 'evergreen-content-poster'),
                'error' => 0
            ]);
        } else {

            // Get Default Category
            $categoryDefault = $wpdb->get_row('SELECT * FROM wp_evergreen_categories WHERE is_default = 1');
            $data = array(
                'meta_value' => $categoryDefault->id
            );

            $where = array(
                'meta_key' => 'ecp-post-category',
                'meta_value' => $category->id
            );

            $wpdb->update('wp_postmeta', $data, $where);

            // Delete schedule
            $schedules_setting = get_option('ecp_schedule_settings');
            if(!empty($schedules_setting)) {
                $schedules = $schedules_setting['schedules'];

                $this->deleteSchedule($category_id, $schedules);
            }

            $wpdb->delete('wp_evergreen_categories', ['id' => $category_id]);
            wp_send_json_success([
                'timestamp' => current_time('timestamp'),
                'category_id' => $category_id,
                'message' => __('Success', 'evergreen-content-poster'),
                'error' => 200
            ]);
        }
    }

    /**
     * Delete schedule by category id and schedules
     *
     * @param $category_id
     * @param $schedules
     */
    public function deleteSchedule($category_id, $schedules): void {
        if(!empty($schedules)) {
            foreach ($schedules as $service => $schedule) {
                foreach ($schedule as $profileId => $single_schedule) {
                    foreach ($single_schedule as $k => $std) {
                        $times = array();
                        foreach ($std->times as $time) {
                            if($time['category_id'] != $category_id) {
                                $times[] = $time;
                            }
                        }

                        $schedules[$service][$profileId][$k]->times = $times;
                    }
                }
            }

            $schedules_setting['schedules'] = $schedules;

            update_option('ecp_schedule_settings', $schedules_setting, true);
        }
    }
    /**
     * Add new Category
     *
     * @since 1.0.0
     */
    public function ajaxAddCategory(): void {
        global $wpdb;

        $category_name = sanitize_text_field($_POST['category_name']);
        $is_random = sanitize_text_field($_POST['category_name']) == 'on' ? 1 : 0;
        $random_category = sanitize_text_field($_POST['category_name']);

        // Check if the category exists in the database
        $category = $wpdb->get_row("SELECT * FROM wp_evergreen_categories WHERE name = '${category_name}'");
        if(!empty((array)$category)) {
            wp_send_json_error([
                'message' => __('Category name already exist', 'evergreen-content-poster'),
                'error' => 0
            ]);
        } else {
            $data = array(
                'name' => $category_name,
                'status' => 1,
                'random_availability' => $is_random,
                'created_at' => date('Y-m-d H:i:s')
            );

            $wpdb->insert('wp_evergreen_categories', $data);
            $category_id = $wpdb->insert_id;
            wp_send_json_success([
                'timestamp' => current_time('timestamp'),
                'category_id' => $category_id,
                'category_name' => $category_name,
                'message' => __('Success', 'evergreen-content-poster'),
                'error' => 200
            ]);
        }
    }

    public function ajaxChangeCategoryStatus(): void {
        global $wpdb;

        $category_id = absint($_POST['category_id']);
        $status = sanitize_text_field($_POST['status']);
        $status = $status == 'on' ? 1 : 0;

        // Check if the category exists in the database
        $category = $wpdb->get_row("SELECT * FROM wp_evergreen_categories WHERE id = ${category_id}");
        if(empty((array)$category)) {
            wp_send_json_error([
                'message' => __('The category doesn\'t exist', 'evergreen-content-poster'),
                'error' => 0
            ]);
        } else {
            $data = array(
                'status' => $status,
                'updated_at' => date('Y-m-d H:i:s')
            );

            $wpdb->update('wp_evergreen_categories', $data, ['id' => $category_id]);
            wp_send_json_success([
                'timestamp' => current_time('timestamp'),
                'category_id' => $category_id,
                'category_name' => $category->name,
                'message' => __('Success', 'evergreen-content-poster'),
                'error' => 200
            ]);
        }
    }

    public function ajaxChangeCategoryRandom(): void {
        global $wpdb;

        $category_id = absint($_POST['category_id']);
        $random = sanitize_text_field($_POST['random']);
        $random = $random == 'on' ? 1 : 0;

        // Check if the category exists in the database
        $category = $wpdb->get_row("SELECT * FROM wp_evergreen_categories WHERE id = ${category_id}");
        if(empty((array)$category)) {
            wp_send_json_error([
                'message' => __('The category doesn\'t exist', 'evergreen-content-poster'),
                'error' => 0
            ]);
        } else {
            $data = array(
                'random_availability' => $random,
                'updated_at' => date('Y-m-d H:i:s')
            );

            $wpdb->update('wp_evergreen_categories', $data, ['id' => $category_id]);
            wp_send_json_success([
                'timestamp' => current_time('timestamp'),
                'category_id' => $category_id,
                'category_name' => $category->name,
                'message' => __('Success', 'evergreen-content-poster'),
                'error' => 200
            ]);
        }
    }

    public function ajaxChangeCategoryName(): void {
        global $wpdb;

        $category_id = absint($_POST['category_id']);
        $category_name = sanitize_text_field($_POST['category_name']);

        // Check if the category exists in the database
        $category = $wpdb->get_row("SELECT * FROM wp_evergreen_categories WHERE id = ${category_id}");
        if(empty((array)$category)) {
            wp_send_json_error([
                'message' => __('The category doesn\'t exist', 'evergreen-content-poster'),
                'error' => 0
            ]);
        } else {
            $data = array(
                'name' => $category_name,
                'updated_at' => date('Y-m-d H:i:s')
            );

            $wpdb->update('wp_evergreen_categories', $data, ['id' => $category_id]);
            wp_send_json_success([
                'timestamp' => current_time('timestamp'),
                'category_id' => $category_id,
                'message' => __('Success', 'evergreen-content-poster'),
                'error' => 200
            ]);
        }
    }

    /**
     * Change Category
     *
     * @since 1.0.0
     */
    public function ajaxPostsSearch(): void {
        global $wpdb;

        $categories = $wpdb->get_results('SELECT * FROM wp_evergreen_categories WHERE status = 1');

        $allCategories = $wpdb->get_results('SELECT * FROM wp_evergreen_categories');
        // Get list post by category_id
        $category_id = absint($_POST['category_id']);
        $order = $_POST['order'];
        $query = trim($_POST['query'], ' ');

        $listProfileIds = array();
        foreach ($this->buffer_profiles as $network => $profile) {
            foreach ($profile as $single_profile) {
                $listProfileIds[] = $single_profile->_id;
            }
        }

        if($category_id) {

            $strSql = "SELECT p.* FROM wp_posts p JOIN wp_postmeta pm ON pm.post_id = p.ID WHERE pm.meta_key = 'ecp-post-category' AND meta_value = " . $category_id . " AND p.post_type = 'ecp-posts' AND p.post_content LIKE '%" . $query . "%'";

            switch ($order) {
                case 'library-recent':
                    $strSql .= ' ORDER BY ID DESC';
                    break;
                case 'library-oldest':
                    $strSql .= ' ORDER BY ID ASC';
                    break;
                case 'postingtime-recent':
                    $strSql = "SELECT p.* FROM wp_posts p JOIN wp_postmeta pm ON pm.post_id = p.ID LEFT JOIN wp_evergreen_content_logs ec ON p.ID = ec.post_id WHERE pm.meta_key = 'ecp-post-category' AND meta_value = " . $category_id . " AND p.post_type = 'ecp-posts' AND p.post_content LIKE '%" . $query . "%' ORDER BY ec.request_sent DESC";
                    break;
                case 'postingtime-oldest':
                    $strSql = "SELECT p.* FROM wp_posts p JOIN wp_postmeta pm ON pm.post_id = p.ID LEFT JOIN wp_evergreen_content_logs ec ON p.ID = ec.post_id WHERE pm.meta_key = 'ecp-post-category' AND meta_value = " . $category_id . " AND p.post_type = 'ecp-posts' AND p.post_content LIKE '%" . $query . "%' ORDER BY ec.request_sent ASC";
                    break;
                default:

                    break;
            }
            $ecp_saved_posts = $wpdb->get_results($strSql);
        } else {
            $strSql = "SELECT * FROM wp_posts WHERE post_type = 'ecp-posts' AND post_content LIKE '%" . $query . "%'";

            switch ($order) {
                case 'library-recent':
                    $strSql .= ' ORDER BY ID DESC';
                    break;
                case 'library-oldest':
                    $strSql .= ' ORDER BY ID ASC';
                    break;
                case 'postingtime-recent':
                    $strSql = "SELECT p.* FROM wp_posts p LEFT JOIN wp_evergreen_content_logs ec ON p.ID = ec.post_id WHERE p.post_type = 'ecp-posts' AND p.post_content LIKE '%" . $query . "%' ORDER BY ec.request_sent DESC";
                    break;
                case 'postingtime-oldest':
                    $strSql = "SELECT p.* FROM wp_posts p LEFT JOIN wp_evergreen_content_logs ec ON p.ID = ec.post_id WHERE p.post_type = 'ecp-posts' AND p.post_content LIKE '%" . $query . "%' ORDER BY ec.request_sent ASC";
                    break;
                default:

                    break;
            }

            $ecp_saved_posts = $wpdb->get_results($strSql);
        }

        $saved_posts = array();
        if(count($ecp_saved_posts) > 0) {
            foreach ($ecp_saved_posts as $k => $saved) {
                $profileId = get_post_meta($saved->ID, 'ecp-post-profile', true);

                if (in_array($profileId, $listProfileIds)) {
                    $saved_posts[] = $saved;
                }
            }
        }

        ob_start();
        if(count($saved_posts) > 0) {
            foreach ($saved_posts as $key => $post){
                $image = get_post_meta( $post->ID, 'ecp-post-media', true );
                $profileId = get_post_meta($post->ID, 'ecp-post-profile', true);
                $ecp_post_ref = get_post_meta($post->ID, 'ecp-post-ref', true);

                if($ecp_post_ref) {
                    $permalink = get_permalink($ecp_post_ref);
                } else {
                    $permalink = '';
                }

                $ecp_category_id = get_post_meta($post->ID, 'ecp-post-category', true);

                if($ecp_category_id) {
                    $category = $wpdb->get_row("SELECT * FROM wp_evergreen_categories WHERE id = ${ecp_category_id}");
                }

                $selected_profile = new stdClass();
                foreach ($this->buffer_profiles as $network => $profile) {
                    foreach ($profile as $single_profile) {
                        if($single_profile->_id == $profileId) {
                            $selected_profile = $single_profile;
                        }
                    }
                }
                if(!empty((array)$selected_profile)):
                    if($permalink != '') {
                        if(isset($setting['utm_tags']) && $setting['utm_tags'] == 'Y') {
                            $link = trim($permalink, '/') . '?utm_source=' . str_replace(' ', '', $selected_profile->formatted_service) . '&utm_medium=social&utm_campaign=Evergreen%20Content%20Poster';
                        } else {
                            $link = trim($permalink, '/');
                        }

                        if($selected_profile->service == 'twitter') {
                            $length = 24;
                        } else {
                            $length = strlen($link) + 1;
                        }
                    } else {
                        $link = '';
                        $length = 0;
                    }

                    global $wpdb;
                    // Check if the post is shared on the buffer and if so, when
                    $history_post_daily = $wpdb->get_row('SELECT * FROM wp_evergreen_content_logs WHERE post_id = ' . $post->ID . " AND result = 'success' ORDER BY request_sent DESC LIMIT 1");
                    ?>
                    <div class="ecp-section ecp-grid ecp-col-940 ecp-fit ecp-content-container ecp-post-saved-template" id="ecp_post_<?php echo $post->ID ?>">
                        <input type="hidden" class="ecp-post-id" value="<?php echo $post->ID; ?>" />
                        <input type="hidden" class="ecp-post-ref" value="<?php echo $ecp_post_ref; ?>" />
                        <input type="hidden" class="saved-category-id" value="<?php echo $category->id; ?>" />
                        <div class="ecp-grid ecp-col-620 content-show" style="margin-bottom: 0px;">
                            <div class="ecp-section ecp-grid ecp-col-940">
                                <div class="ecp-grid ecp-col-855">
                                    <?php if(!empty((array)$history_post_daily)):?>
                                        <p class="ecp-post-last-shared"><?php _e('Last shared to your', 'evergreen-content-poster'); ?> <?= $selected_profile->formatted_username . ' ' . $selected_profile->formatted_service ?> <?php _e('at', 'evergreen-content-poster'); ?> <?php echo date('M d, Y H:i:s', strtotime($history_post_daily->request_sent)); ?></p>
                                        <?php if($category): ?><span class="category-name"><?= $category ? $category->name : '' ?></span> <?php endif; ?>
                                    <?php else:?>
                                        <p class="ecp-post-last-shared"><?php _e('Not shared to your', 'evergreen-content-poster') ?> <?php echo $selected_profile->formatted_service ?> <?php _e('yet', 'evergreen-content-poster'); ?></p>
                                        <?php if($category): ?><span class="category-name"><?= $category ? $category->name : '' ?></span> <?php endif; ?>
                                    <?php endif;?>
                                </div>
                                <div class="ecp-grid ecp-col-10">
                                    <div class="ecp-connected-profile-avatar" style="padding-top: 15px;">
                                        <img class="ecp-profile-circle-small" ng-src="<?php echo !empty((array)$selected_profile) ? $selected_profile->avatar : EVERGREEN_CONTENT_POSTER_PATH . '/admin/img/ecp-profile-unknown.png'; ?>" img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png" src="<?php echo !empty((array)$selected_profile) ? $selected_profile->avatar : EVERGREEN_CONTENT_POSTER_PATH . '/admin/img/ecp-profile-unknown.png'; ?>" />
                                        <div class="ecp-social-network-icon-small ecp-<?php echo !empty((array)$selected_profile) ? $selected_profile->service : '' ?>"></div>
                                        <div></div>
                                    </div>
                                </div>
                                <div class="ecp-grid ecp-col-10" style="padding-top: 15px;">
                                    <a href="#" class="ecp-post-action ecp-post-edit">
                                        <span class="dashicons dashicons-edit-page"></span>
                                    </a>
                                </div>
                                <div class="ecp-grid ecp-col-10" style="padding-top: 15px;">
                                    <a href="#" class="ecp-post-action ecp-post-delete">
                                        <span class="dashicons dashicons-trash"></span>
                                    </a>
                                </div>
                            </div>
                            <div class="ecp-section ecp-grid ecp-col-940 ecp-post-text">
                                <p class="ecp-post-content"><?php echo $post->post_content ?></p>
                            </div>
                        </div>

                        <div class="ecp-grid ecp-col-620 content-edit hidden" style="margin-bottom: 0px;">
                            <div class="ecp-section ecp-grid ecp-col-940">
                                <div class="ecp-grid ecp-col-855" style="margin-bottom: 0">
                                    <?php if(!empty((array)$history_post_daily)):?>
                                        <p class="ecp-post-last-shared"><?php _e('Last shared to your', 'evergreen-content-poster'); ?> <?= $selected_profile->formatted_username . ' ' . $selected_profile->formatted_service ?> <?php _e('at', 'evergreen-content-poster'); ?> <?php echo date('M d, Y H:i:s', strtotime($history_post_daily->request_sent)); ?></p>
                                        <span class="category-name"><?= $category ? $category->name : '' ?></span>
                                    <?php else:?>
                                        <p class="ecp-post-last-shared"><?php _e('Not shared to your', 'evergreen-content-poster') ?> <?php echo $selected_profile->formatted_service ?> <?php _e('yet', 'evergreen-content-poster'); ?></p>
                                        <span class="category-name"><?= $category ? $category->name : '' ?></span>
                                    <?php endif;?>
                                </div>
                            </div>

                            <?php
                            switch ($selected_profile->service) {
                                case 'facebook':
                                    $limit = EVERGREEN_CONTENT_POSTER_FACEBOOK_POST_LENGTH;
                                    break;
                                case 'instagram':
                                    $limit = EVERGREEN_CONTENT_POSTER_INSTAGRAM_POST_LENGTH;
                                    break;
                                case 'linkedin':
                                    $limit = EVERGREEN_CONTENT_POSTER_LINKEDIN_PROFILE_POST_LENGTH;
                                    break;
                                case 'pinterest':
                                    $limit = EVERGREEN_CONTENT_POSTER_PINTEREST_POST_LENGTH;
                                    break;
                                case 'twitter':
                                    $limit = EVERGREEN_CONTENT_POSTER_TWITTER_POST_LENGTH;
                                    break;
                                default:
                                    $limit = 600;
                                    break;
                            }
                            ?>
                            <div class="ecp-input" style="top: -25px; position: relative;">
                                <div class="area-content-box">
                                    <?php if(empty($image)){ $cur_length = $limit - strlen($post->post_content); } else { $cur_length = $limit - strlen($post->post_content) - $length;} ?>
                                    <div class="ecp-countdown ecp-blue" <?php if($cur_length < 0): ?> style="background-color: rgb(251, 86, 84)" <?php endif;?>><span class="counterNumber"><?php if(empty($image)){ echo $limit - strlen($post->post_content); } else { echo $limit - strlen($post->post_content) - $length;} ?></span></div>
                                    <textarea data-network="<?php echo $selected_profile->service ?>" rows="3" data-counter="<?php echo $limit?>" class="ecp-post-content area-content ecp-service-post-text-library text-content-<?php echo $post->ID?>" data-id="<?php echo $post->ID?>" data-length="<?php if(empty($image)){ echo $limit - strlen($post->post_content); } else { echo $limit - strlen($post->post_content) - $length;}?>" style="min-height: unset"><?php echo $post->post_content ?></textarea>
                                </div>
                            </div>
                            <select name="ecp-category-libary" value="<?= $ecp_category_id ?>" class="ecp-admin-input ecp-category-libary ecp_category_select">
                                <?php
                                if(count($allCategories) > 0) {
                                    foreach ($allCategories as $category) {
                                        ?>
                                        <option value="<?php echo $category->id ?>" <?php if($category->id == $ecp_category_id): ?> selected <?php endif; ?>><?php echo $category->name ?></option>
                                        <?php
                                    }
                                }
                                ?>
                            </select>
                            <button id="add-row-<?php echo $post->ID?>" class="button ecp-navy-button change-post-in-library" style="margin-top: -10px" data-id="<?php echo $post->ID?>" <?php if ($cur_length < 0): ?> disabled<?php endif;?>><?php _e( 'Save changes', 'evergreen-content-poster' ); ?></button>
                            <button class="ecp-button cancel-change" style="margin-top: -10px; margin-right: 20px!important; cursor: pointer" data-id="<?php echo $post->ID?>"><?php _e( 'Cancel', 'evergreen-content-poster' ); ?></button>
                        </div>
                        <div class="ecp-grid ecp-col-300 ecp-post-img-bg" style="margin-bottom: 0px;height: 222px">
                            <?php if ( !empty( $image) ) :?>
                                <img class="ecp-post-image-display" src="<?php echo get_post_meta($post->ID, 'ecp-post-media', true); ?>" />
                            <?php else : ?>
                                <img class="ecp-post-image-display" src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-visual-attached.png" />
                            <?php endif; ?>
                            <div class="ecp-image-lib-overlay"></div>
                            <div class="ecp-image-actions">
                                <a href="#" class="ecp-image-edit ecp-edit-media" title="" target="_blank">
                                    <label for="wp_uploadfile_new_<?php echo $post->ID?>" data-id="<?php echo $post->ID?>"><span class="dashicons dashicons-edit"></span></label>
                                    <input id="wp_uploadfile_new_<?php echo $post->ID?>" data-id="<?php echo $post->ID?>" type="file" class="ecp-fileinput" name="egpostattachement[]" value="" />
                                    <input class="ecp-post-image" data-profile="" type="hidden" name="ecp_post_image" value="" />
                                </a>
                                <?php if($selected_profile->service != 'instagram' && $selected_profile->service != 'pinterest'): ?>
                                    <a href="#" class="ecp-image-delete ecp-remove-media ecp-image-delete-add-media-saved <?php if (empty($image)) : ?> hidden <?php endif; ?>" title="">
                                        <span class="dashicons dashicons-no-alt"></span>
                                    </a>
                                <?php endif;?>
                                <input type="hidden" class="url-plugin" value="<?= EVERGREEN_CONTENT_POSTER_PATH ?>">
                                <input type="hidden" class="is_image" value="<?php if(empty($image)){ echo 0; } else { echo 1;} ?>">
                                <input type="hidden" class="url-length" value="<?php echo $length?>">
                                <input type="hidden" class="ecp-network" value="<?php echo $selected_profile->service?>">
                            </div>
                        </div>
                    </div>
                <?php endif;?>
            <?php }
        } else {
            ?>
            <div class="ecp-section ecp-grid ecp-col-940 ecp-no-result-class" align="center">
                <p class="ecp-no-result">
                    <?php if($category_id && $query == ''): ?>
                        <?php _e( 'No posts were found in this category', 'evergreen-content-poster' ); ?>
                    <?php else: ?>
                        <?php echo _e( 'No results were found, while searching "', 'evergreen-content-poster' ) . $query . '"...' ?>
                    <?php endif;?>
                </p>
            </div>

            <?php
        }


        $content = ob_get_clean();
        wp_send_json_success($content);
    }

    /**
     * Delete image when click button "x"
     *
     * @since 1.0.0
     */
    public function ajaxDeleteMedia(): void {
        $post_id = absint($_POST['post_id']);

        if (!update_post_meta($post_id, 'ecp-post-media', ''))
            wp_send_json_error('error');

        wp_send_json_success(['timestamp' => current_time('timestamp')]);
    }

    public function load_media_files(): void {
        wp_enqueue_media();
    }

    /**
     * Change post content when click "edit"
     *
     * @since 1.0.0
     */
    public function ajaxChangePostContent(): void {

        $post_id = absint($_POST['post_id']);
        $content = sanitize_text_field($_POST['content']);
        $category_id = absint($_POST['category_id']);
        $myPost = array();
        $myPost['ID'] = $post_id;
        $myPost['post_content'] = $content;

        if(!wp_update_post($myPost, true)) {
            wp_send_json_error('error');
        } else {
            update_post_meta($post_id, 'ecp-post-category', $category_id);
            wp_send_json_success(['timestamp' => current_time('timestamp')]);
        }
    }

    /**
     * Change post image when click "edit"
     *
     * @since 1.0.0
     */
    public function ajaxChangePostImage(): void {

        $post_id = absint($_POST['post_id']);
        $url = sanitize_text_field($_POST['url']);
        if(!update_post_meta($post_id, 'ecp-post-media', $url)) {
            wp_send_json_error('error');
        } else {
            wp_send_json_success(['timestamp' => current_time('timestamp')]);
        }
    }

    /**
     * Delete post when click "DELETE"
     *
     * @since 1.0.0
     */
    public function delete_network_post(): void
    {
        global $wpdb;
        if (!empty($_POST['post_ref']) && intval($_POST['post_ref']) < 0)
            wp_send_json_error('error');

        $post_id = absint($_POST['ecp_post_id']);

        if (!wp_delete_post($post_id, true))
            wp_send_json_error('error');

        $wpdb->delete('wp_postmeta', ['post_id' => $post_id]);

        wp_send_json_success(['timestamp' => current_time('timestamp')]);
    }

    public function load_page(): void {
        global $wpdb;

        $categories = $wpdb->get_results('SELECT * FROM wp_evergreen_categories WHERE status = 1');

        $allCategories = $wpdb->get_results('SELECT * FROM wp_evergreen_categories');
        ?>
        <div class="ecp-grid ecp-col-940 ecp-top-menu" ecp-registered="1">
            <input type="hidden" class="in-library" name="in-library" value="1">
            <div class="header-wrapper-box" style="position: relative">
                <div class="ecp-header-wrapper">
                    <div class="ecp-grid ecp-col-700">
                        <div class="ecp-header-logo"></div>
                        <ul class="ecp-header-menu">
                            <li class=""><a class="ecp-tab-selector" href="<?php echo get_bloginfo('wpurl'); ?>/wp-admin/admin.php?page=evergreen-content-settings" data-link="ecp_settings"><span><?php _e( 'Settings', 'evergreen-content-poster' ); ?></span></a></li>
                            <li class="ecp-active-tab"><a class="ecp-tab-selector" href="#" data-link="ecp_content_library"><span><?php _e( 'Content Library', 'evergreen-content-poster' ); ?></span></a></li>
                        </ul>
                    </div>
                    <div class="ecp-clearfix"></div>
                </div>
                <div class="ecp-grid ecp-col-940 ecp-fit ecp-loading-saving"><?php _e( 'Saving Settings', 'evergreen-content-poster' ); ?></div>
            </div>

            <label class="hidden category"><?php _e('category', 'evergreen-content-poster'); ?></label>
            <label class="hidden saving-post"><?php echo sprintf(__('Adding content item to your %s queue', 'evergreen-content-poster'), '<span class="saving-network-name"></span>') ?></label>
            <label class="hidden saving-default"><?php _e('Saving Category', 'evergreen-content-poster'); ?></label>
            <label class="hidden saving-active"><?php _e('Category set to active', 'evergreen-content-poster'); ?></label>
            <label class="hidden saving-inactive"><?php _e('Category set to inactive', 'evergreen-content-poster'); ?></label>

            <label class="hidden saving-random-active"><?php _e('Category will be used when random category is selected in your schedule', 'evergreen-content-poster'); ?></label>
            <label class="hidden saving-random-inactive"><?php _e('Category won\'t be used when random category is selected in your schedule', 'evergreen-content-poster'); ?></label>

            <label class="hidden saving-success"><?php _e('Category Saved!', 'evergreen-content-poster'); ?></label>
            <label class="hidden saving-error"><?php _e('There was an error saving your category. Please try again later.', 'evergreen-content-poster'); ?></label>
            <label class="hidden saving-delete-category"><?php echo sprintf(__('Deleting all posts from category %s and deleting category %s', 'evergreen-content-poster'), '<span class="saving-category-name"></span>', '<span class="saving-category-name"></span>') ?></label>

            <label class="hidden saved-delete-category"><?php echo sprintf(__('Successfully deleted all posts from category %s and category %s', 'evergreen-content-poster'), '<span class="saving-category-name"></span>', '<span class="saving-category-name"></span>') ?></label>
            <label class="hidden saving-move-category"><?php echo sprintf(__('Moving all posts to the default category and deleting category %s', 'evergreen-content-poster'), '<span class="saving-category-name"></span>') ?></label>
            <label class="hidden saved-move-category"><?php echo sprintf(__('Successfully moved all posts and deleted category %s', 'evergreen-content-poster'), '<span class="saving-category-name"></span>') ?></label>
            <label class="hidden saving-post-success"><?php echo sprintf(__('Content item successfully added to your %s queue', 'evergreen-content-poster'), '<span class="saving-network-name"></span>') ?></label>
            <label class="hidden saving-post-error"><?php echo sprintf(__('There was a problem adding this content item to your %s queue', 'evergreen-content-poster'), '<span class="saving-network-name"></span>') ?></label>
            <label class="hidden saving-category"><?php echo sprintf(__('Creating category %s', 'evergreen-content-poster'), '<span class="saving-category-name"></span>') ?></label>
            <label class="hidden saved-category"><?php echo sprintf(__('Successfully created category %s', 'evergreen-content-poster'), '<span class="saving-category-name"></span>') ?></label>
            <label class="hidden sharing-now"><?php echo sprintf(__('Sharing to your %s', 'evergreen-content-poster'), '<span class="social-network-name"></span>') ?></label>
            <label class="hidden shared-now"><?php echo sprintf(__('Successfully shared to your %s', 'evergreen-content-poster'), '<span class="social-network-name"></span>') ?></label>
            <label class="hidden adding-now"><?php echo sprintf(__('Adding message to your %s', 'evergreen-content-poster'), '<span class="social-network-name"></span>') ?></label>
            <label class="hidden added-now"><?php echo sprintf(__('Successfully added message to your %s', 'evergreen-content-poster'), '<span class="social-network-name"></span>') ?></label>
            <label class="hidden default-error"><?php _e('An error has occurred, please try again later', 'evergreen-content-poster') ?></label>
        </div>
        <div class="ecp-wrapper">
            <div class="ecp-container">

                <div class="ecp-section">

                    <div class="ecp-grid ecp-col-700">
                        <div id="ecp-saved-posts-block" class="ecp-admin-tab ecp-grid ecp-col-940 ecp-message" style="display: block;">

                            <?php

                            $user_id = get_current_user_id();

                            if (defined('DISABLE_WP_CRON') && DISABLE_WP_CRON == true && !get_user_meta($user_id, 'ecp-wp-cron-notice-dismissed')) { ?>
                                <div class="ecp-error-container-notification">
                                    <div class="ecp-container-notification__image">
                                        <img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-wp-cron-not-working.svg"
                                             width="60" height="60">
                                    </div>
                                    <div class="top-notify">
                                        <div class="ecp-container-notification__content">
                                            <h3><?php _e('The WordPress Cron seems to be disabled', 'evergreen-content-poster'); ?></h3>
                                            <p><?php echo sprintf(
                                                /* translators: %1s is a link start tag to an FAQ article to help troubleshoot the cron issue, %2s is the link closing tag. */
                                                    esc_html__('The WordPress Cron seems to be disabled on your website. This can cause sharing issues with the Evergreen Content Poster. If sharing is not working, then see %1shere for a potential solution.%2s', 'evergreen-content-poster'),
                                                    '<a href="https://evergreencontentposter.io/#how-can-i-fix-the-evergreen-content-poster-not-posting" target="_blank">',
                                                    '</a>'
                                                ); ?>
                                            </p>
                                        </div>
                                        <a href="#" style=""
                                           class="button dismiss ecp-container__configuration-wizard--dismiss--cron">
                                            <span class="dashicons dashicons-no-alt"></span>
                                        </a>
                                    </div>
                                </div>
                            <?php } ?>

                            <div class="ecp-section ecp-grid ecp-col-940 ecp-fit ecp-option-container ecp-content-category-title-wrapper">
                                <h2><?php _e( 'Your Content Library Categories', 'evergreen-content-poster' ); ?></h2>
                            </div>

                            <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting ecp-content-library-tool">
                                <div class="ecp-grid ecp-col-160 flex-item">
                                    <select name="ecp_category_sort" value="" class="ecp-admin-input ecp_category_sort ecp_category_select" aria-invalid="false">
                                        <option value="0" selected=""><?php _e( 'All categories', 'evergreen-content-poster' ); ?></option>
                                        <?php
                                        if(count($allCategories) > 0) {
                                            foreach ($allCategories as $category) {
                                                ?>
                                                <option value="<?php echo $category->id ?>"><?php echo $category->name ?></option>
                                                <?php
                                            }
                                        }
                                        ?>
                                    </select>
                                </div>
                                <div class="ecp-grid ecp-col-220 flex-item">
                                    <select name="ecp_library_sort_order" value="" class="ecp-admin-input ecp_library_sort_order">
                                        <option value="library-recent"><?php _e( 'Added to Library (recent first)', 'evergreen-content-poster' ); ?></option>
                                        <option value="library-oldest"><?php _e( 'Added to Library (oldest first)', 'evergreen-content-poster' ); ?></option>
                                        <option value="postingtime-recent"><?php _e( 'Posting time (recent first)', 'evergreen-content-poster' ); ?></option>
                                        <option value="postingtime-oldest"><?php _e( 'Posting time (oldest first)', 'evergreen-content-poster' ); ?></option>
                                    </select>
                                </div>
                                <div class="ecp-grid ecp-col-220 flex-item">
                                    <div class="ecp-admin-input" style="border: 1px solid #ced3cd;border-radius: 4px;float: right;box-shadow: none;margin: 2px 0 1px 0;width: 100%;height: 50px; background-color: #fff">
                                        <input style="border-radius: 0;width: 85%; padding: 10px; border: none; border-right: 1px solid #ced3cd" type="text" name="ecp_content_search" placeholder="<?php _e( 'Search', 'evergreen-content-poster' ); ?>" class=" ecp_content_search" data-ref="saved_numberofdays" aria-invalid="false" /><span style="width: 13%; padding-top: 13px; color: #ced3cd"; class="dashicons dashicons-search"></span>
                                    </div>
                                </div>
                                <div class="ecp-grid ecp-col-120 flex-item">
                                    <div class="button ecp-navy-button add_new_cate_but" style="height: 50px; margin: 2px 0; float: none; padding: 17px 30px;"><?php _e( 'Add new category', 'evergreen-content-poster' ); ?></div>
                                </div>
                                <div class="ecp-grid ecp-col-140 ecp-option-container ecp-field-setting ecp-network-container flex-item">
                                    <div class="ecp-grid-right ecp-profile-dropdown" style="width: 100%">
                                        <a href="javascript:void(0)" class="ecp-col-940 button ecp-navy-button ecp-show-profiles"><?php _e('Add one more post', 'evergreen-content-poster'); ?> <span class="ecp-grid-right dashicons dashicons-arrow-down-alt2" style="position: absolute;top: 18px;right: 10px;"></span></a>
                                        <ul class="ecp-network-list">
                                            <?php foreach ($this->buffer->profiles() as $service => $profile_list) : ?>
                                                <?php
                                                foreach ($profile_list as $key => $single_profile) :
                                                    $avatar = EVERGREEN_CONTENT_POSTER_PATH . '/admin/img/ecp-profile-unknown.png';
                                                    if (!empty($single_profile->avatar))
                                                        $avatar = $single_profile->avatar;

                                                    $profile_username = !empty($single_profile->formatted_username) ? $single_profile->formatted_username : strtolower($single_profile->service_type) . ($key + 1);
                                                    if (strlen($profile_username) > 18) {
                                                        $profile_username = substr($profile_username, 0, 15) . '...';
                                                    }

                                                    $service_type = ucwords($single_profile->service . ' ' . strtolower($single_profile->service_type));
                                                    if (strlen($service_type) > 17) {
                                                        $service_type = substr($service_type, 0, 14) . '...';
                                                    }
                                                    $length = 0;
                                                    $link = '';
                                                    ?>
                                                    <li>
                                                        <div class="ecp-grid ecp-col-940">
                                                            <a href="javascript:void(0)" data-url="<?= $link?>" data-urllength="<?= $length ?>" data-username="<?php echo $single_profile->formatted_username; ?>" data-formatted-service="<?= $single_profile->formatted_username . ' ' . $single_profile->formatted_service; ?>" data-profile="<?php echo $single_profile->id; ?>" data-service="<?php echo strtolower($single_profile->service) . '-' . strtolower($single_profile->service_type); ?>" data-avatar="<?php echo $avatar; ?>" data-network="<?php echo strtolower($single_profile->service); ?>" class="button ecp-network-single">
                                                                <div class="ecp-connected-profilex">
                                                                    <div class="ecp-connected-profile-avatar">
                                                                        <img class="ecp-profile-circle-medium" ng-src="<?php echo $avatar; ?>" img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png" src="<?php echo $avatar; ?>" />
                                                                        <div class="ecp-social-network-icon-medium ecp-<?php echo strtolower($single_profile->service); ?>"></div>
                                                                        <span class="ecp-connected-profile-network"><?php _e($service_type, 'evergreen-content-poster'); ?></span>
                                                                    </div>
                                                                </div>
                                                            </a>
                                                        </div>
                                                    </li>
                                                <?php
                                                endforeach;
                                                unset($single_profile);
                                                ?>
                                            <?php endforeach; ?>
                                        </ul>
                                    </div>
                                </div>
                            </div>

                            <!-- Adding a category into the system -->
                            <div id="ecp_add_category" class="ecp-hidden">
                                <div class="ecp-grid ecp-col-300">
                                    <p class="ecp-input-label"><?php _e( 'Enter category name', 'evergreen-content-poster' ); ?></p>
                                </div>
                                <div class="ecp-grid ecp-col-300">
                                    <input type="text" name="ecp_category_name" min="1" max="256" required="true" placeholder="<?php _e( 'Category name', 'evergreen-content-poster' ); ?>" class="ecp-admin-input ecp_category_name"/>
                                </div>
                                <div class="ecp-grid ecp-col-60">
                                    <div class="button ecp-default-button category_cancel" style="height: 50px; margin: 2px 2em 0 0; float: none; padding: 17px 30px;"><?php _e( 'Cancel', 'evergreen-content-poster' ); ?></div>
                                </div>
                                <div class="ecp-grid ecp-col-60">
                                    <div class="button ecp-navy-button category_add_new" style="height: 50px; margin: 2px 2em; float: none; padding: 17px 30px;" disabled><?php _e( 'Save', 'evergreen-content-poster' ); ?></div>
                                </div>

                                <div class="ecp-clearfix"></div>

                                <div class="ecp-grid ecp-col-300">
                                    <p class="ecp-input-label"><?php _e('Can also be used as random category', 'evergreen-content-poster'); ?></p>
                                    <p class="description"><?php _e('If you chose "Random Category" (instead of a specific category) in your schedule for a particular account, we randomly select a category from those that have this checkbox turned on, and also have posts available for that particular account. Within the randomly selected category we use the next content in line.', 'evergreen-content-poster'); ?></p>
                                </div>

                                <div class="ecp-grid ecp-col-300">
                                    <?php
                                    $checked = 'checked';
                                    $data_status = 'on';
                                    ?>
                                    <input type="checkbox" class="ecp-hidden" name="random_availability" value="Y" data-ref="saved_random_availability" checked="checked" />
                                    <input type="hidden" name="saved_random_availability" value="on" />
                                    <div class="ecp-checkbox-toggle" data-status="<?php echo $data_status; ?>" data-field="random_availability">
                                        <div class="ecp-checkbox-on"><?php _e('ON', 'evergreen-content-poster'); ?></div>
                                        <div class="ecp-checkbox-off"><?php _e('OFF', 'evergreen-content-poster'); ?></div>
                                    </div>
                                </div>

                            </div>

                            <div id="ecp_default_category_view">
                                <div class="ecp-grid ecp-col-940">
                                    <p class="ecp-show-edit"><?php echo sprintf(
                                        /* translators: %1$s is anchor tag to open the edit categories part, %2$s is the link closing tag */
                                            esc_html__('Click %1shere%2s to edit the categories.', 'evergreen-content-poster'),
                                            '<a class="ecp-show-categories" href="#">',
                                            '</a>'); ?>
                                    </p>
                                    <p class="ecp-hidden ecp-hide-edit"><?php echo sprintf(
                                        /* translators: %1$s is anchor tag to open the edit categories part, %2$s is the link closing tag */
                                            esc_html__('Click %1shere%2s to stop editing the categories.', 'evergreen-content-poster'),
                                            '<a class="ecp-hide-categories" href="#">',
                                            '</a>'); ?>
                                    </p>
                                </div>
                            </div>

                            <!-- Show and edit active categories -->
                            <div id="ecp_edit_category" class="ecp-hidden">
                                <div class="ecp-grid ecp-col-940">
                                    <p><?php _e( 'This table shows your (active) categories, and how many posts each category has. If you want you can edit the category name, empty the category, or delete the category.', 'evergreen-content-poster' ); ?></p>
                                    <p><?php _e( 'By making a category inactive, the scheduler stops sharing posts from that particular category.', 'evergreen-content-poster' ); ?></p>
                                </div>

                                <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">

                                    <div class="ecp-grid ecp-col-60 ecp-bottom-margin-small">
                                        <p><?php _e( 'Active', 'evergreen-content-poster' ); ?></p>
                                    </div>
                                    <div class="ecp-grid ecp-col-60 ecp-bottom-margin-small">
                                        <p><?php _e( 'Random category', 'evergreen-content-poster' ); ?></p>
                                    </div>
                                    <div class="ecp-grid ecp-col-540 ecp-bottom-margin-small">
                                        <p><?php _e( 'Name', 'evergreen-content-poster' ); ?></p>
                                    </div>
                                    <div class="ecp-grid ecp-col-60 ecp-bottom-margin-small">
                                        <p><?php _e( '# Posts', 'evergreen-content-poster' ); ?></p>
                                    </div>
                                    <div class="ecp-grid ecp-col-120 ecp-bottom-margin-small">
                                        <p>&nbsp;</p>
                                    </div>

                                    <div class="categories_list">
                                        <?php
                                        $profileIds = array();
                                        foreach ($this->buffer_profiles as $network => $profile) {
                                            foreach ($profile as $single_profile) {
                                                $profileIds[] = $single_profile->_id;
                                            }
                                        }

                                        ?>

                                        <?php foreach ($allCategories as $category):
                                            // Get count post in category
                                            $strSql = "SELECT p.* FROM wp_posts p JOIN wp_postmeta pm ON p.ID = pm.post_id WHERE pm.meta_key = 'ecp-post-category' AND pm.meta_value = {$category->id} AND p.post_type = 'ecp-posts'";

                                            $results = $wpdb->get_results($strSql);
                                            $count = 0;
                                            foreach ($results as $result) {
                                                $post_meta = get_post_meta($result->ID);
                                                if(isset($post_meta['ecp-post-profile']) && in_array($post_meta['ecp-post-profile'][0], $profileIds)) {
                                                    $count++;
                                                }
                                            }
                                            ?>


                                            <div class="category_box" id="category_box_<?php echo $category->id ?>">
                                                <input type="hidden" class="category-id" value="<?= $category->id ?>">
                                                <div class="ecp-grid ecp-col-60 ecp-bottom-margin-small">
                                                    <div class="ecp-checkbox-toggle-small" data-status="<?php echo $category->status ? 'on' : 'off' ?>" data-field="ecp_cat_active">
                                                        <div class="ecp-checkbox-on-small change_status" ><?php _e('ON', 'evergreen-content-poster'); ?></div>
                                                        <div class="ecp-checkbox-off-small change_status" ><?php _e('OFF', 'evergreen-content-poster'); ?></div>
                                                    </div>
                                                </div>
                                                <div class="ecp-grid ecp-col-60 ecp-bottom-margin-small">
                                                    <div class="ecp-checkbox-toggle-small-random" data-random="<?php echo $category->random_availability ? 'on' : 'off' ?>" data-field="ecp_cat_active">
                                                        <div class="ecp-checkbox-on-small change_random" ><?php _e('ON', 'evergreen-content-poster'); ?></div>
                                                        <div class="ecp-checkbox-off-small change_random" ><?php _e('OFF', 'evergreen-content-poster'); ?></div>
                                                    </div>
                                                </div>
                                                <div class="ecp-grid ecp-col-540 ecp-bottom-margin-small ecp-category-name-show">
                                                    <p><?php echo $category->name ?></p>
                                                </div>
                                                <div class="ecp-grid ecp-col-540 ecp-bottom-margin-small ecp-hidden ecp-category-name-edit">
                                                    <input style="width: 50%; float: left" type="text" class="category-name-input ecp-admin-input" name="category-name-input" value="<?= $category->name ?>">
                                                    <button id="" class="button ecp-navy-button change-category-name" style="margin: 0" data-id="<?php echo $category->id ?>"><?php _e( 'Save changes', 'evergreen-content-poster' ); ?></button>
                                                    <button class="ecp-button change-category-name-cancel" style="margin-top: 0px; margin-right: 20px!important; cursor: pointer" data-id="160"><?php _e( 'Cancel', 'evergreen-content-poster' ); ?></button>
                                                </div>
                                                <div class="ecp-grid ecp-col-60 ecp-bottom-margin-small">
                                                    <!-- if one, then "post" if zero or more than one "posts" -->
                                                    <p><span class="posts_number_all <?php if($category->is_default == 1): ?>posts_number_default <?php else: ?> posts_number <?php endif; ?>"><?php echo $count ? $count : 0 ?> </span> <?php _e( 'post', 'evergreen-content-poster' ); ?></p>
                                                </div>
                                                <div class="ecp-grid ecp-col-120 ecp-bottom-margin-small ecp-category-action">
                                                    <p>
                                                        <span class="dashicons dashicons-edit ecp-change-name-button" title="<?php _e( 'Edit the name of the category', 'evergreen-content-poster' ); ?>"></span>
                                                        <?php if($category->is_default != 1): ?>
                                                            <!-- Delete category and move posts to the default category -->
                                                            <a href="#ex1" rel="modal:open" class="dashicons dashicons-migrate ecp-migrate-button" title="<?php _e( 'Move all posts to the default category', 'evergreen-content-poster' ); ?>"></a>
                                                            <!-- Delete category and delete all the posts -->
                                                            <a href="#delete-modal" rel="modal:open" class="dashicons dashicons-trash ecp-delete-category-button" title="<?php _e( 'Delete category and all posts', 'evergreen-content-poster' ); ?>"></a>
                                                        <?php endif; ?>
                                                    </p>

                                                </div>
                                            </div>
                                        <?php endforeach; ?>
                                    </div>

                                </div>
                            </div>

                            <!-- adding content to the library -->
                            <div class="ecp-hidden ecp-category-fields-base">
                                <div class="category_box" id="">
                                    <input type="hidden" class="category-id" value="">
                                    <div class="ecp-grid ecp-col-60 ecp-bottom-margin-small">
                                        <div class="ecp-checkbox-toggle-small" data-status="on" data-field="ecp_cat_active">
                                            <div class="ecp-checkbox-on-small change_status" ><?php _e('ON', 'evergreen-content-poster'); ?></div>
                                            <div class="ecp-checkbox-off-small change_status" ><?php _e('OFF', 'evergreen-content-poster'); ?></div>
                                        </div>
                                    </div>
                                    <div class="ecp-grid ecp-col-620 ecp-bottom-margin-small ecp-category-name-show">
                                        <p></p>
                                    </div>
                                    <div class="ecp-grid ecp-col-620 ecp-bottom-margin-small ecp-hidden ecp-category-name-edit">
                                        <input style="width: 50%; float: left" type="text" class="category-name-input ecp-admin-input" name="category-name-input" value="">
                                        <button id="" class="button ecp-navy-button change-category-name" style="margin: 0" data-id=""><?php _e( 'Save changes', 'evergreen-content-poster' ); ?></button>
                                        <button class="ecp-button change-category-name-cancel" style="margin-top: 0px; margin-right: 20px!important; cursor: pointer" data-id="160"><?php _e( 'Cancel', 'evergreen-content-poster' ); ?></button>
                                    </div>
                                    <div class="ecp-grid ecp-col-60 ecp-bottom-margin-small">
                                        <!-- if one, then "post" if zero or more than one "posts" -->
                                        <p><span class="posts_number_all posts_number">0 </span> <?php _e( 'post', 'evergreen-content-poster' ); ?></p>
                                    </div>
                                    <div class="ecp-grid ecp-col-120 ecp-bottom-margin-small ecp-category-action">
                                        <p>
                                            <span class="dashicons dashicons-edit ecp-change-name-button" title="<?php _e( 'Edit the name of the category', 'evergreen-content-poster' ); ?>"></span>
                                            <!-- Delete category and move posts to the default category -->
                                            <a href="#ex1" rel="modal:open" class="dashicons dashicons-migrate ecp-migrate-button" title="<?php _e( 'Move all posts to the default category', 'evergreen-content-poster' ); ?>"></a>
                                            <!-- Delete category and delete all the posts -->
                                            <a href="#delete-modal" rel="modal:open" class="dashicons dashicons-trash ecp-delete-category-button" title="<?php _e( 'Delete category and all posts', 'evergreen-content-poster' ); ?>"></a>
                                        </p>

                                    </div>
                                </div>
                            </div>

                            <input type="hidden" name="ecp-post-ref" id="ecp-post-ref" value="" />
                            <input type="hidden" name="url-length" id="url-length" value="" />
                            <div id="ecp-profile-posts-block"></div>

                            <div class="ecp-fields-base ecp-hidden">
                                <div class="ecp-fields-template ecp-post-fields-container ecp-grid ecp-col-940">
                                    <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                        <div class="ecp-hidden ecp-profile-data" data-avatar="" data-network=""></div>
                                        <div id="repeatable-fieldset">
                                            <div id="evergreen-content-poster" class="ecp-new-data-row active-row" rel="1">
                                                <div class="ecp-td">
                                                    <span class="ecp-input-title"><?php _e('Evergreen Content', 'evergreen-content-poster'); ?></span><br /><br />
                                                    <div class="ecp-input" style="top: -25px; position: relative;">
                                                        <div class="ecp-countdown ecp-blue"><span class="counterNumber">256</span></div>
                                                        <textarea name="egcontent[]" cols="60" rows="6" placeholder="<?php _e('Write your awesome custom content here...', 'evergreen-content-poster'); ?>" id="ecp_custom_message" class="ecp-textarea large-text  ecp-service-post-text" name="ecp_custom_mesage" style="border-top-right-radius: 0px;" spellcheck="false"></textarea>
                                                        <input type="hidden" class="url-plugin" value="<?= EVERGREEN_CONTENT_POSTER_PATH ?>">
                                                    </div>
                                                    <p class="ecp-posttext-info"></p>
                                                </div>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting ecp-posts-form-bottom-block">
                                        <div class="ecp-grid ecp-col-300">
                                            <p class="ecp-input-label" style="padding-left: 0;"><?php _e('Evergreen Content Category', 'evergreen-content-poster'); ?></p>
                                            <p class="description"><?php _e('Select the category for this post, or leave for default', 'evergreen-content-poster'); ?></p>
                                        </div>
                                        <div class=" ecp-grid ecp-col-300 ecp-grid-right">
                                            <select style="margin-top: 1rem!important" name="ecp_category" value="" class="ecp-admin-input ecp_category ecp_category_select" data-ref="ecp_categories" aria-invalid="false">
                                                <?php
                                                if(count($allCategories) > 0) {
                                                    foreach ($allCategories as $category) {
                                                        ?>
                                                        <option value="<?php echo $category->id ?>"><?php echo $category->name ?></option>
                                                        <?php
                                                    }
                                                }
                                                ?>
                                            </select>
                                        </div>
                                    </div>

                                    <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting ecp-posts-form-bottom-block">
                                        <div class="ecp-grid ecp-col-460">
                                            <span class="ecp-input-title"><?php _e('Evergreen Content Share Image', 'evergreen-content-poster'); ?></span><br />
                                            <div class="ecp-upload-custom">
                                                <div class="ecp-grid ecp-col-620 ecp-post-img-bg hidden upload-image-new" style="margin-bottom: 0;height: 246px">
                                                    <img class="ecp-post-image-display" src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-visual-attached.png" />
                                                    <div class="ecp-image-overlay"></div>
                                                    <div class="ecp-image-actions">
                                                        <a href="#" class="ecp-image-edit ecp-edit-media" title="" target="_blank">
                                                            <label for="wp_uploadfile_new"><span class="dashicons dashicons-edit"></span></label>
                                                            <input id="wp_uploadfile_new" type="file" class="ecp-fileinput" name="egpostattachement[]" value="" />
                                                            <input class="ecp-post-image" data-profile="" type="hidden" name="ecp_post_image" value="" />
                                                        </a>
                                                        <a href="#" class="ecp-image-delete ecp-remove-media ecp-image-delete-add-media" title="">
                                                            <span class="dashicons dashicons-no-alt"></span>
                                                        </a>
                                                    </div>
                                                </div>
                                                <div class="upload-image-old">
                                                    <div class="ecp-image-upload">
                                                        <label for="wp_uploadfile" class="ecp-label-btn label-custom"><?php _e('Add Media', 'evergreen-content-poster'); ?></label>
                                                        <input id="wp_uploadfile" type="file" class="ecp-fileinput" name="egpostattachement[]" value="" />
                                                        <input class="ecp-post-image" data-profile="" type="hidden" name="ecp_post_image" value="" />
                                                    </div>
                                                    <p class="ecp-postimage-info"></p>
                                                </div>
                                            </div>
                                            <input type="hidden" class="is_image" value="0">
                                        </div>

                                        <div class="ecp-grid ecp-col-460 ecp-grid-right ecp-add-library-item">
                                            <div class="" >
                                                <button id="add-row" class="button ecp-navy-button ecp-add-post"><?php _e('Add Item to Library', 'evergreen-content-poster'); ?></button>
                                            </div>
                                            <div class="" >
                                                <button id="cancel" class="button ecp-default-button ecp-cancel-add-post ecp-cancel-without-popup"><?php _e('Cancel', 'evergreen-content-poster'); ?></button>
                                                <a style="margin-top: 3rem!important; margin-bottom: 0!important;" href="#confirm-cancel-modal" rel="modal:open" class="button ecp-default-button ecp-hidden ecp-cancel-with-popup"><?php _e('Cancel', 'evergreen-content-poster'); ?></button></a>
                                            </div>
                                        </div>

                                        <div id="confirm-cancel-modal" class="modal all-modal">
                                            <p style="border-bottom: 1px solid #a4a4a4; padding: 20px 0"><?php _e('Do you really want to stop adding this item to your library?', 'evergreen-content-poster') ?></p>
                                            <a href="#" style="padding: 10px 30px;" class="button ecp-navy-button ecp-cancel-add-post jquery-modal-close">Ok</a>
                                            <a href="#" style="color:#000; text-decoration:none;margin-right:20px;padding: 10px 30px;border: 1px solid #1b3a51;float: right" class="ecp-button jquery-modal-close"><?php _e('Cancel', 'evergreen-content-poster') ?></a>
                                        </div>
                                        <input type="hidden" class="url-plugin" value="<?= EVERGREEN_CONTENT_POSTER_PATH ?>">
                                        <input type="hidden" class="ecp-social-name-add-post" value="">
                                    </div>
                                </div>
                            </div>

                            <div class="ecp-hidden ecp-posttext-texts">
                                <p class="ecp-posttext facebook-page" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_FACEBOOK_POST_LENGTH; ?>"><?php _e('Based on the current content above your Facebook Page Post has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?></p>
                                <p class="ecp-posttext facebook-group" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_FACEBOOK_GROUP_POST_LENGTH; ?>"><?php _e('Based on the current content above your Facebook Group Post has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?></p>
                                <p class="ecp-posttext instagram" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_INSTAGRAM_POST_LENGTH; ?>"><?php _e('Based on the current content above your Instagram Post has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?></p>
                                <p class="ecp-posttext instagram-business" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_INSTAGRAM_POST_LENGTH; ?>"><?php _e('Based on the current content above your Instagram Post has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?></p>
                                <p class="ecp-posttext linkedin-profile" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_LINKEDIN_PROFILE_POST_LENGTH; ?>"><?php _e('Based on the current content above your LinkedIn Personal Post has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?></p>
                                <p class="ecp-posttext linkedin-page" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_LINKEDIN_PAGE_POST_LENGTH; ?>"><?php _e('Based on the current content above your LinkedIn Page Post has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?></p>
                                <p class="ecp-posttext pinterest" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_PINTEREST_POST_LENGTH; ?>"><?php _e('Based on the current content above your Pinterest Pin description has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?></p>
                                <p class="ecp-posttext pinterest-board" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_PINTEREST_POST_LENGTH; ?>"><?php _e('Based on the current content above your Pinterest Pin description has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?></p>
                                <p class="ecp-posttext twitter-profile" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_TWITTER_POST_LENGTH; ?>"><?php _e('Based on a link being added, and the current content above your tweet has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?></p>
                            </div>
                            <div class="ecp-hidden ecp-postimage-texts">
                                <?php
                                // whichever network is chosen to post to one of the below messages needs to be shown
                                ?>
                                <p class="ecp-postimage facebook-page"><?php _e('Add an image that is optimized for maximum exposure on your Facebook page. We recommend using either the size of a Facebook Page Photo (940x788) or a Facebook Link Post (1200x628).', 'evergreen-content-poster'); ?></p>
                                <p class="ecp-postimage facebook-group"><?php _e('Add an image that is optimized for maximum exposure in Facebook Groups. We recommend using the size of a Facebook Group Photo (640x334).', 'evergreen-content-poster'); ?></p>
                                <p class="ecp-postimage instagram"><?php _e('Add an image that is optimized for maximum exposure on Instagram. We recommend using the size of an Instagram Photo (1080x1080) or a Facebook Link Post (1200x628).', 'evergreen-content-poster'); ?></p>
                                <p class="ecp-postimage instagram-business"><?php _e('Add an image that is optimized for maximum exposure on Instagram. We recommend using the size of an Instagram Photo (1080x1080) or a Facebook Link Post (1200x628).', 'evergreen-content-poster'); ?></p>
                                <p class="ecp-postimage linkedin-profile"><?php _e('Add an image that is optimized for maximum exposure on your LinkedIn profile. We recommend using the size of a LinkedIn Photo (1400x800).', 'evergreen-content-poster'); ?></p>
                                <p class="ecp-postimage linkedin-page"><?php _e('Add an image that is optimized for maximum exposure on your LinkedIn page. We recommend using the size of a LinkedIn Page Photo (1400x800).', 'evergreen-content-poster'); ?></p>
                                <p class="ecp-postimage pinterest"><?php _e('Add one or more images that are optimized for maximum exposure on Pinterest. We recommend using an image that is formatted in a 2:3 aspect ratio like 1000 x 1500.', 'evergreen-content-poster'); ?></p>
                                <p class="ecp-postimage pinterest-board"><?php _e('Add one or more images that are optimized for maximum exposure on Pinterest. We recommend using an image that is formatted in a 2:3 aspect ratio like 1000 x 1500.', 'evergreen-content-poster'); ?></p>
                                <p class="ecp-postimage twitter-profile"><?php _e('Add an image that is optimized for maximum exposure on Twitter. We recommend using an image that is formatted in 16:9 aspect ratio like 1200x675.', 'evergreen-content-poster'); ?></p>
                            </div>

                            <div class="ecp-hidden ecp-post-saved-base">
                                <div class="ecp-section ecp-grid ecp-col-940 ecp-fit ecp-content-container ecp-post-saved-template">


                                    <input type="hidden" class="ecp-post-id" value="" />
                                    <input type="hidden" class="ecp-service" value="" />
                                    <input type="hidden" class="ecp-post-ref" value="" />
                                    <input type="hidden" class="saved-category-id" value="" />
                                    <div class="ecp-grid ecp-col-620 content-show" style="margin-bottom: 0;">
                                        <div class="ecp-section ecp-grid ecp-col-940">
                                            <div class="ecp-grid ecp-col-780">
                                                <p class="ecp-post-last-shared"><?php _e('Not shared to your', 'evergreen-content-poster') ?> <span class="network_name"></span> <?php _e('yet', 'evergreen-content-poster'); ?></p>
                                                <span class="category-name"></span>
                                            </div>
                                            <div class="ecp-grid ecp-col-10">
                                                <div class="ecp-connected-profile-avatar" style="padding-top: 15px;">
                                                    <img class="ecp-profile-circle-small" ng-src="<?php echo $avatar; ?>" img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png" src="<?php echo $avatar; ?>" />
                                                    <div class="ecp-social-network-icon-small ecp-twitter"></div>
                                                </div>
                                            </div>
                                            <div class="ecp-grid ecp-col-10" style="padding-top: 15px;">
                                                <div class="ecp-dropdown">
                                                    <a href="#" class="ecp-post-action ecp-dropdown-share ecp-dropbtn"><span class="dashicons dashicons-share"></span></a>
                                                    <div class="ecp-my-dropdown ecp-dropdown-content">
                                                        <a href="#" class="ecp-share-now-action" data-id="" data-content="" data-image="" data-social-name=""><?php _e('Share now', 'evergreen-content-poster') ?></a>
                                                        <a href="#" class="ecp-add-queue-action" data-id="" data-content="" data-image="" data-social-name=""><?php _e('Add to queue', 'evergreen-content-poster') ?></a>
                                                    </div>
                                                </div>
                                            </div>
                                            <div class="ecp-grid ecp-col-10" style="padding-top: 15px;">
                                                <a href="#" class="ecp-post-action ecp-post-edit">
                                                    <span class="dashicons dashicons-edit-page"></span>
                                                </a>
                                            </div>
                                            <div class="ecp-grid ecp-col-10" style="padding-top: 15px;">
                                                <a href="#" class="ecp-post-action ecp-post-delete">
                                                    <span class="dashicons dashicons-trash"></span>
                                                </a>
                                            </div>
                                        </div>
                                        <div class="ecp-section ecp-grid ecp-col-940 ecp-post-text">
                                            <p class="ecp-post-content"></p>
                                        </div>
                                    </div>
                                    <div class="ecp-grid ecp-col-620 content-edit hidden" style="margin-bottom: 0px;">
                                        <div class="ecp-section ecp-grid ecp-col-940">
                                            <div class="ecp-grid ecp-col-855" style="margin-bottom: 0">
                                                <p class="ecp-post-last-shared"><?php _e('Not shared to your', 'evergreen-content-poster') ?> <span class="network_name"></span> <?php _e('yet', 'evergreen-content-poster'); ?></p>
                                                <span class="category-name"></span>
                                            </div>
                                        </div>

                                        <div class="ecp-input" style="top: -25px; position: relative;">
                                            <div class="area-content-box">
                                                <div class="ecp-countdown ecp-blue"><span class="counterNumber"></span></div>
                                                <textarea data-network="" rows="3" data-counter="" class="ecp-post-content area-content ecp-service-post-text-library" data-id="" data-length="" style="min-height: unset"></textarea>
                                            </div>
                                        </div>
                                        <select name="ecp-category-libary" value="" class="ecp-admin-input ecp-category-libary ecp_category_select" aria-invalid="false">
                                            <?php
                                            if(count($allCategories) > 0) {
                                                foreach ($allCategories as $category) {
                                                    ?>
                                                    <option value="<?php echo $category->id ?>"><?php echo $category->name ?></option>
                                                    <?php
                                                }
                                            }
                                            ?>
                                        </select>
                                        <a href="#" class="button ecp-navy-button change-post-in-library" style="margin-top: -10px" data-id=""><?php _e('Save changes', 'evergreen-content-poster'); ?></a>
                                        <a href="#" class="ecp-button cancel-change" style="margin-top: -10px; margin-right: 20px!important; cursor: pointer" data-id=""><?php _e('Cancel', 'evergreen-content-poster'); ?></a>
                                    </div>

                                    <div class="ecp-grid ecp-col-300 ecp-post-img-bg" style="margin-bottom: 0px;height: 246px">
                                        <img class="ecp-post-image-display" src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-visual-attached.png" />
                                        <div class="ecp-image-overlay"></div>
                                        <div class="ecp-image-actions">
                                            <a href="#" class="ecp-image-edit ecp-edit-media" title="" target="_blank">
                                                <label for="" data-id=""><span class="dashicons dashicons-edit"></span></label>
                                                <input id="" data-id="" type="file" class="ecp-fileinput" name="egpostattachement[]" value="" />
                                                <input class="ecp-post-image" data-profile="" type="hidden" name="ecp_post_image" value="" />
                                            </a>
                                            <a href="#" class="ecp-image-delete ecp-remove-media ecp-image-delete-add-media-saved" title="">
                                                <span class="dashicons dashicons-no-alt"></span>
                                            </a>
                                            <input type="hidden" class="url-plugin" value="<?= EVERGREEN_CONTENT_POSTER_PATH ?>">
                                            <input type="hidden" class="is_image" value="">
                                            <input type="hidden" class="url-length" value="<?php echo $length ?>">
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <!-- Start of the Content Library -->
                            <?php
                            $ecp_saved_posts = new WP_Query(array(
                                'post_type' => array('ecp-posts'),
                                'posts_per_page' => -1,
                                'orderby' => 'ID',
                                'order'   => 'DESC',
                            ));

                            $setting = $this->common->general_settings();
                            ?>

                            <div class="ecp-section ecp-grid ecp-col-940 ecp-fit ecp-option-container ecp-content-library-title-wrapper" style="border-top: none; padding-top: inherit;">
                                <h2><?php _e( 'Your Evergreen Content Library', 'evergreen-content-poster' ); ?></h2>
                            </div>

                            <div id="ecp-post-list">
                                <?php
                                foreach ($ecp_saved_posts->posts as $key => $post) :
                                    $image = get_post_meta( $post->ID, 'ecp-post-media', true );
                                    $profileId = get_post_meta($post->ID, 'ecp-post-profile', true);
                                    $ecp_post_ref = get_post_meta($post->ID, 'ecp-post-ref', true);

                                    if($ecp_post_ref) {
                                        $permalink = get_permalink($ecp_post_ref);
                                    } else {
                                        $permalink = '';
                                    }

                                    $ecp_category_id = get_post_meta($post->ID, 'ecp-post-category', true);
                                    $category = new stdClass();
                                    if($ecp_category_id) {
                                        $category = $wpdb->get_row("SELECT * FROM wp_evergreen_categories WHERE id = ${ecp_category_id}");
                                    }

                                    $selected_profile = new stdClass();
                                    foreach ($this->buffer_profiles as $network => $profile) {
                                        foreach ($profile as $single_profile) {
                                            if($single_profile->_id == $profileId) {
                                                $selected_profile = $single_profile;
                                            }
                                        }
                                    }

                                    if(!empty((array)$selected_profile)):
                                        $social_name = $selected_profile->formatted_username . ' ' . $selected_profile->formatted_service;
                                        if($permalink != '') {
                                            if(isset($setting['utm_tags']) && $setting['utm_tags'] == 'Y') {
                                                $link = trim($permalink, '/') . '?utm_source=' . str_replace(' ', '', $selected_profile->formatted_service) . '&utm_medium=social&utm_campaign=Evergreen%20Content%20Poster';
                                            } else {
                                                $link = trim($permalink, '/');
                                            }

                                            if($selected_profile->service == 'twitter') {
                                                $length = 24;
                                            } else {
                                                $length = strlen($link) + 1;
                                            }
                                        } else {
                                            $link = '';
                                            $length = 0;
                                        }

                                        global $wpdb;
                                        // Check if the post is shared on the buffer and if so, when
                                        $history_post_daily = $wpdb->get_row('SELECT * FROM wp_evergreen_content_logs WHERE post_id = ' . $post->ID . " AND result = 'success' ORDER BY request_sent DESC LIMIT 1");
                                        ?>
                                        <div class="ecp-section ecp-grid ecp-col-940 ecp-fit ecp-content-container ecp-post-saved-template" id="ecp_post_<?php echo $post->ID ?>">
                                            <input type="hidden" class="ecp-post-id" value="<?php echo $post->ID; ?>" />
                                            <input type="hidden" class="ecp-post-ref" value="<?php echo $ecp_post_ref; ?>" />
                                            <input type="hidden" class="saved-category-id" value="<?php echo $category->id; ?>" />
                                            <div class="ecp-grid ecp-col-620 content-show" style="margin-bottom: 0px;">
                                                <div class="ecp-section ecp-grid ecp-col-940">
                                                    <div class="ecp-grid ecp-col-780">
                                                        <?php if(!empty((array)$history_post_daily)):?>
                                                            <p class="ecp-post-last-shared"><?php _e('Last shared to your', 'evergreen-content-poster'); ?> <?= $selected_profile->formatted_username . ' ' . $selected_profile->formatted_service ?> <?php _e('at', 'evergreen-content-poster'); ?> <?php echo date('M d, Y H:i:s', strtotime($history_post_daily->request_sent)); ?></p>
                                                            <?php if($category): ?><span class="category-name"><?= $category ? $category->name : '' ?></span> <?php endif; ?>
                                                        <?php else:?>
                                                            <p class="ecp-post-last-shared"><?php _e('Not shared to your', 'evergreen-content-poster') ?> <?php echo $selected_profile->formatted_service ?> <?php _e('yet', 'evergreen-content-poster'); ?></p>
                                                            <?php if($category): ?><span class="category-name"><?= $category ? $category->name : '' ?></span> <?php endif; ?>
                                                        <?php endif;?>
                                                    </div>
                                                    <div class="ecp-grid ecp-col-10">
                                                        <div class="ecp-connected-profile-avatar" style="padding-top: 15px;">
                                                            <img class="ecp-profile-circle-small" ng-src="<?php echo !empty((array)$selected_profile) ? $selected_profile->avatar : EVERGREEN_CONTENT_POSTER_PATH . '/admin/img/ecp-profile-unknown.png'; ?>" img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png" src="<?php echo !empty((array)$selected_profile) ? $selected_profile->avatar : EVERGREEN_CONTENT_POSTER_PATH . '/admin/img/ecp-profile-unknown.png'; ?>" />
                                                            <div class="ecp-social-network-icon-small ecp-<?php echo !empty((array)$selected_profile) ? $selected_profile->service : '' ?>"></div>
                                                            <div></div>
                                                        </div>
                                                    </div>
                                                    <div class="ecp-grid ecp-col-10" style="padding-top: 15px;">
                                                        <div class="ecp-dropdown">
                                                            <a href="#" class="ecp-post-action ecp-dropdown-share ecp-dropbtn"><span class="dashicons dashicons-share"></span></a>
                                                            <div class="ecp-my-dropdown ecp-dropdown-content">
                                                                <a href="#" class="ecp-share-now-action" data-id="<?php echo $post->ID ?>" data-content="<?= $post->post_content ?>" data-image="<?= $image ?>" data-social-name="<?= $social_name ?>"><?php _e('Share now', 'evergreen-content-poster') ?></a>
                                                                <a href="#" class="ecp-add-queue-action" data-id="<?php echo $post->ID ?>" data-content="<?= $post->post_content ?>" data-image="<?= $image ?>" data-social-name="<?= $social_name ?>"><?php _e('Add to queue', 'evergreen-content-poster') ?></a>
                                                            </div>
                                                        </div>
                                                    </div>
                                                    <div class="ecp-grid ecp-col-10" style="padding-top: 15px;">
                                                        <a href="#" class="ecp-post-action ecp-post-edit">
                                                            <span class="dashicons dashicons-edit-page"></span>
                                                        </a>
                                                    </div>
                                                    <div class="ecp-grid ecp-col-10" style="padding-top: 15px;">
                                                        <a href="#" class="ecp-post-action ecp-post-delete">
                                                            <span class="dashicons dashicons-trash"></span>
                                                        </a>
                                                    </div>
                                                </div>
                                                <div class="ecp-section ecp-grid ecp-col-940 ecp-post-text">
                                                    <p class="ecp-post-content"><span class="ecp-post-content-show"><?php echo preg_replace('@(https?://([-\w\.]+[-\w])+(:\d+)?(/([\w/_\.#-]*(\?\S+)?[^\.\s])?)?)@', '<a class="ecp-library-direct-link" href="$1" target="_blank" rel="nofollow">$1</a>', $post->post_content)  ?></span> <a class="ecp-library-wp-post-link" href="<?php echo $permalink ?>" target="_blank" rel="nofollow"><?php echo $permalink ?></a></p>
                                                </div>
                                            </div>

                                            <div class="ecp-grid ecp-col-620 content-edit hidden" style="margin-bottom: 0px;">
                                                <div class="ecp-section ecp-grid ecp-col-940">
                                                    <div class="ecp-grid ecp-col-855" style="margin-bottom: 0">
                                                        <?php if(!empty((array)$history_post_daily)):?>
                                                            <p class="ecp-post-last-shared"><?php _e('Last shared to your', 'evergreen-content-poster'); ?> <?= $selected_profile->formatted_username . ' ' . $selected_profile->formatted_service ?> <?php _e('at', 'evergreen-content-poster'); ?> <?php echo date('M d, Y H:i:s', strtotime($history_post_daily->request_sent)); ?></p>
                                                            <span class="category-name"><?= $category ? $category->name : '' ?></span>
                                                        <?php else:?>
                                                        <p class="ecp-post-last-shared"><?php _e('Not shared to your', 'evergreen-content-poster') ?> <?php echo $selected_profile->formatted_service ?> <?php _e('yet', 'evergreen-content-poster'); ?></p>
                                                        <span class="category-name"><?= $category ? $category->name : '' ?>
                                                            <?php endif;?>
                                                    </div>
                                                </div>

                                                <?php
                                                switch ($selected_profile->service) {
                                                    case 'facebook':
                                                        $limit = EVERGREEN_CONTENT_POSTER_FACEBOOK_POST_LENGTH;
                                                        break;
                                                    case 'instagram':
                                                        $limit = EVERGREEN_CONTENT_POSTER_INSTAGRAM_POST_LENGTH;
                                                        break;
                                                    case 'linkedin':
                                                        $limit = EVERGREEN_CONTENT_POSTER_LINKEDIN_PROFILE_POST_LENGTH;
                                                        break;
                                                    case 'pinterest':
                                                        $limit = EVERGREEN_CONTENT_POSTER_PINTEREST_POST_LENGTH;
                                                        break;
                                                    case 'twitter':
                                                        $limit = EVERGREEN_CONTENT_POSTER_TWITTER_POST_LENGTH;
                                                        break;
                                                    default:
                                                        $limit = 600;
                                                        break;
                                                }
                                                ?>
                                                <div class="ecp-input" style="top: -25px; position: relative;">
                                                    <div class="area-content-box">
                                                        <?php if(empty($image)){ $cur_length = $limit - strlen($post->post_content); } else { $cur_length = $limit - strlen($post->post_content) - $length;} ?>
                                                        <div class="ecp-countdown ecp-blue" <?php if($cur_length < 0): ?> style="background-color: rgb(251, 86, 84)" <?php endif;?>><span class="counterNumber"><?php if(empty($image)){ echo $limit - strlen($post->post_content); } else { echo $limit - strlen($post->post_content) - $length;} ?></span></div>
                                                        <textarea data-network="<?php echo $selected_profile->service ?>" rows="3" data-counter="<?php echo $limit?>" class="ecp-post-content area-content ecp-service-post-text-library text-content-<?php echo $post->ID?>" data-id="<?php echo $post->ID?>" data-length="<?php if(empty($image)){ echo $limit - strlen($post->post_content); } else { echo $limit - strlen($post->post_content) - $length;}?>" style="min-height: unset"><?php echo $post->post_content ?></textarea>
                                                    </div>
                                                </div>
                                                <select name="ecp-category-libary" value="<?= $ecp_category_id ?>" class="ecp-admin-input ecp-category-libary ecp_category_select">
                                                    <?php
                                                    if(count($allCategories) > 0) {
                                                        foreach ($allCategories as $category) {
                                                            ?>
                                                            <option value="<?php echo $category->id ?>" <?php if($category->id == $ecp_category_id): ?> selected <?php endif; ?>><?php echo $category->name ?></option>
                                                            <?php
                                                        }
                                                    }
                                                    ?>
                                                </select>
                                                <button id="add-row-<?php echo $post->ID?>" class="button ecp-navy-button change-post-in-library" style="margin-top: -10px" data-id="<?php echo $post->ID?>" <?php if ($cur_length < 0): ?> disabled<?php endif;?>><?php _e( 'Save changes', 'evergreen-content-poster' ); ?></button>
                                                <button class="ecp-button cancel-change" style="margin-top: -10px; margin-right: 20px!important; cursor: pointer" data-id="<?php echo $post->ID?>"><?php _e( 'Cancel', 'evergreen-content-poster' ); ?></button>
                                            </div>
                                            <div class="ecp-grid ecp-col-300 ecp-post-img-bg" style="margin-bottom: 0px;height: 222px">
                                                <?php if ( !empty( $image) ) :?>
                                                    <img class="ecp-post-image-display" src="<?php echo get_post_meta($post->ID, 'ecp-post-media', true); ?>" />
                                                <?php else : ?>
                                                    <img class="ecp-post-image-display" src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-visual-attached.png" />
                                                <?php endif; ?>
                                                <div class="ecp-image-lib-overlay"></div>
                                                <div class="ecp-image-actions">
                                                    <a href="#" class="ecp-image-edit ecp-edit-media" title="" target="_blank">
                                                        <label for="wp_uploadfile_new_<?php echo $post->ID?>" data-id="<?php echo $post->ID?>"><span class="dashicons dashicons-edit"></span></label>
                                                        <input id="wp_uploadfile_new_<?php echo $post->ID?>" data-id="<?php echo $post->ID?>" type="file" class="ecp-fileinput" name="egpostattachement[]" value="" />
                                                        <input class="ecp-post-image" data-profile="" type="hidden" name="ecp_post_image" value="" />
                                                    </a>
                                                    <?php if($selected_profile->service != 'instagram' && $selected_profile->service != 'pinterest'): ?>
                                                        <a href="#" class="ecp-image-delete
                                                    ecp-remove-media ecp-image-delete-add-media-saved <?php if(empty($image)): ?> hidden <?php endif; ?>" title="">
                                                            <span class="dashicons dashicons-no-alt"></span>
                                                        </a>
                                                    <?php endif;?>
                                                    <input type="hidden" class="url-plugin" value="<?= EVERGREEN_CONTENT_POSTER_PATH ?>">
                                                    <input type="hidden" class="is_image" value="<?php if(empty($image)){ echo 0; } else { echo 1;} ?>">
                                                    <input type="hidden" class="url-length" value="<?php echo $length?>">
                                                    <input type="hidden" class="ecp-network" value="<?php echo $selected_profile->service?>">
                                                </div>
                                            </div>
                                        </div>
                                    <?php endif;?>
                                <?php endforeach; ?>

                            </div>

                            <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting ecp-no-content-list <?php if ( !empty($ecp_saved_posts->posts) ):?> hidden <?php endif; ?>">
                                <div class="ecp-grid ecp-col-700">
                                    <?php
                                    if (!$this->buffer->get_token()) :
                                        ?>
                                        <img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-content.svg" width="180" height="174" style="display: block; margin: 0 auto 2rem;">
                                        <p class="description" style="text-align: center;"><?php _e('There is nothing added to your library yet.', 'evergreen-content-poster'); ?> <?php echo sprintf(
                                            /* translators: %1$s is a link start tag to Buffer signup page, %2$s is the link closing tag */
                                                esc_html__( 'Before you can add any content though, you first have to %1sconnect your social profiles%2s.', 'evergreen-content-poster'),
                                                '<a href="' . esc_url( admin_url( 'admin.php?page=evergreen-content-settings#AccountSettings') ) . '" style="color: #fb5654">',
                                                '</a>'
                                            ); ?>
                                        </p>
                                    <?php else : ?>
                                        <img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-content.svg" width="180" height="174" style="display: block; margin: 0 auto 2rem;">
                                        <p class="description" style="text-align: center;"><?php _e('There is nothing added to your library yet.', 'evergreen-content-poster');?> <?php echo sprintf(
                                            /* translators: %1$s is a link start tag to the posts page, %2$s is the link closing tag, %3s is a link start tag to the pages page, %4s is the link closing tag */
                                                esc_html__( 'You can add items using the form underneath each %1spost%2s or %3spage%4s.', 'evergreen-content-poster'),
                                                '<a href="' . esc_url( admin_url( 'edit.php') ) .'" style="color: #fb5654">',
                                                '</a>',
                                                '<a href="' . esc_url( admin_url( 'edit.php?post_type=page') ) .'" style="color: #fb5654">',
                                                '</a>'
                                            ); ?>
                                        </p>
                                    <?php endif; ?>
                                </div>
                            </div>

                        </div>
                    </div><!-- end ecp-grid ecp-col-700 -->

                    <div class="ecp-admin-sidebar ecp-grid ecp-col-220 ecp-fit">
                        <div id="ecp-admin-sidebar">
                            <div id="ecp-love" class="ecp-component dark-text text-center">
                                <p class="ecp-component-title"><?php _e('Love the Plugin?', 'evergreen-content-poster'); ?><br />
                                    <span style="font-size:18px;font-weight:normal;"><?php _e('How about rating us?', 'evergreen-content-poster'); ?></span>
                                </p>
                                <div class="ecp-component-icon">
                                    <a class="ecp-rating-link" target="_blank" data-ecp-rating-value="5" href="https://wordpress.org/support/plugin/evergreen-content-poster/reviews/?rate=5"><span class="dashicons dashicons-star-empty"></span></a>
                                    <a class="ecp-rating-link" target="_blank" data-ecp-rating-value="4" href="https://wordpress.org/support/plugin/evergreen-content-poster/reviews/?rate=4"><span class="dashicons dashicons-star-empty"></span></a>
                                    <a class="ecp-rating-link" target="_blank" data-ecp-rating-value="3" href="https://wordpress.org/support/plugin/evergreen-content-poster/reviews/?rate=3"><span class="dashicons dashicons-star-empty"></span></a>
                                    <a class="ecp-rating-link" target="_blank" data-ecp-rating-value="2" href="https://wordpress.org/support/plugin/evergreen-content-poster/reviews/?rate=2"><span class="dashicons dashicons-star-empty"></span></a>
                                    <a class="ecp-rating-link" target="_blank" data-ecp-rating-value="1" href="https://wordpress.org/support/plugin/evergreen-content-poster/reviews/?rate=1"><span class="dashicons dashicons-star-empty"></span></a>
                                </div>
                                <p><?php _e('Would you mind giving us an honest review in the WordPress listings? It would mean the world to us.', 'evergreen-content-poster'); ?></p>
                            </div>
                            <div id="ecp-support-cta">
                                <p><?php _e('We\'re sorry you\'re not having a great experience. How can we help you fix that?', 'evergreen-content-poster'); ?></p>
                                <p><?php _e('You can email us or, even better, send us a support request so we can address your needs as quickly and effectively as possible.', 'evergreen-content-poster'); ?></p>
                                <p><a target="_blank" class="ecp-component-cta ecp-link-nojs" href="https://usergrowth.io/contact/?utm_source=plugin%20feedback&utm_medium=software&utm_campaign=Evergreen%20Content%20Poster"><?php _e('Contact Support', 'evergreen-content-poster'); ?></a></p>
                                <p><?php _e('If you still want to rate our plugin right now, you can do that by clicking here:', 'evergreen-content-poster'); ?> <a href="#" class="ecp-link-nojs" target="_blank" id="ecp-review-link"><?php _e('leave a review', 'evergreen-content-poster'); ?></a></p>
                                <p><span class="ecp-close-modal"><?php _e('Nevermind, close this box', 'evergreen-content-poster'); ?></span></p>
                            </div>
                            <script>
                                if (typeof jQuery != 'function') {
                                    console.log('Evergreen Content Poster requires jQuery. Please ensure that your theme does not restrict access to everyone\'s favorite JS library.');
                                } else {
                                    jQuery(document).ready(function() {
                                        var originalContent = jQuery('#ecp-love').html();
                                        updateListeners();

                                        function replace(el, html) {
                                            el.slideToggle(300, function() {
                                                el.html(html);
                                                updateListeners();
                                                el.slideToggle('slow');
                                            });
                                        }

                                        /**
                                         * Content is moved into different parent containers,
                                         * so update to fit new selectors.
                                         *
                                         */
                                        function updateListeners() {
                                            jQuery('#ecp-love .ecp-rating-link').on('click', function(e) {
                                                var value = parseInt(jQuery(this).data('ecp-rating-value'), 10);
                                                if (isNaN(value) || value > 3) return;

                                                e.preventDefault();

                                                var href = jQuery(this).attr('href');
                                                jQuery('#ecp-support-cta #ecp-review-link').attr('href', href);

                                                replace(jQuery('#ecp-love'), jQuery('#ecp-support-cta').html());
                                            });


                                            jQuery('.ecp-close-modal').on('click', function() {
                                                replace(jQuery('#ecp-love'), originalContent);
                                            });
                                        }
                                    });
                                }
                            </script>
                            <div id="ecp-idea" class="ecp-component dark-text text-center">
                                <div class="ecp-component-icon">
                                    <span class="dashicons dashicons-lightbulb"></span>
                                </div> <p class="ecp-component-title"><?php _e('Have an idea?', 'evergreen-content-poster'); ?></p>
                                <p><?php _e('Are you missing a feature? Do you know a way to make the plugin even better?', 'evergreen-content-poster'); ?></p>
                                <p><?php _e('Leave a comment and upvote features on our public roadmap', 'evergreen-content-poster'); ?></p>
                                <a href="https://trello.com/b/QUUOK2NB/evergreen-content-poster-public-roadmap" class="button ecp-navy-button" target="_blank" style="float:none;"><?php _e('Share your idea', 'evergreen-content-poster'); ?></a>
                            </div>

                            <div id="ecp-help" class="ecp-component dark-text text-center">
                                <div class="ecp-component-icon">
                                    <span class="dashicons dashicons-sos"></span>
                                </div>
                                <p class="ecp-component-title"><?php _e('Need Help?', 'evergreen-content-poster'); ?></p>
                                <p><?php _e('Something not working correctly and want to contact support?', 'evergreen-content-poster'); ?></p>
                                <p><?php _e('Copy your System Status by clicking the button below and include this in an email to support@evergreencontentposter.io', 'evergreen-content-poster'); ?></p>
                                <p><?php _e('Optionally you can also include a log of the messages you successfully or unsuccessfully shared.', 'evergreen-content-poster'); ?></p>
                                <button class="ecp-component-cta ecp-system-status"><?php _e('Get system status', 'evergreen-content-poster'); ?></button>
                                <button class="ecp-component-cta ecp-status-logfile"><?php _e('Get sharing logfile', 'evergreen-content-poster'); ?></button>
                            </div>
                        </div><!-- end ecp-admin-sidebar ecp-col-220 -->
                        <?php
                        $debug_bar = new Evergreen_Content_Poster();
                        $debugHTML = $debug_bar->ecp_do_admin_sidebar();

                        echo $debugHTML;
                        ?>
                    </div>

                </div><!-- end ecp-section -->

            </div><!-- end ecp-container -->
            <div id="ex1" class="modal all-modal">
                <p style="border-bottom: 1px solid #a4a4a4; padding: 20px 0"><?php echo sprintf(__('Do you really want to delete the category %s and move all posts to the default category?', 'evergreen-content-poster'), '<span class="modal-category-name"></span>') ?></p>
                <div class="alert alert-warning">
                    <p><?php _e('Deleting a category and moving the posts will trigger the following changes:', 'evergreen-content-poster'); ?></p>
                    <ul>
                        <li><?php _e('Any schedule related to this category will be removed.', 'evergreen-content-poster'); ?></li>
                        <li><?php _e('All posts that are in this category will be <strong>moved to the default category</strong>.', 'evergreen-content-poster'); ?></li>
                    </ul>
                    <p><?php _e('Are you sure you want to remove this category?', 'evergreen-content-poster'); ?></p>
                </div>
                <a href="#" style="padding: 10px 30px" class="button ecp-navy-button ecp-move-posts-to-default jquery-modal-close"><?php _e('Ok', 'evergreen-content-poster') ?></a>
                <a href="#" style="color:#000; text-decoration:none;margin-right:20px;padding: 10px 30px;border: 1px solid #1b3a51;float: right" class="ecp-button jquery-modal-close"><?php _e('Cancel', 'evergreen-content-poster') ?></a>
            </div>

            <div id="delete-modal" class="modal all-modal">
                <p style="border-bottom: 1px solid #a4a4a4; padding: 20px 0"><?php echo sprintf(__("Do you really want to delete the category %s and delete all it's posts?", 'evergreen-content-poster'), '<span class="modal-category-name"></span>') ?></p>
                <div class="alert alert-warning">
                    <p><?php _e('Deleting a category and deleting the posts will trigger the following changes:', 'evergreen-content-poster'); ?></p>
                    <ul>
                        <li><?php _e('Any schedule related to this category will be removed.', 'evergreen-content-poster'); ?></li>
                        <li><strong><?php _e('All posts that are in this category will be deleted', 'evergreen-content-poster'); ?></strong></li>
                    </ul>
                    <p><?php _e('Are you sure you want to remove this category?', 'evergreen-content-poster'); ?></p>
                </div>
                <a href="#" style="padding: 10px 30px;" class="button ecp-navy-button ecp-delete-category jquery-modal-close"><?php _e('Ok', 'evergreen-content-poster') ?></a>
                <a href="#" style="color:#000; text-decoration:none;margin-right:20px;padding: 10px 30px;border: 1px solid #1b3a51;float: right" class="ecp-button jquery-modal-close"><?php _e('Cancel', 'evergreen-content-poster') ?></a>
            </div>
        </div><!-- end .ecp-wrapper -->
        <?php
    }

}