<?php

/**
 * The settings page functionalities of the plugin.
 *
 * @link       https://usergrowth.io/
 * @since      1.0.0
 * @package    Evergreen_Content_Poster
 * @subpackage Evergreen_Content_Poster/Settings
 * @author     usergrowth <info@usergrowth.io>
 */

class Evergreen_Content_Poster_Settings
{

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;

    private $buffer;
    private $common;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     */
    public function __construct(Evergreen_Content_Poster_Buffer $buffer, Evergreen_Content_Poster_Common $common)
    {
        $this->buffer = $buffer;
        $this->common = $common;

        $this->load_settings();

        add_action('wp_ajax_ajaxInsertData', [$this, 'ajaxInsertData']);
        add_action('wp_ajax_ajaxDeleteData', [$this, 'ajaxDeleteData']);
        add_action('wp_ajax_ajaxClearData', [$this, 'ajaxClearData']);
        add_action('wp_ajax_ajaxPostBufferData', [$this, 'ajaxPostBufferData']);
        add_action('wp_ajax_updateDismissConfig', [$this, 'updateDismissConfig']);
        add_action('wp_ajax_updateDismissCronConfig', [$this, 'updateDismissCronConfig']);
        add_action('wp_ajax_genScheduleByFrequency', [$this, 'genScheduleByFrequency']);
    }

    public function checkStatusCategory($category_id)
    {
        global $wpdb;

        if ($category_id > 0) {
            $category = $wpdb->get_row("SELECT status FROM {$wpdb->prefix}evergreen_categories WHERE id = {$category_id}");

            return $category->status;
        } else {
            return true;
        }

    }

    public function updateDismissConfig(): void
    {
        $user_id = get_current_user_id();
        add_user_meta($user_id, 'ecp-getting-started-dismissed', 'true', true);

        wp_send_json_success(array(
            'error' => 200,
            'message' => 'Ok'
        ));

    }

    public function updateDismissCronConfig(): void
    {
        $user_id = get_current_user_id();
        add_user_meta($user_id, 'ecp-wp-cron-notice-dismissed', 'true', true);

        wp_send_json_success(array(
            'error' => 200,
            'message' => 'Ok'
        ));

    }

    /**
     *
     * create schedule according to selected frequency
     * @since    1.2.0
     */
    public function genScheduleByFrequency(): void
    {
        global $wpdb, $statistics;

        $allCategories = $wpdb->get_results('SELECT * FROM wp_evergreen_categories');
        $allCategoriesName = array();
        foreach ($allCategories as $category) {
            $allCategoriesName[$category->id] = $category->name;
        }

        // Get the active category list
        $categories = $wpdb->get_results('SELECT * FROM wp_evergreen_categories WHERE status = 1');

        $categoryIds = array();

        foreach ($categories as $category) {
            $categoryIds[] = $category->id;
        }

        $frequency = sanitize_text_field($_POST['frequency']);

        $ecp_options = get_option('ecp_options');

        $pre_frequency = $ecp_options['ecp_frequency'] ?? '';

        // Get list network connecting
        $profiles = $this->buffer->profiles();

        $categoriesId = array();

        foreach ($allCategories as $category) {
            $categoriesId[] = $category->id;
        }

        if (count($categoriesId) > 1) {
            $categoriesId[] = 0;
        }

        $schedules_setting = $this->buffer_schedules;
        $schedules = $schedules_setting['schedules'];

        foreach ($schedules as $service => $schedule) {
            foreach ($schedule as $id => $item) {
                foreach ($item as $std) {
                    if (isset($std->times) && !empty($std->times)) {
                        $std->times = array();
                    }
                }
            }
        }

        //Check db
        $ecp_frequency_schedules = get_option('ecp_frequency_schedules');

        if ($frequency == 'seldom') {
            $ecp_options['ecp_frequency'] = 'seldom';
            update_option('ecp_options', $ecp_options);
            if (isset($ecp_frequency_schedules['seldom']) && !empty($ecp_frequency_schedules['seldom'])) {
                $schedules_setting['schedules'] = $ecp_frequency_schedules['seldom'];
            } else {
                $ecp_frequency_schedules['seldom'] = array();

                foreach ($schedules as $id => $network) {
                    foreach ($network as $schedule_profile) {
                        $categoryIdsGented = $categoriesId;
                        foreach ($schedule_profile as $k => $schedule) {
                            $temp = array();
                            if ($k == 0) {
                                $temp['time_push'] = $this->random_time();
                                if (count($categoriesId) > 1 || count($categoriesId) == 0) {
                                    $temp['category_id'] = 0;
                                    $key = array_search(0, $categoryIdsGented);
                                    unset($categoryIdsGented[$key]);
                                } else {
                                    $temp['category_id'] = $categoriesId[0];
                                }

                                $schedule->times[] = $temp;
                            } elseif ($k == 1) {
                                $temp['time_push'] = $this->random_time();
                                if (count($categoriesId) == 0) {
                                    $temp['category_id'] = 0;
                                } else {
                                    if (in_array(1, $categoryIdsGented)) {
                                        $temp['category_id'] = 1;
                                        $key = array_search(1, $categoryIdsGented);
                                        unset($categoryIdsGented[$key]);
                                    } else {
                                        if (in_array(2, $categoryIdsGented)) {
                                            $temp['category_id'] = 2;
                                            $key = array_search(2, $categoryIdsGented);
                                            unset($categoryIdsGented[$key]);
                                        } else {
                                            if (count($categoryIdsGented) == 0) {
                                                $categoryIdsGented = $categoriesId;
                                            }
                                            $a = array_rand($categoryIdsGented, 1);
                                            $temp['category_id'] = $categoryIdsGented[$a];
                                            unset($categoryIdsGented[$a]);
                                        }
                                    }

                                }

                                $schedule->times[] = $temp;
                            } elseif ($k == 3) {
                                $temp['time_push'] = $this->random_time();
                                if (count($categoriesId) == 0) {
                                    $temp['category_id'] = 0;
                                } else {
                                    if (in_array(1, $categoryIdsGented)) {
                                        $temp['category_id'] = 1;
                                        $key = array_search(1, $categoryIdsGented);
                                        unset($categoryIdsGented[$key]);
                                    } else {
                                        if (in_array(2, $categoryIdsGented)) {
                                            $temp['category_id'] = 2;
                                            $key = array_search(2, $categoryIdsGented);
                                            unset($categoryIdsGented[$key]);
                                        } else {
                                            if (count($categoryIdsGented) == 0) {
                                                $categoryIdsGented = $categoriesId;
                                            }
                                            $a = array_rand($categoryIdsGented, 1);
                                            $temp['category_id'] = $categoryIdsGented[$a];
                                            unset($categoryIdsGented[$a]);
                                        }
                                    }

                                }

                                $schedule->times[] = $temp;
                            } elseif ($k == 5) {
                                $temp['time_push'] = $this->random_time();
                                if (count($categoriesId) == 0) {
                                    $temp['category_id'] = 0;
                                } else {
                                    if (count($categoryIdsGented) == 0) {
                                        $categoryIdsGented = $categoriesId;
                                    }
                                    $a = array_rand($categoryIdsGented, 1);
                                    $temp['category_id'] = $categoryIdsGented[$a];
                                    unset($categoryIdsGented[$a]);

                                }

                                $schedule->times[] = $temp;
                            } else {
                                if ($id == 'twitter') {
                                    $temp['time_push'] = $this->random_time();
                                    if (count($categoryIdsGented) == 0) {
                                        $categoryIdsGented = $categoriesId;
                                    }
                                    $a = array_rand($categoryIdsGented, 1);
                                    $temp['category_id'] = $categoryIdsGented[$a];
                                    unset($categoryIdsGented[$a]);
                                    $schedule->times[] = $temp;
                                }
                            }
                        }
                    }
                }

                $schedules_setting['schedules'] = $schedules;
                $ecp_frequency_schedules['seldom'] = $schedules;
                update_option('ecp_frequency_schedules', $ecp_frequency_schedules);
            }

            update_option('ecp_schedule_settings', $schedules_setting, 'yes');
        } elseif ($frequency == 'regularly') {
            $ecp_options['ecp_frequency'] = 'regularly';
            update_option('ecp_options', $ecp_options);

            if (isset($ecp_frequency_schedules['regularly']) && !empty($ecp_frequency_schedules['regularly'])) {
                $schedules_setting['schedules'] = $ecp_frequency_schedules['regularly'];
            } else {
                $ecp_frequency_schedules['regularly'] = array();

                foreach ($schedules as $id => $network) {
                    foreach ($network as $schedule_profile) {
                        $categoryIdsGented = $categoriesId;
                        if ($id != 'twitter') {
                            foreach ($schedule_profile as $k => $schedule) {
                                $temp = array();
                                $temp['time_push'] = $this->random_time();
                                if (count($categoriesId) == 0) {
                                    $temp['category_id'] = 0;
                                } else {
                                    if (count($categoryIdsGented) == 0) {
                                        $categoryIdsGented = $categoriesId;
                                    }
                                    $a = array_rand($categoryIdsGented, 1);
                                    $temp['category_id'] = $categoryIdsGented[$a];
                                    unset($categoryIdsGented[$a]);

                                }

                                $schedule->times[] = $temp;
                            }
                        } else {
                            for ($i = 0; $i < 3; $i++) {
                                foreach ($schedule_profile as $k => $schedule) {
                                    $temp = array();
                                    $temp['time_push'] = $this->random_time();
                                    if (count($categoriesId) == 0) {
                                        $temp['category_id'] = 0;
                                    } else {
                                        if (count($categoryIdsGented) == 0) {
                                            $categoryIdsGented = $categoriesId;
                                        }
                                        $a = array_rand($categoryIdsGented, 1);
                                        $temp['category_id'] = $categoryIdsGented[$a];
                                        unset($categoryIdsGented[$a]);

                                    }

                                    $schedule->times[] = $temp;
                                }
                            }
                        }
                    }
                }

                $schedules_setting['schedules'] = $schedules;
                $ecp_frequency_schedules['regularly'] = $schedules;
                update_option('ecp_frequency_schedules', $ecp_frequency_schedules);
            }

            update_option('ecp_schedule_settings', $schedules_setting, 'yes');
        } elseif ($frequency == 'often') {
            $ecp_options['ecp_frequency'] = 'often';
            update_option('ecp_options', $ecp_options);

            if (isset($ecp_frequency_schedules['often']) && !empty($ecp_frequency_schedules['often'])) {
                $schedules_setting['schedules'] = $ecp_frequency_schedules['often'];
            } else {
                $ecp_frequency_schedules['often'] = array();

                foreach ($schedules as $id => $network) {
                    foreach ($network as $schedule_profile) {
                        $categoryIdsGented = $categoriesId;
                        if ($id != 'twitter') {
                            $time_prev = null;
                            foreach ($schedule_profile as $k => $schedule) {
                                for ($i = 0; $i < 2; $i++) {
                                    $temp = array();
                                    if ($i == 0) {
                                        $temp['time_push'] = $this->random_time(null, 7, 10);
                                        $time_prev = $temp['time_push'];
                                    } else {
                                        $temp['time_push'] = $this->random_time($time_prev);
                                    }
                                    if (count($categoriesId) == 0) {
                                        $temp['category_id'] = 0;
                                    } else {
                                        if (count($categoryIdsGented) == 0) {
                                            $categoryIdsGented = $categoriesId;
                                        }
                                        $a = array_rand($categoryIdsGented, 1);
                                        $temp['category_id'] = $categoryIdsGented[$a];
                                        unset($categoryIdsGented[$a]);

                                    }

                                    if (isset($schedule->times)) {
                                        $schedule->times[] = $temp;
                                    }

                                }
                            }
                        } else {
                            for ($i = 0; $i < 6; $i++) {
                                foreach ($schedule_profile as $k => $schedule) {
                                    $temp = array();
                                    $temp['time_push'] = $this->random_time();
                                    if (count($categoriesId) == 0) {
                                        $temp['category_id'] = 0;
                                    } else {
                                        if (count($categoryIdsGented) == 0) {
                                            $categoryIdsGented = $categoriesId;
                                        }
                                        $a = array_rand($categoryIdsGented, 1);
                                        $temp['category_id'] = $categoryIdsGented[$a];
                                        unset($categoryIdsGented[$a]);

                                    }

                                    $schedule->times[] = $temp;
                                }
                            }
                        }
                    }
                }

                $schedules_setting['schedules'] = $schedules;
                $ecp_frequency_schedules['often'] = $schedules;
                update_option('ecp_frequency_schedules', $ecp_frequency_schedules);
            }

            update_option('ecp_schedule_settings', $schedules_setting, 'yes');
        } else {
            $ecp_options['ecp_frequency'] = 'custom';
            update_option('ecp_options', $ecp_options);

            if (isset($ecp_frequency_schedules['custom']) && !empty($ecp_frequency_schedules['custom'])) {
                $schedules_setting['schedules'] = $ecp_frequency_schedules['custom'];
            } else {
                if (isset($_POST['use_pre_schedule']) && $_POST['use_pre_schedule']) {
                    $schedules_setting['schedules'] = isset($ecp_frequency_schedules[$pre_frequency]) && !empty($ecp_frequency_schedules[$pre_frequency]) ? $ecp_frequency_schedules[$pre_frequency] : $schedules;
                } else {
                    $schedules_setting['schedules'] = $schedules;
                }
                $ecp_frequency_schedules['custom'] = $schedules_setting['schedules'];
                update_option('ecp_frequency_schedules', $ecp_frequency_schedules);
            }

            update_option('ecp_schedule_settings', $schedules_setting, 'yes');
        }

        $scheduleDefineLast = $this->getScheduleDefine($schedules_setting['schedules'], $profiles);

        if (isset($_POST['service']) && $_POST['service'] && isset($_POST['id']) && $_POST['id']) {
            $selected_schedules = $schedules_setting['schedules'][$_POST['service']][$_POST['id']];

            foreach ($profiles as $service => $list_profile) {
                if ($service == sanitize_text_field($_POST['service'])) {
                    foreach ($list_profile as $profile) {
                        if ($profile->id == $_POST['id']) {
                            $selected_profile_ajax = $profile;
                        }
                    }
                }
            }

            ob_start();
            $is_empty_schedule = true;

            foreach ($selected_schedules as $schedule) {
                if (!empty($schedule->times)) {
                    $is_empty_schedule = false;
                }
            }
            ?>
            <div class="ecp-col-940 ecp-option-container ecp-field-setting no_schedule">
                <?php if (!$is_empty_schedule) : ?>
                    <?php foreach ($selected_schedules as $ds_key => $daily_schedule) : ?>
                        <div class="ecp-grid ecp-col-130" style="margin-right: 0.9%">
                            <?php
                            $times = [];
                            foreach ($daily_schedule->times as $time) {
                                if (strlen($time['time_push']) == 4) {
                                    $time['time_push'] = '0' . $time['time_push'];
                                }
                                $times[] = $time;
                            }
                            $daily_schedule->times = $times;
                            sort($daily_schedule->times);

                            foreach ($daily_schedule->times as $key => $value) : ?>
                                <a href="#delete-schedule" class="show-modal-delete" rel="modal:open"
                                   data-day="<?= $daily_schedule->days[0] ?>"
                                   data-id="<?php echo $selected_profile_ajax->_id ?>"
                                   data-service="<?= $selected_profile_ajax->service ?>"
                                   data-value="<?= $value['time_push'] ?>" data-key="<?= $key ?>" data-general="0">
                                    <div class="ecp-grid ecp-col-940 scheduled-item">
                                        <div class="ecp-connected-profile-avatar">
                                            <img class="ecp-profile-circle"
                                                 ng-src="<?php echo $selected_profile_ajax->avatar; ?>"
                                                 img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png"
                                                 src="<?php echo $selected_profile_ajax->avatar; ?>">
                                            <div class="ecp-social-network-icon ecp-<?php echo strtolower($selected_profile_ajax->service); ?>"></div>
                                        </div>
                                        <div class="ecp-text">
                                            <span class="schedule_field schedule_time"><?php _e($value['time_push'], 'evergreen-content-poster'); ?></span><br/>
                                            <span class="schedule_field schedule_category"><?php echo $value['category_id'] ? $allCategoriesName[$value['category_id']] : _e('Random category', 'evergreen content poster') ?></span>
                                            <input type="hidden"
                                                   name="scheduled_daytime[<?php echo $selected_profile_ajax->id; ?>][<?php echo $ds_key; ?>][]"
                                                   value="<?php echo $value['time_push']; ?>"/>
                                            <p class="ecp-remove-schedule hidden"><span
                                                        class="dashicons dashicons-no"></span></p>
                                        </div>

                                        <?php if (!in_array($value['category_id'], $categoryIds) && $value['category_id'] != 0): ?>
                                            <div class="ecp-overlay"><span
                                                        class="dashicons dashicons-controls-pause"></span></div>
                                        <?php endif; ?>
                                    </div>
                                </a>
                            <?php endforeach; ?>
                        </div>
                    <?php endforeach; ?>

                <?php else : ?>
                    <div class="ecp-grid ecp-col-940">
                        <span class="">
                        	<img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-schedule.svg"
                                 width="180" height="124" style="display: block; margin: 3em auto;">
							<p style="text-align: center;"><?php _e('There is no schedule at the moment, please use the form above to create your schedule.', 'evergreen-content-poster'); ?></p>
						</span>
                    </div>
                <?php endif; ?>
            </div>
            <?php
        } else {
            $scheduleDefineLast = $this->getScheduleDefine($schedules_setting['schedules'], $profiles);
            ob_start();
            ?>
            <div class="ecp-col-940 ecp-option-container ecp-field-setting no_schedule">
                <?php
                $is_empty_schedule = true;

                foreach ($scheduleDefineLast as $schedule) {
                    if (!empty($schedule->times)) {
                        $is_empty_schedule = false;
                    }
                }

                ?>
                <?php if (!$is_empty_schedule) : ?>
                    <?php foreach ($scheduleDefineLast as $ds_key => $daily_schedule) : ?>
                        <div class="ecp-grid ecp-col-130" style="margin-right: 0.9%">
                            <?php
                            foreach ($daily_schedule->times as $key => $value) : ?>
                                <a href="#delete-schedule" class="show-modal-delete" rel="modal:open"
                                   data-day="<?= $daily_schedule->days[0] ?>" data-id="<?php echo $value['_id'] ?>"
                                   data-service="<?= $value['service'] ?>" data-value="<?= $value['time'] ?>"
                                   data-key="<?= $value['key'] ?>" data-general="1">
                                    <div class="ecp-grid ecp-col-940 scheduled-item">
                                        <div class="ecp-connected-profile-avatar">
                                            <img class="ecp-profile-circle" ng-src="<?php echo $value['avatar']; ?>"
                                                 img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png"
                                                 src="<?php echo $value['avatar']; ?>">
                                            <div class="ecp-social-network-icon ecp-<?php echo strtolower($value['service']); ?>"></div>
                                        </div>
                                        <div class="ecp-text">
                                            <span class="schedule_field schedule_time"><?php _e($value['time'], 'evergreen-content-poster'); ?></span><br/>
                                            <span class="schedule_field schedule_category"><?php echo $value['category_id'] ? $allCategoriesName[$value['category_id']] : _e('Random category', 'evergreen content poster') ?></span>
                                            <input type="hidden"
                                                   name="scheduled_daytime[<?php echo $value['_id']; ?>][<?php echo $ds_key; ?>][]"
                                                   value="<?php echo $value['time']; ?>"/>
                                            <p class="ecp-remove-schedule hidden"><span
                                                        class="dashicons dashicons-no"></span></p>
                                        </div>

                                        <?php if (!in_array($value['category_id'], $categoryIds) && $value['category_id'] != 0): ?>
                                            <div class="ecp-overlay"><span
                                                        class="dashicons dashicons-controls-pause"></span></div>
                                        <?php endif; ?>
                                    </div>
                                </a>
                            <?php endforeach; ?>
                        </div>
                    <?php endforeach; ?>

                <?php else : ?>
                    <div class="ecp-grid ecp-col-940">
                        <span class="">
                        	<img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-schedule.svg"
                                 width="180" height="124" style="display: block; margin: 3em auto;">
							<p style="text-align: center;"><?php _e('There is no schedule at the moment, please use the form above to create your schedule.', 'evergreen-content-poster'); ?></p>
						</span>
                    </div>
                <?php endif; ?>
            </div>
            <?php
        }

        if (count($allCategories) > 1) {
            // Get scheduleDefine
            // $scheduleDefineLast = $this->getScheduleDefine($schedules, $profiles);
            // Get statistics
            $statistics = $this->get_statistics($allCategories, $scheduleDefineLast, $profiles);
            $totalNum = $this->getTotalStatistics($statistics['total']);
            if ($totalNum > 0) {
                include('partials/evergreen_content_statistics.php');
            }
        }

        $content = ob_get_clean();
        wp_send_json_success($content);

    }

    public function random_time($prev_time = null, $minHour = null, $maxHour = null)
    {
        $min_hour = $minHour ? $minHour : 7;
        $max_hour = $maxHour ? $maxHour : 18;
        $min_minute = 0;
        $max_minute = 59;

        if ($prev_time) {
            $prev_arr = explode(':', $prev_time);
            if ($prev_arr[0] <= 10) {
                $hour = $prev_arr[0] + 7;
            } else {
                $hour = $prev_time - 7;
                $hour = $hour < 7 ? 7 : $hour;
            }

            $minute = rand($min_minute, $max_minute);
            $minute = $minute < 10 ? '0' . $minute : $minute;

            return $hour . ':' . $minute;
        } else {

            $hour = rand($min_hour, $max_hour);
            $hour = $hour < 10 ? '0' . $hour : $hour;

            $minute = rand($min_minute, $max_minute);
            $minute = $minute < 10 ? '0' . $minute : $minute;

            return $hour . ':' . $minute;
        }
    }

    /**
     * Check exist post in category
     *
     * @param $category_id
     * @return bool
     */
    public function checkExistPostInCategory($category_id)
    {
        global $wpdb;
        $ecp_saved_posts = $wpdb->get_results("SELECT * FROM wp_posts WHERE post_type = 'ecp-posts'");

        foreach ($ecp_saved_posts as $ecp_saved_post) {
            $postmeta = get_post_meta($ecp_saved_post->ID);
            if ($category_id == $postmeta['ecp-post-category'][0]) {
                return true;
            }
        }

        return false;
    }

    /**
     * Get random category id
     *
     * @param $categoryIds
     * @return bool|mixed
     */
    public function getRandomCategoryId($categoryIds)
    {
        $number = count($categoryIds);
        $i = 0;
        do {
            $i++;
            $key_random = array_rand($categoryIds);
            $random_category_id = $categoryIds[$key_random];

            if ($this->checkExistPostInCategory($random_category_id)) {
                return $random_category_id;
            } else {
                unset($categoryIds[$key_random]);
            }

        } while ($i < $number);

        return 0;
    }

    /**
     * Post to buffer
     *
     * @since    1.0.0
     */
    public function ajaxPostBufferData($profile_id_daily = null)
    {
        global $wpdb;

        $profiles = $this->buffer->profiles();
        // Check which tab active
        $setting = $this->common->general_settings();

        $ecp_saved_posts = $wpdb->get_results("SELECT * FROM wp_posts WHERE post_type = 'ecp-posts'");

        $categoriesIsRandomIds = array();
        $allCategoriesIsRandom = $wpdb->get_results("SELECT id FROM {$wpdb->prefix}evergreen_categories WHERE status = 1 AND random_availability = 1");
        if (count($allCategoriesIsRandom) > 0) {
            foreach ($allCategoriesIsRandom as $item) {
                $categoriesIsRandomIds[] = $item->id;
            }
        }

        $today_now = date('Y-m-d H:i:s');
        if (count($ecp_saved_posts) > 0) {
            $time_zone = $setting['eg_timezone'];
            if (strpos($time_zone, 'UTC') !== false) {
                $time_zone = str_replace('UTC', '', $time_zone);
                $minute = $time_zone * 60;
                $today_now = date('Y-m-d H:i:s', strtotime($minute . ' minutes', strtotime(date('Y-m-d H:i:s'))));
                $date = date('Y-m-d', strtotime($minute . ' minutes', strtotime(date('Y-m-d H:i:s'))));
                $time = date('H:i', strtotime($minute . ' minutes', strtotime(date('Y-m-d H:i:s'))));
            } else {
                $today = new DateTime('now', new DateTimeZone($time_zone));
                $today_now = $today->format('Y-m-d H:i:s');
                $date = $today->format('Y-m-d');
                $time = $today->format('H:i');
            }

            $ecp_posting_schedule = '';
            $profile_ids = array();
            if ($setting['ecp_posting_schedule'] == 'timestamp') {
                $date_last_timestamp = get_option('ecp_date_last_timestamp');
                if (isset($date_last_timestamp) && !is_null($date_last_timestamp)) {
                    // update the timestamp
                    update_option('ecp_date_last_timestamp', $today_now);
                } else {
                    // add new
                    add_option('ecp_date_last_timestamp', $today_now);
                }


                $date_last_active = get_option('ecp_date_last_active');
                $ecp_posting_schedule = 'timestamp';
                // get list schedule
                $schedule_settings = $this->common->schedules();
                $schedules = $schedule_settings['schedules'];

                $day = date('D', strtotime($date));
                $day = strtolower($day);
                // Check at present any schedules that are eligible to post
                foreach ($schedules as $service => $schedule) {
                    foreach ($schedule as $profile_id => $single_schedule) {
                        foreach ($single_schedule as $std) {
                            if ($std->days[0] == $day) {
                                foreach ($std->times as $time_temp) {
                                    if (isset($date_last_timestamp) && !is_null($date_last_timestamp)) {
                                        $day_last = date('Y-m-d', strtotime($date_last_timestamp));
                                        $time_last = date('H:i', strtotime($date_last_timestamp));

                                        if ($day_last == $date) {
                                            if ($time_temp['time_push'] > $time_last && $time_temp['time_push'] <= $time) {
                                                // check category is active
                                                if ($this->checkStatusCategory($time_temp['category_id'])) {
                                                    $row['profile_id'] = $profile_id;
                                                    if ($time_temp['category_id'] > 0) {
                                                        $row['category_id'] = $time_temp['category_id'];
                                                    } else {
                                                        $row['category_id'] = $this->getRandomCategoryId($categoriesIsRandomIds);
                                                    }
                                                    $profile_ids[] = $row;
                                                }
                                            }
                                        } else {
                                            if ($time_temp['time_push'] <= $time) {
                                                if ($this->checkStatusCategory($time_temp['category_id'])) {
                                                    $row['profile_id'] = $profile_id;
                                                    if ($time_temp['category_id'] > 0) {
                                                        $row['category_id'] = $time_temp['category_id'];
                                                    } else {
                                                        $row['category_id'] = $this->getRandomCategoryId($categoriesIsRandomIds);
                                                    }
                                                    $profile_ids[] = $row;
                                                }
                                            }
                                        }
                                    } else {
                                        if (isset($date_last_active) && !is_null($date_last_active)) {
                                            $day_active = date('Y-m-d', strtotime($date_last_active));
                                            $time_active = date('H:i', strtotime($date_last_active));

                                            if ($day_active == $date) {
                                                if ($time_temp['time_push'] <= $time && $time_temp['time_push'] >= $time_active) {
                                                    if ($this->checkStatusCategory($time_temp['category_id'])) {
                                                        $row['profile_id'] = $profile_id;
                                                        if ($time_temp['category_id'] > 0) {
                                                            $row['category_id'] = $time_temp['category_id'];
                                                        } else {
                                                            $row['category_id'] = $this->getRandomCategoryId($categoriesIsRandomIds);
                                                        }
                                                        $profile_ids[] = $row;
                                                    }
                                                }
                                            } else {
                                                if ($time_temp['time_push'] <= $time) {
                                                    if ($this->checkStatusCategory($time_temp['category_id'])) {
                                                        $row['profile_id'] = $profile_id;
                                                        if ($time_temp['category_id'] > 0) {
                                                            $row['category_id'] = $time_temp['category_id'];
                                                        } else {
                                                            $row['category_id'] = $this->getRandomCategoryId($categoriesIsRandomIds);
                                                        }
                                                        $profile_ids[] = $row;
                                                    }
                                                }
                                            }
                                        } else {
                                            if ($time_temp['time_push'] <= $time) {
                                                if ($this->checkStatusCategory($time_temp['category_id'])) {
                                                    $row['profile_id'] = $profile_id;
                                                    if ($time_temp['category_id'] > 0) {
                                                        $row['category_id'] = $time_temp['category_id'];
                                                    } else {
                                                        $row['category_id'] = $this->getRandomCategoryId($categoriesIsRandomIds);
                                                    }
                                                    $profile_ids[] = $row;
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            } elseif ($setting['ecp_posting_schedule'] == 'daily_posts') {
//                $ecp_posting_schedule = 'daily_posts';
                // Check if there was already a post shared today
//                $history_post_daily = $wpdb->get_results("SELECT * FROM wp_evergreen_content_logs WHERE ecp_posting_schedule = 'daily_posts' AND result = 'success' AND DATE(request_sent) = '" . $date . "'");
//
//                if(empty($history_post_daily)) {
//                    foreach ($profiles as $service => $profile) {
//                        foreach ($profile as $single_profile) {
//                            if(isset($setting['post_per_day_' . $single_profile->id]) && $setting['post_per_day_' . $single_profile->id] > 0) {
//                                for($i = 0; $i < $setting['post_per_day_' . $single_profile->id]; $i++) {
//                                    $profile_ids[] = ['profile_id' => $single_profile->id, 'category_id' => null];
//                                }
//                            }
//                        }
//                    }
//                } else {
//                    wp_send_json_success('Unsuccessful, posted to the buffer before, please check again!');
//                }
                if ($profile_id_daily) {
                    $profile_ids[] = ['profile_id' => $profile_id_daily, 'category_id' => null];
                }

            } elseif ($setting['ecp_posting_schedule'] == 'empty_queue') {
                $ecp_posting_schedule = 'empty_queue';
                // Check which profiles are active
                foreach ($profiles as $service => $profile) {
                    foreach ($profile as $single_profile) {
                        if (isset($setting['empty_queue_status_' . $single_profile->id]) && $setting['empty_queue_status_' . $single_profile->id] == 'Y') {
                            $profile_ids[] = ['profile_id' => $single_profile->id, 'category_id' => null];
                        }
                    }
                }

                // Repeats the active profile list, checking if the cache is empty
                if (count($profile_ids) > 0) {
                    foreach ($profile_ids as $k => $profile) {
                        $std = $this->buffer->updates_pending($profile['profile_id']);
                        if (!is_wp_error($std)) {
                            if ((isset($std['total']) && $std['total'] > 0)) {
                                unset($profile_ids[$k]);
                            }
                        } else {
                            unset($profile_ids[$k]);
                        }
                    }
                }
            } else {
                return false;
            }

            $list_param = array();
            if (count($profile_ids) > 0) {
                $selected_post_ids = array();
                foreach ($profile_ids as $profileId) {
                    $params = array();
                    $ecp_saved_post_selected = new stdClass();
                    // Get the article corresponding to the profile
                    if ($setting['eg_postingorder'] == 'random') {
                        $ecp_saved_post_of_profile = array();
                        foreach ($ecp_saved_posts as $ecp_saved_post) {
                            $postmeta = get_post_meta($ecp_saved_post->ID);
                            if (isset($postmeta['ecp-post-profile']) && $postmeta['ecp-post-profile'][0] == $profileId['profile_id'] && (is_null($profileId['category_id']) || $profileId['category_id'] == $postmeta['ecp-post-category'][0])) {
                                $ecp_saved_post_of_profile[] = $ecp_saved_post;
                            }
                        }
                        if (!empty($ecp_saved_post_of_profile)) {
                            do {
                                $rand_post = array_rand($ecp_saved_post_of_profile, 1);
                                // Check min number of day
                                $post_id = $ecp_saved_post_of_profile[$rand_post]->ID;
                                $history_post = $wpdb->get_results('SELECT * FROM wp_evergreen_content_logs WHERE post_id = ' . $post_id . " AND result = 'success' AND DATE_ADD(request_sent, INTERVAL " . $setting['eg_numberofdays'] . ' DAY) > NOW()');

                                if (!empty($history_post)) {
                                    $conti = true;
                                    unset($ecp_saved_post_of_profile[$rand_post]);
                                } else {
                                    $ecp_saved_post_selected = $ecp_saved_post_of_profile[$rand_post];
                                    $conti = false;
                                }
                            } while ($conti && !empty($ecp_saved_post_of_profile));
                        }
                    } else {
                        foreach ($ecp_saved_posts as $ecp_saved_post) {
                            $postmeta = get_post_meta($ecp_saved_post->ID);
                            if (isset($postmeta['ecp-post-profile']) && $postmeta['ecp-post-profile'][0] == $profileId['profile_id'] && (is_null($profileId['category_id']) || ($profileId['category_id'] == $postmeta['ecp-post-category'][0]))) {
                                if (!in_array($ecp_saved_post->ID, $selected_post_ids)) {
                                    $history_post = $wpdb->get_results('SELECT * FROM wp_evergreen_content_logs WHERE post_id = ' . $ecp_saved_post->ID . " AND result = 'success' AND DATE_ADD(request_sent, INTERVAL " . $setting['eg_numberofdays'] . ' DAY) > NOW()');

                                    if (empty($history_post)) {
                                        $ecp_saved_post_selected = $ecp_saved_post;
                                        $selected_post_ids[] = $ecp_saved_post->ID;
                                        break;
                                    }
                                }
                            }
                        }
                    }

                    if (!empty((array) $ecp_saved_post_selected)) {
                        $postmeta_selected = get_post_meta($ecp_saved_post_selected->ID);
                        $profiles = $this->buffer->profiles();
                        foreach ($profiles as $service => $profile) {
                            foreach ($profile as $single_profile) {
                                if ($single_profile->id == $profileId['profile_id']) {
                                    $profile_selected = $single_profile;
                                }
                            }
                        }

                        $params['profile_ids'][] = $profileId['profile_id'];
                        $params['text'] = $ecp_saved_post_selected->post_content;
                        if (isset($postmeta_selected['ecp-post-ref'][0]) && $postmeta_selected['ecp-post-ref'][0] > 0) {
                            if (isset($setting['utm_tags']) && $setting['utm_tags'] == 'Y') {
                                $link = trim(get_permalink($postmeta_selected['ecp-post-ref'][0]), '/') . '?utm_source=' . str_replace(' ', '', $profile_selected->formatted_service) . '&utm_medium=social&utm_campaign=Evergreen%20Content%20Poster';
                            } else {
                                $link = trim(get_permalink($postmeta_selected['ecp-post-ref'][0]), '/');
                            }
                        } else {
                            $link = '';
                        }

                        if (strtolower($profile_selected->service) != 'twitter') {
                            if (isset($postmeta_selected['ecp-post-media'][0]) && $postmeta_selected['ecp-post-media'][0] != '') {
                                $params['media'] = array(
                                    'photo' => $postmeta_selected['ecp-post-media'][0],
                                );
                                $params['text'] = $ecp_saved_post_selected->post_content . ' ' . $link;
                            } else {
                                $params['media'] = array(
                                    'link' => $link,
                                    'picture' => $postmeta_selected['ecp-post-media'][0],
                                    'thumbnail' => $postmeta_selected['ecp-post-media'][0]
                                );
                            }
                        } else {
                            if (isset($postmeta_selected['ecp-post-media'][0]) && $postmeta_selected['ecp-post-media'][0] != '') {
                                $params['media'] = array(
                                    'photo' => $postmeta_selected['ecp-post-media'][0],
                                );
                                $params['text'] = $ecp_saved_post_selected->post_content . ' ' . $link;
                            } else {

                                $params['text'] = $ecp_saved_post_selected->post_content . ' ' . $link;

                            }
                        }
                        $params['top'] = (isset($setting['eg_position']) && $setting['eg_position'] == 'bottom') ? false : true;
                        $status['param'] = $params;
                        $status['post_id'] = $ecp_saved_post_selected->ID;
                        $list_param[] = $status;
                    }
                }
            }
        }

        $log_error = array();
        $log = new Evergreen_Content_Poster_Log();

        if (empty($list_param)) {
            wp_send_json_error('No eligible posts found that can be send to Buffer on from any profile');
        } else {
            if ($setting['ecp_posting_schedule'] == 'timestamp' || $setting['ecp_posting_schedule'] == 'daily_posts') {
                foreach ($list_param as $index => $status) {
                    $status['param']['top'] = true;
                    $profiles = $this->buffer->profiles();
                    foreach ($profiles as $service => $profile) {
                        foreach ($profile as $single_profile) {
                            if ($single_profile->id == $status['param']['profile_ids'][0]) {
                                $profile_selected = $single_profile;
                            }
                        }
                    }

                    // Send request
                    $result = $this->buffer->updates_create($status['param']);

                    // Store result in log array
                    if (is_wp_error($result)) {
                        // Error
                        $errors = true;
                        $row = array(
                            'action' => 'publish',
                            'request_sent' => $today_now,
                            'profile_id' => $status['param']['profile_ids'][0],
                            'profile_name' => $profile_selected->formatted_service . ': ' . $profile_selected->formatted_username,
                            'result' => 'error',
                            'result_message' => $result->get_error_message(),
                            'status_text' => $status['param']['text'],
                            'status_image' => $status['param']['media']['photo'] ?? null,
                            'status_link' => $status['param']['media']['link'] ?? null,
                            'ecp_posting_schedule' => $ecp_posting_schedule
                        );
                        $log_error[] = ($profile_selected->formatted_service . ': ' . $profile_selected->formatted_username . ': ' . $result->get_error_message());
                        $log->add($status['post_id'], $row);
                    } else {
                        // Share request
                        // update API statistics
                        $token = evergreenGetStatisticsToken();
                        // Get data
                        $data['statistics'] = array(
                            'token' => $token,
                            $profile_selected->service . '_' . $profile_selected->service_type . '_name' => $profile_selected->formatted_username,
                            $profile_selected->service . '_' . $profile_selected->service_type . '_posts' => 1
                        );

                        updateApiStatistics($data);

                        $resultShare = $this->buffer->updates_share($result['id']);
                        $row = array(
                            'action' => 'publish',
                            'request_sent' => $today_now,
                            'profile_id' => $result['profile_id'],
                            'profile_name' => $profile_selected->formatted_service . ': ' . $profile_selected->formatted_username,
                            'status_text' => $result['status_text'],
                            'status_created_at' => isset($result['status_created_at']) ? date('Y-m-d H:i:s', $result['status_created_at']) : date('Y-m-d H:i:s'),
                            'status_due_at' => isset($result['status_due_at']) ? date('Y-m-d H:i:s', $result['status_due_at']) : date('Y-m-d H:i:s'),
                            'status_image' => $status['param']['media']['photo'] ?? null,
                            'status_link' => $status['param']['media']['link'] ?? null,
                            'ecp_posting_schedule' => $ecp_posting_schedule
                        );
                        if (is_wp_error($resultShare)) {
                            $row['result'] = 'error';
                            $row['result_message'] = $resultShare->get_error_message();
                            $log->add($status['post_id'], $row);
                            wp_send_json_success([
                                'message' => __($resultShare->get_error_message(), 'evergreen-content-poster'),
                                'error' => 0
                            ]);
                        } else {
                            $row['result'] = 'success';
                            $row['result_message'] = $resultShare['message'];
                            $log->add($status['post_id'], $row);

                            wp_send_json_success([
                                'timestamp' => current_time('timestamp'),
                                'message' => __($resultShare['message'], 'evergreen-content-poster'),
                                'error' => 200
                            ]);
                        }
                        $log->add($status['post_id'], $row);
                    }
                }
            } else {
                foreach ($list_param as $index => $status) {

                    $profiles = $this->buffer->profiles();
                    foreach ($profiles as $service => $profile) {
                        foreach ($profile as $single_profile) {
                            if ($single_profile->id == $status['param']['profile_ids'][0]) {
                                $profile_selected = $single_profile;
                            }
                        }
                    }

                    // Send request
                    $result = $this->buffer->updates_create($status['param']);
                    // Store result in log array
                    if (is_wp_error($result)) {
                        // Error
                        $errors = true;
                        $row = array(
                            'action' => 'publish',
                            'request_sent' => $today_now,
                            'profile_id' => $status['param']['profile_ids'][0],
                            'profile_name' => $profile_selected->formatted_service . ': ' . $profile_selected->formatted_username,
                            'result' => 'error',
                            'result_message' => $result->get_error_message(),
                            'status_text' => $status['param']['text'],
                            'status_image' => $status['param']['media']['photo'] ?? null,
                            'status_link' => $status['param']['media']['link'] ?? null,
                            'ecp_posting_schedule' => $ecp_posting_schedule
                        );
                        $log_error[] = ($profile_selected->formatted_service . ': ' . $profile_selected->formatted_username . ': ' . $result->get_error_message());
                        $log->add($status['post_id'], $row);
                    } else {
                        // OK
                        // update API statistics
                        $token = evergreenGetStatisticsToken();
                        $data['statistics'] = array(
                            'token' => $token,
                            $profile_selected->service . '_' . $profile_selected->service_type . '_name' => $profile_selected->formatted_username,
                            $profile_selected->service . '_' . $profile_selected->service_type . '_posts' => 1
                        );

                        updateApiStatistics($data);
                        $row = array(
                            'action' => 'publish',
                            'request_sent' => $today_now,
                            'profile_id' => $result['profile_id'],
                            'profile_name' => $profile_selected->formatted_service . ': ' . $profile_selected->formatted_username,
                            'result' => 'success',
                            'result_message' => $result['message'],
                            'status_text' => $result['status_text'],
                            'status_created_at' => date('Y-m-d H:i:s', $result['status_created_at']),
                            'status_due_at' => date('Y-m-d H:i:s', $result['due_at']),
                            'status_image' => $status['param']['media']['photo'] ?? null,
                            'status_link' => $status['param']['media']['link'] ?? null,
                            'ecp_posting_schedule' => $ecp_posting_schedule
                        );
                        $log->add($status['post_id'], $row);
                    }
                }
            }

        }

        wp_send_json_success('The buffer was successfully pushed up, please check the log to see the status');
    }

    /**
     * Handling information when adding the schedule
     *
     * @param $options
     * @param $network
     * @param $day
     * @param $hour
     * @param $minute
     * @return mixed
     * @since     1.0.0
     */
    public function addOption($options, $network, $day, $hour, $minute, $category_id)
    {
        $allNetworks = $this->buffer->networks();
        switch ($day) {
            case 'every_day':
                if ($network) {
                    if ($network == 'all_networks') {
                        foreach ($allNetworks as $key => $networkfor) {
                            for ($i = 0; $i < count($options[$networkfor['service']][$key]); $i++) {
                                $options[$networkfor['service']][$key][$i]->times[] = array('time_push' => $hour . ':' . $minute, 'category_id' => $category_id);
                                for ($j = 0; $j < count($options[$networkfor['service']][$key][$i]->times); $j++) {
                                    if (strlen($options[$networkfor['service']][$key][$i]->times[$j]['time_push']) == 4) {
                                        $options[$networkfor['service']][$key][$i]->times[$j]['time_push'] = '0' . $options[$networkfor['service']][$key][$i]->times[$j]['time_push'];
                                    }
                                }
                                sort($options[$networkfor['service']][$key][$i]->times);
                            }
                        }
                    } else {
                        foreach ($allNetworks as $key => $networkfor) {
                            if ($key == $network) {
                                for ($i = 0; $i < count($options[$networkfor['service']][$key]); $i++) {
                                    $options[$networkfor['service']][$key][$i]->times[] = array('time_push' => $hour . ':' . $minute, 'category_id' => $category_id);
                                    for ($j = 0; $j < count($options[$networkfor['service']][$key][$i]->times); $j++) {
                                        if (strlen($options[$networkfor['service']][$key][$i]->times[$j]['time_push']) == 4) {
                                            $options[$networkfor['service']][$key][$i]->times[$j]['time_push'] = '0' . $options[$networkfor['service']][$key][$i]->times[$j]['time_push'];
                                        }
                                    }
                                    sort($options[$networkfor['service']][$key][$i]->times);
                                }
                            }
                        }
                    }
                }
                break;
            case 'weekdays':
                if ($network) {
                    if ($network == 'all_networks') {
                        foreach ($allNetworks as $key => $networkfor) {
                            for ($i = 0; $i < count($options[$networkfor['service']][$key]); $i++) {
                                if ($options[$networkfor['service']][$key][$i]->days[0] != 'sun' && $options[$networkfor['service']][$key][$i]->days[0] != 'sat') {
                                    $options[$networkfor['service']][$key][$i]->times[] = array('time_push' => $hour . ':' . $minute, 'category_id' => $category_id);
                                    for ($j = 0; $j < count($options[$networkfor['service']][$key][$i]->times); $j++) {
                                        if (strlen($options[$networkfor['service']][$key][$i]->times[$j]['time_push']) == 4) {
                                            $options[$networkfor['service']][$key][$i]->times[$j]['time_push'] = '0' . $options[$networkfor['service']][$key][$i]->times[$j]['time_push'];
                                        }
                                    }
                                    sort($options[$networkfor['service']][$key][$i]->times);
                                }
                            }
                        }
                    } else {
                        foreach ($allNetworks as $key => $networkfor) {
                            if ($key == $network) {
                                for ($i = 0; $i < count($options[$networkfor['service']][$key]); $i++) {
                                    if ($options[$networkfor['service']][$key][$i]->days[0] != 'sun' && $options[$networkfor['service']][$key][$i]->days[0] != 'sat') {
                                        $options[$networkfor['service']][$key][$i]->times[] = array('time_push' => $hour . ':' . $minute, 'category_id' => $category_id);
                                        for ($j = 0; $j < count($options[$networkfor['service']][$key][$i]->times); $j++) {
                                            if (strlen($options[$networkfor['service']][$key][$i]->times[$j]['time_push']) == 4) {
                                                $options[$networkfor['service']][$key][$i]->times[$j]['time_push'] = '0' . $options[$networkfor['service']][$key][$i]->times[$j]['time_push'];
                                            }
                                        }
                                        sort($options[$networkfor['service']][$key][$i]->times);
                                    }
                                }
                            }
                        }
                    }
                }
                break;
            case 'weekends':
                if ($network) {
                    if ($network == 'all_networks') {
                        foreach ($allNetworks as $key => $networkfor) {
                            for ($i = 0; $i < count($options[$networkfor['service']][$key]); $i++) {
                                if ($options[$networkfor['service']][$key][$i]->days[0] == 'sun' || $options[$networkfor['service']][$key][$i]->days[0] == 'sat') {
                                    $options[$networkfor['service']][$key][$i]->times[] = array('time_push' => $hour . ':' . $minute, 'category_id' => $category_id);
                                    for ($j = 0; $j < count($options[$networkfor['service']][$key][$i]->times); $j++) {
                                        if (strlen($options[$networkfor['service']][$key][$i]->times[$j]['time_push']) == 4) {
                                            $options[$networkfor['service']][$key][$i]->times[$j]['time_push'] = '0' . $options[$networkfor['service']][$key][$i]->times[$j]['time_push'];
                                        }
                                    }
                                    sort($options[$networkfor['service']][$key][$i]->times);
                                }
                            }
                        }
                    } else {
                        foreach ($allNetworks as $key => $networkfor) {
                            if ($key == $network) {
                                for ($i = 0; $i < count($options[$networkfor['service']][$key]); $i++) {
                                    if ($options[$networkfor['service']][$key][$i]->days[0] == 'sun' || $options[$networkfor['service']][$key][$i]->days[0] == 'sat') {
                                        $options[$networkfor['service']][$key][$i]->times[] = array('time_push' => $hour . ':' . $minute, 'category_id' => $category_id);
                                        for ($j = 0; $j < count($options[$networkfor['service']][$key][$i]->times); $j++) {
                                            if (strlen($options[$networkfor['service']][$key][$i]->times[$j]['time_push']) == 4) {
                                                $options[$networkfor['service']][$key][$i]->times[$j]['time_push'] = '0' . $options[$networkfor['service']][$key][$i]->times[$j]['time_push'];
                                            }
                                        }
                                        sort($options[$networkfor['service']][$key][$i]->times);
                                    }
                                }
                            }
                        }
                    }
                }
                break;

            case '0':
                if ($network) {
                    if ($network == 'all_networks') {
                        foreach ($allNetworks as $key => $networkfor) {
                            for ($i = 0; $i < count($options[$networkfor['service']][$key]); $i++) {
                                if ($options[$networkfor['service']][$key][$i]->days[0] == 'mon') {
                                    $options[$networkfor['service']][$key][$i]->times[] = array('time_push' => $hour . ':' . $minute, 'category_id' => $category_id);
                                    for ($j = 0; $j < count($options[$networkfor['service']][$key][$i]->times); $j++) {
                                        if (strlen($options[$networkfor['service']][$key][$i]->times[$j]['time_push']) == 4) {
                                            $options[$networkfor['service']][$key][$i]->times[$j]['time_push'] = '0' . $options[$networkfor['service']][$key][$i]->times[$j]['time_push'];
                                        }
                                    }
                                    sort($options[$networkfor['service']][$key][$i]->times);
                                }
                            }
                        }
                    } else {
                        foreach ($allNetworks as $key => $networkfor) {
                            if ($key == $network) {
                                for ($i = 0; $i < count($options[$networkfor['service']][$key]); $i++) {
                                    if ($options[$networkfor['service']][$key][$i]->days[0] == 'mon') {
                                        $options[$networkfor['service']][$key][$i]->times[] = array('time_push' => $hour . ':' . $minute, 'category_id' => $category_id);
                                        for ($j = 0; $j < count($options[$networkfor['service']][$key][$i]->times); $j++) {
                                            if (strlen($options[$networkfor['service']][$key][$i]->times[$j]['time_push']) == 4) {
                                                $options[$networkfor['service']][$key][$i]->times[$j]['time_push'] = '0' . $options[$networkfor['service']][$key][$i]->times[$j]['time_push'];
                                            }
                                        }
                                        sort($options[$networkfor['service']][$key][$i]->times);
                                    }
                                }
                            }
                        }
                    }
                }
                break;
            case '1':
                if ($network) {
                    if ($network == 'all_networks') {
                        foreach ($allNetworks as $key => $networkfor) {
                            for ($i = 0; $i < count($options[$networkfor['service']][$key]); $i++) {
                                if ($options[$networkfor['service']][$key][$i]->days[0] == 'tue') {
                                    $options[$networkfor['service']][$key][$i]->times[] = array('time_push' => $hour . ':' . $minute, 'category_id' => $category_id);
                                    for ($j = 0; $j < count($options[$networkfor['service']][$key][$i]->times); $j++) {
                                        if (strlen($options[$networkfor['service']][$key][$i]->times[$j]['time_push']) == 4) {
                                            $options[$networkfor['service']][$key][$i]->times[$j]['time_push'] = '0' . $options[$networkfor['service']][$key][$i]->times[$j]['time_push'];
                                        }
                                    }
                                    sort($options[$networkfor['service']][$key][$i]->times);
                                }
                            }
                        }
                    } else {
                        foreach ($allNetworks as $key => $networkfor) {
                            if ($key == $network) {
                                for ($i = 0; $i < count($options[$networkfor['service']][$key]); $i++) {
                                    if ($options[$networkfor['service']][$key][$i]->days[0] == 'tue') {
                                        $options[$networkfor['service']][$key][$i]->times[] = array('time_push' => $hour . ':' . $minute, 'category_id' => $category_id);
                                        for ($j = 0; $j < count($options[$networkfor['service']][$key][$i]->times); $j++) {
                                            if (strlen($options[$networkfor['service']][$key][$i]->times[$j]['time_push']) == 4) {
                                                $options[$networkfor['service']][$key][$i]->times[$j]['time_push'] = '0' . $options[$networkfor['service']][$key][$i]->times[$j]['time_push'];
                                            }
                                        }
                                        sort($options[$networkfor['service']][$key][$i]->times);
                                    }
                                }
                            }
                        }
                    }
                }
                break;
            case '2':
                if ($network) {
                    if ($network == 'all_networks') {
                        foreach ($allNetworks as $key => $networkfor) {
                            for ($i = 0; $i < count($options[$networkfor['service']][$key]); $i++) {
                                if ($options[$networkfor['service']][$key][$i]->days[0] == 'wed') {
                                    $options[$networkfor['service']][$key][$i]->times[] = array('time_push' => $hour . ':' . $minute, 'category_id' => $category_id);
                                    for ($j = 0; $j < count($options[$networkfor['service']][$key][$i]->times); $j++) {
                                        if (strlen($options[$networkfor['service']][$key][$i]->times[$j]['time_push']) == 4) {
                                            $options[$networkfor['service']][$key][$i]->times[$j]['time_push'] = '0' . $options[$networkfor['service']][$key][$i]->times[$j]['time_push'];
                                        }
                                    }
                                    sort($options[$networkfor['service']][$key][$i]->times);
                                }
                            }
                        }
                    } else {
                        foreach ($allNetworks as $key => $networkfor) {
                            if ($key == $network) {
                                for ($i = 0; $i < count($options[$networkfor['service']][$key]); $i++) {
                                    if ($options[$networkfor['service']][$key][$i]->days[0] == 'wed') {
                                        $options[$networkfor['service']][$key][$i]->times[] = array('time_push' => $hour . ':' . $minute, 'category_id' => $category_id);
                                        for ($j = 0; $j < count($options[$networkfor['service']][$key][$i]->times); $j++) {
                                            if (strlen($options[$networkfor['service']][$key][$i]->times[$j]['time_push']) == 4) {
                                                $options[$networkfor['service']][$key][$i]->times[$j]['time_push'] = '0' . $options[$networkfor['service']][$key][$i]->times[$j]['time_push'];
                                            }
                                        }
                                        sort($options[$networkfor['service']][$key][$i]->times);
                                    }
                                }
                            }
                        }
                    }
                }
                break;
            case '3':
                if ($network) {
                    if ($network == 'all_networks') {
                        foreach ($allNetworks as $key => $networkfor) {
                            for ($i = 0; $i < count($options[$networkfor['service']][$key]); $i++) {
                                if ($options[$networkfor['service']][$key][$i]->days[0] == 'thu') {
                                    $options[$networkfor['service']][$key][$i]->times[] = array('time_push' => $hour . ':' . $minute, 'category_id' => $category_id);
                                    for ($j = 0; $j < count($options[$networkfor['service']][$key][$i]->times); $j++) {
                                        if (strlen($options[$networkfor['service']][$key][$i]->times[$j]['time_push']) == 4) {
                                            $options[$networkfor['service']][$key][$i]->times[$j]['time_push'] = '0' . $options[$networkfor['service']][$key][$i]->times[$j]['time_push'];
                                        }
                                    }
                                    sort($options[$networkfor['service']][$key][$i]->times);
                                }
                            }
                        }
                    } else {
                        foreach ($allNetworks as $key => $networkfor) {
                            if ($key == $network) {
                                for ($i = 0; $i < count($options[$networkfor['service']][$key]); $i++) {
                                    if ($options[$networkfor['service']][$key][$i]->days[0] == 'thu') {
                                        $options[$networkfor['service']][$key][$i]->times[] = array('time_push' => $hour . ':' . $minute, 'category_id' => $category_id);
                                        for ($j = 0; $j < count($options[$networkfor['service']][$key][$i]->times); $j++) {
                                            if (strlen($options[$networkfor['service']][$key][$i]->times[$j]['time_push']) == 4) {
                                                $options[$networkfor['service']][$key][$i]->times[$j]['time_push'] = '0' . $options[$networkfor['service']][$key][$i]->times[$j]['time_push'];
                                            }
                                        }
                                        sort($options[$networkfor['service']][$key][$i]->times);
                                    }
                                }
                            }
                        }
                    }
                }
                break;
            case '4':
                if ($network) {
                    if ($network == 'all_networks') {
                        foreach ($allNetworks as $key => $networkfor) {
                            for ($i = 0; $i < count($options[$networkfor['service']][$key]); $i++) {
                                if ($options[$networkfor['service']][$key][$i]->days[0] == 'fri') {
                                    $options[$networkfor['service']][$key][$i]->times[] = array('time_push' => $hour . ':' . $minute, 'category_id' => $category_id);
                                    for ($j = 0; $j < count($options[$networkfor['service']][$key][$i]->times); $j++) {
                                        if (strlen($options[$networkfor['service']][$key][$i]->times[$j]['time_push']) == 4) {
                                            $options[$networkfor['service']][$key][$i]->times[$j]['time_push'] = '0' . $options[$networkfor['service']][$key][$i]->times[$j]['time_push'];
                                        }
                                    }
                                    sort($options[$networkfor['service']][$key][$i]->times);
                                }
                            }
                        }
                    } else {
                        foreach ($allNetworks as $key => $networkfor) {
                            if ($key == $network) {
                                for ($i = 0; $i < count($options[$networkfor['service']][$key]); $i++) {
                                    if ($options[$networkfor['service']][$key][$i]->days[0] == 'fri') {
                                        $options[$networkfor['service']][$key][$i]->times[] = array('time_push' => $hour . ':' . $minute, 'category_id' => $category_id);
                                        for ($j = 0; $j < count($options[$networkfor['service']][$key][$i]->times); $j++) {
                                            if (strlen($options[$networkfor['service']][$key][$i]->times[$j]['time_push']) == 4) {
                                                $options[$networkfor['service']][$key][$i]->times[$j]['time_push'] = '0' . $options[$networkfor['service']][$key][$i]->times[$j]['time_push'];
                                            }
                                        }
                                        sort($options[$networkfor['service']][$key][$i]->times);
                                    }
                                }
                            }
                        }
                    }
                }
                break;
            case '5':
                if ($network) {
                    if ($network == 'all_networks') {
                        foreach ($allNetworks as $key => $networkfor) {
                            for ($i = 0; $i < count($options[$networkfor['service']][$key]); $i++) {
                                if ($options[$networkfor['service']][$key][$i]->days[0] == 'sat') {
                                    $options[$networkfor['service']][$key][$i]->times[] = array('time_push' => $hour . ':' . $minute, 'category_id' => $category_id);
                                    for ($j = 0; $j < count($options[$networkfor['service']][$key][$i]->times); $j++) {
                                        if (strlen($options[$networkfor['service']][$key][$i]->times[$j]['time_push']) == 4) {
                                            $options[$networkfor['service']][$key][$i]->times[$j]['time_push'] = '0' . $options[$networkfor['service']][$key][$i]->times[$j]['time_push'];
                                        }
                                    }
                                    sort($options[$networkfor['service']][$key][$i]->times);
                                }
                            }
                        }
                    } else {
                        foreach ($allNetworks as $key => $networkfor) {
                            if ($key == $network) {
                                for ($i = 0; $i < count($options[$networkfor['service']][$key]); $i++) {
                                    if ($options[$networkfor['service']][$key][$i]->days[0] == 'sat') {
                                        $options[$networkfor['service']][$key][$i]->times[] = array('time_push' => $hour . ':' . $minute, 'category_id' => $category_id);
                                        for ($j = 0; $j < count($options[$networkfor['service']][$key][$i]->times); $j++) {
                                            if (strlen($options[$networkfor['service']][$key][$i]->times[$j]['time_push']) == 4) {
                                                $options[$networkfor['service']][$key][$i]->times[$j]['time_push'] = '0' . $options[$networkfor['service']][$key][$i]->times[$j]['time_push'];
                                            }
                                        }
                                        sort($options[$networkfor['service']][$key][$i]->times);
                                    }
                                }
                            }
                        }
                    }
                }
                break;
            case '6':
                if ($network) {
                    if ($network == 'all_networks') {
                        foreach ($allNetworks as $key => $networkfor) {
                            for ($i = 0; $i < count($options[$networkfor['service']][$key]); $i++) {
                                if ($options[$networkfor['service']][$key][$i]->days[0] == 'sun') {
                                    $options[$networkfor['service']][$key][$i]->times[] = array('time_push' => $hour . ':' . $minute, 'category_id' => $category_id);
                                    for ($j = 0; $j < count($options[$networkfor['service']][$key][$i]->times); $j++) {
                                        if (strlen($options[$networkfor['service']][$key][$i]->times[$j]['time_push']) == 4) {
                                            $options[$networkfor['service']][$key][$i]->times[$j]['time_push'] = '0' . $options[$networkfor['service']][$key][$i]->times[$j]['time_push'];
                                        }
                                    }
                                    sort($options[$networkfor['service']][$key][$i]->times);
                                }
                            }
                        }
                    } else {
                        foreach ($allNetworks as $key => $networkfor) {
                            if ($key == $network) {
                                for ($i = 0; $i < count($options[$networkfor['service']][$key]); $i++) {
                                    if ($options[$networkfor['service']][$key][$i]->days[0] == 'sun') {
                                        $options[$networkfor['service']][$key][$i]->times[] = array('time_push' => $hour . ':' . $minute, 'category_id' => $category_id);
                                        for ($j = 0; $j < count($options[$networkfor['service']][$key][$i]->times); $j++) {
                                            if (strlen($options[$networkfor['service']][$key][$i]->times[$j]['time_push']) == 4) {
                                                $options[$networkfor['service']][$key][$i]->times[$j]['time_push'] = '0' . $options[$networkfor['service']][$key][$i]->times[$j]['time_push'];
                                            }
                                        }
                                        sort($options[$networkfor['service']][$key][$i]->times);
                                    }
                                }
                            }
                        }
                    }
                }
                break;
        }

        return $options;
    }

    public function updateCustomFrequency($schedules): void
    {
        $ecp_frequency_schedules = get_option('ecp_frequency_schedules') ? get_option('ecp_frequency_schedules') : array();
        $ecp_frequency_schedules['custom'] = $schedules;

        update_option('ecp_frequency_schedules', $ecp_frequency_schedules);

        $ecp_options = get_option('ecp_options');
        $ecp_options['ecp_frequency'] = 'custom';

        update_option('ecp_options', $ecp_options);
    }

    /**
     * Add posting schedule when "Add posting time"
     *
     * @since 1.0.0
     */
    public function ajaxInsertData(): void
    {
        global $wpdb, $statistics;

        $allCategories = $wpdb->get_results('SELECT * FROM wp_evergreen_categories');
        $allCategoriesName = array();
        foreach ($allCategories as $category) {
            $allCategoriesName[$category->id] = $category->name;
        }

        $categories = $wpdb->get_results('SELECT * FROM wp_evergreen_categories WHERE status = 1');

        $categoryIds = array();

        foreach ($categories as $category) {
            $categoryIds[] = $category->id;
        }

        // push data to db
        $schedules = get_option('ecp_schedule_settings');
        $ecp_frequency_schedules = get_option('ecp_frequency_schedules');
        $ecp_options = get_option('ecp_options');

        if (isset($ecp_options['ecp_frequency'])) {
            $schedules['schedules'] = $ecp_frequency_schedules[$ecp_options['ecp_frequency']];
        }

        $options = $this->addOption($schedules['schedules'], sanitize_text_field($_POST['network']), sanitize_text_field($_POST['day']), sanitize_text_field($_POST['hour']), sanitize_text_field($_POST['minute']), absint($_POST['category_id']));

        $schedules['schedules'] = $options;
        update_option('ecp_schedule_settings', $schedules, 'yes');

        $this->updateCustomFrequency($schedules['schedules']);

        $profiles = $this->buffer->profiles();

        if (isset($_POST['service']) && $_POST['service'] && isset($_POST['id']) && $_POST['id']) {
            $selected_schedules = $options[$_POST['service']][$_POST['id']];

            foreach ($profiles as $service => $list_profile) {
                if ($service == sanitize_text_field($_POST['service'])) {
                    foreach ($list_profile as $profile) {
                        if ($profile->id == $_POST['id']) {
                            $selected_profile_ajax = $profile;
                        }
                    }
                }
            }

            ob_start();
            $is_empty_schedule = true;

            foreach ($selected_schedules as $schedule) {
                if (!empty($schedule->times)) {
                    $is_empty_schedule = false;
                }
            }
            ?>
            <div class="ecp-col-940 ecp-option-container ecp-field-setting no_schedule">
                <?php if (!$is_empty_schedule) : ?>
                    <?php foreach ($selected_schedules as $ds_key => $daily_schedule) : ?>
                        <div class="ecp-grid ecp-col-130" style="margin-right: 0.9%">
                            <?php
                            $times = [];
                            foreach ($daily_schedule->times as $time) {
                                if (strlen($time['time_push']) == 4) {
                                    $time['time_push'] = '0' . $time['time_push'];
                                }
                                $times[] = $time;
                            }
                            $daily_schedule->times = $times;
                            sort($daily_schedule->times);

                            foreach ($daily_schedule->times as $key => $value) : ?>
                                <a href="#delete-schedule" class="show-modal-delete" rel="modal:open"
                                   data-day="<?= $daily_schedule->days[0] ?>"
                                   data-id="<?php echo $selected_profile_ajax->_id ?>"
                                   data-service="<?= $selected_profile_ajax->service ?>"
                                   data-value="<?= $value['time_push'] ?>" data-key="<?= $key ?>" data-general="0">
                                    <div class="ecp-grid ecp-col-940 scheduled-item">
                                        <div class="ecp-connected-profile-avatar">
                                            <img class="ecp-profile-circle"
                                                 ng-src="<?php echo $selected_profile_ajax->avatar; ?>"
                                                 img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png"
                                                 src="<?php echo $selected_profile_ajax->avatar; ?>">
                                            <div class="ecp-social-network-icon ecp-<?php echo strtolower($selected_profile_ajax->service); ?>"></div>
                                        </div>
                                        <div class="ecp-text">
                                            <span class="schedule_field schedule_time"><?php _e($value['time_push'], 'evergreen-content-poster'); ?></span><br/>
                                            <span class="schedule_field schedule_category"><?php echo $value['category_id'] ? $allCategoriesName[$value['category_id']] : _e('Random category', 'evergreen content poster') ?></span>
                                            <input type="hidden"
                                                   name="scheduled_daytime[<?php echo $selected_profile_ajax->id; ?>][<?php echo $ds_key; ?>][]"
                                                   value="<?php echo $value['time_push']; ?>"/>
                                            <p class="ecp-remove-schedule hidden"><span
                                                        class="dashicons dashicons-no"></span></p>
                                        </div>

                                        <?php if (!in_array($value['category_id'], $categoryIds) && $value['category_id'] != 0): ?>
                                            <div class="ecp-overlay"><span
                                                        class="dashicons dashicons-controls-pause"></span></div>
                                        <?php endif; ?>
                                    </div>
                                </a>
                            <?php endforeach; ?>
                        </div>
                    <?php endforeach; ?>

                <?php else : ?>
                    <div class="ecp-grid ecp-col-940">
                        <span class="">
                        	<img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-schedule.svg"
                                 width="180" height="124" style="display: block; margin: 3em auto;">
							<p style="text-align: center;"><?php _e('There is no schedule at the moment, please use the form above to create your schedule.', 'evergreen-content-poster'); ?></p>
						</span>
                    </div>
                <?php endif; ?>
            </div>
            <?php
        } else {
            $scheduleDefineLast = $this->getScheduleDefine($options, $profiles);
            ob_start();
            ?>
            <div class="ecp-col-940 ecp-option-container ecp-field-setting no_schedule">
                <?php
                $is_empty_schedule = true;

                foreach ($scheduleDefineLast as $schedule) {
                    if (!empty($schedule->times)) {
                        $is_empty_schedule = false;
                    }
                }

                ?>
                <?php if (!$is_empty_schedule) : ?>
                    <?php foreach ($scheduleDefineLast as $ds_key => $daily_schedule) : ?>
                        <div class="ecp-grid ecp-col-130" style="margin-right: 0.9%">
                            <?php
                            foreach ($daily_schedule->times as $key => $value) : ?>
                                <a href="#delete-schedule" class="show-modal-delete" rel="modal:open"
                                   data-day="<?= $daily_schedule->days[0] ?>" data-id="<?php echo $value['_id'] ?>"
                                   data-service="<?= $value['service'] ?>" data-value="<?= $value['time'] ?>"
                                   data-key="<?= $value['key'] ?>" data-general="1">
                                    <div class="ecp-grid ecp-col-940 scheduled-item">
                                        <div class="ecp-connected-profile-avatar">
                                            <img class="ecp-profile-circle" ng-src="<?php echo $value['avatar']; ?>"
                                                 img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png"
                                                 src="<?php echo $value['avatar']; ?>">
                                            <div class="ecp-social-network-icon ecp-<?php echo strtolower($value['service']); ?>"></div>
                                        </div>
                                        <div class="ecp-text">
                                            <span class="schedule_field schedule_time"><?php _e($value['time'], 'evergreen-content-poster'); ?></span><br/>
                                            <span class="schedule_field schedule_category"><?php echo $value['category_id'] ? $allCategoriesName[$value['category_id']] : _e('Random category', 'evergreen content poster') ?></span>
                                            <input type="hidden"
                                                   name="scheduled_daytime[<?php echo $value['_id']; ?>][<?php echo $ds_key; ?>][]"
                                                   value="<?php echo $value['time']; ?>"/>
                                            <p class="ecp-remove-schedule hidden"><span
                                                        class="dashicons dashicons-no"></span></p>
                                        </div>

                                        <?php if (!in_array($value['category_id'], $categoryIds) && $value['category_id'] != 0): ?>
                                            <div class="ecp-overlay"><span
                                                        class="dashicons dashicons-controls-pause"></span></div>
                                        <?php endif; ?>
                                    </div>
                                </a>
                            <?php endforeach; ?>
                        </div>
                    <?php endforeach; ?>

                <?php else : ?>
                    <div class="ecp-grid ecp-col-940">
                        <span class="">
                        	<img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-schedule.svg"
                                 width="180" height="124" style="display: block; margin: 3em auto;">
							<p style="text-align: center;"><?php _e('There is no schedule at the moment, please use the form above to create your schedule.', 'evergreen-content-poster'); ?></p>
						</span>
                    </div>
                <?php endif; ?>
            </div>
            <?php
        }

        if (count($allCategories) > 1) {
            // Get scheduleDefine
            $scheduleDefineLast = $this->getScheduleDefine($options, $profiles);
            // Get statistics
            $statistics = $this->get_statistics($allCategories, $scheduleDefineLast, $profiles);
            $totalNum = $this->getTotalStatistics($statistics['total']);
            if ($totalNum > 0) {
                include('partials/evergreen_content_statistics.php');
            }
        }

        $content = ob_get_clean();
        wp_send_json_success($content);
        ?>
        <?php
    }

    /**
     * Delete schedule
     *
     * @since   1.0.0
     */
    public function ajaxDeleteData(): void
    {
        global $wpdb, $statistics;

        $allCategories = $wpdb->get_results('SELECT * FROM wp_evergreen_categories');
        $allCategoriesName = array(
            '0' => __('Random category', 'evergreen-content-poster')
        );
        foreach ($allCategories as $category) {
            $allCategoriesName[$category->id] = $category->name;
        }

        $categories = $wpdb->get_results('SELECT * FROM wp_evergreen_categories WHERE status = 1');

        $categoryIds = array();

        foreach ($categories as $category) {
            $categoryIds[] = $category->id;
        }

        // push data to db
        $schedules_setting = get_option('ecp_schedule_settings');
        $schedules = $schedules_setting['schedules'];

        $ecp_frequency_schedules = get_option('ecp_frequency_schedules');
        $ecp_options = get_option('ecp_options');

        if (isset($ecp_options['ecp_frequency'])) {
            $schedules = $ecp_frequency_schedules[$ecp_options['ecp_frequency']];
        }

        $schedule = $schedules[sanitize_text_field($_POST['service'])][$_POST['id']];
        $scheduleLast = array();
        foreach ($schedule as $key => $std) {
            if ($std->days[0] == sanitize_text_field($_POST['day'])) {

                $times = array_values($std->times);
                unset($times[sanitize_text_field($_POST['key'])]);

                $timeLast = array_values($times);
                $std->times = $timeLast;
            }
            $scheduleLast[] = $std;
        }

        $schedules[sanitize_text_field($_POST['service'])][$_POST['id']] = $scheduleLast;

        $schedules_setting['schedules'] = $schedules;
        update_option('ecp_schedule_settings', $schedules_setting, 'yes');

        $this->updateCustomFrequency($schedules);

        $selected_schedules = $schedules[sanitize_text_field($_POST['service'])][$_POST['id']];

        $profiles = $this->buffer->profiles();

        if (is_null($_POST['general']) || !$_POST['general']) {
            foreach ($profiles as $service => $list_profile) {
                if ($service == $_POST['service']) {
                    foreach ($list_profile as $profile) {
                        if ($profile->id == $_POST['id']) {
                            $selected_profile_ajax = $profile;
                        }
                    }
                }
            }

            ob_start();
            $is_empty_schedule = true;
            foreach ($selected_schedules as $schedule) {
                if (!empty($schedule->times)) {
                    $is_empty_schedule = false;
                }
            }
            ?>
            <div class="ecp-col-940 ecp-option-container ecp-field-setting no_schedule">
                <?php if (!$is_empty_schedule) : ?>
                    <?php foreach ($selected_schedules as $ds_key => $daily_schedule) : ?>
                        <div class="ecp-grid ecp-col-130" style="margin-right: 0.9%">
                            <?php
                            $times = [];

                            foreach ($daily_schedule->times as $time) {
                                if (strlen($time['time_push']) == 4) {
                                    $time['time_push'] = '0' . $time['time_push'];
                                }
                                $times[] = $time;
                            }

                            $daily_schedule->times = $times;
                            sort($daily_schedule->times);
                            foreach ($daily_schedule->times as $key => $value) : ?>
                                <a href="#delete-schedule" class="show-modal-delete" rel="modal:open"
                                   data-day="<?= $daily_schedule->days[0] ?>"
                                   data-id="<?php echo $selected_profile_ajax->_id ?>"
                                   data-service="<?= $selected_profile_ajax->service ?>"
                                   data-value="<?= $value['time_push'] ?>" data-key="<?= $key ?>" data-general="0">
                                    <div class="ecp-grid ecp-col-940 scheduled-item">
                                        <div class="ecp-connected-profile-avatar">
                                            <img class="ecp-profile-circle"
                                                 ng-src="<?php echo $selected_profile_ajax->avatar; ?>"
                                                 img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png"
                                                 src="<?php echo $selected_profile_ajax->avatar; ?>">
                                            <div class="ecp-social-network-icon ecp-<?php echo strtolower($selected_profile_ajax->service); ?>"></div>
                                        </div>
                                        <div class="ecp-text">
                                            <span class="schedule_field schedule_time"><?php _e($value['time_push'], 'evergreen-content-poster'); ?></span><br/>
                                            <span class="schedule_field schedule_category"><?= $allCategoriesName[$value['category_id']] ?></span>
                                            <input type="hidden"
                                                   name="scheduled_daytime[<?php echo $selected_profile_ajax->id; ?>][<?php echo $ds_key; ?>][]"
                                                   value="<?php echo $value['time_push']; ?>"/>
                                            <p class="ecp-remove-schedule hidden"><span
                                                        class="dashicons dashicons-no"></span></p>
                                        </div>

                                        <?php if (!in_array($value['category_id'], $categoryIds) && $value['category_id'] != 0): ?>
                                            <div class="ecp-overlay"><span
                                                        class="dashicons dashicons-controls-pause"></span></div>
                                        <?php endif; ?>
                                    </div>
                                </a>
                            <?php endforeach; ?>
                        </div>
                    <?php endforeach; ?>

                <?php else : ?>
                    <div class="ecp-grid ecp-col-940">
                        <span class="">
                        	<img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-schedule.svg"
                                 width="180" height="124" style="display: block; margin: 3em auto;">
							<p style="text-align: center;"><?php _e('There is no schedule at the moment, please use the form above to create your schedule.', 'evergreen-content-poster'); ?></p>
						</span>
                    </div>
                <?php endif; ?>
            </div>
            <?php
        } else {
            // Get scheduleDefine
            $scheduleDefineLast = $this->getScheduleDefine($schedules, $profiles);
            ob_start();
            ?>
            <div class="ecp-col-940 ecp-option-container ecp-field-setting no_schedule">
                <?php
                $is_empty_schedule = true;

                foreach ($scheduleDefineLast as $schedule) {
                    if (!empty($schedule->times)) {
                        $is_empty_schedule = false;
                    }
                }

                ?>
                <?php if (!$is_empty_schedule) : ?>
                    <?php foreach ($scheduleDefineLast as $ds_key => $daily_schedule) : ?>
                        <div class="ecp-grid ecp-col-130" style="margin-right: 0.9%">
                            <?php
                            foreach ($daily_schedule->times as $key => $value) : ?>
                                <a href="#delete-schedule" class="show-modal-delete" rel="modal:open"
                                   data-day="<?= $daily_schedule->days[0] ?>" data-id="<?php echo $value['_id'] ?>"
                                   data-service="<?= $value['service'] ?>" data-value="<?= $value['time'] ?>"
                                   data-key="<?= $value['key'] ?>" data-general="1">
                                    <div class="ecp-grid ecp-col-940 scheduled-item">
                                        <div class="ecp-connected-profile-avatar">
                                            <img class="ecp-profile-circle" ng-src="<?php echo $value['avatar']; ?>"
                                                 img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png"
                                                 src="<?php echo $value['avatar']; ?>">
                                            <div class="ecp-social-network-icon ecp-<?php echo strtolower($value['service']); ?>"></div>
                                        </div>
                                        <div class="ecp-text">
                                            <span class="schedule_field schedule_time"><?php _e($value['time'], 'evergreen-content-poster'); ?></span><br/>
                                            <span class="schedule_field schedule_category"><?php echo $value['category_id'] ? $allCategoriesName[$value['category_id']] : _e('Random category', 'evergreen content poster') ?></span>
                                            <input type="hidden"
                                                   name="scheduled_daytime[<?php echo $value['_id']; ?>][<?php echo $ds_key; ?>][]"
                                                   value="<?php echo $value['time']; ?>"/>
                                            <p class="ecp-remove-schedule hidden"><span
                                                        class="dashicons dashicons-no"></span></p>
                                        </div>

                                        <?php if (!in_array($value['category_id'], $categoryIds) && $value['category_id'] != 0): ?>
                                            <div class="ecp-overlay"><span
                                                        class="dashicons dashicons-controls-pause"></span></div>
                                        <?php endif; ?>
                                    </div>
                                </a>
                            <?php endforeach; ?>
                        </div>
                    <?php endforeach; ?>

                <?php else : ?>
                    <div class="ecp-grid ecp-col-940">
                        <span class="">
                        	<img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-schedule.svg"
                                 width="180" height="124" style="display: block; margin: 3em auto;">
							<p style="text-align: center;"><?php _e('There is no schedule at the moment, please use the form above to create your schedule.', 'evergreen-content-poster'); ?></p>
						</span>
                    </div>
                <?php endif; ?>
            </div>
        <?php }
        if (count($allCategories) > 1) {
            // Get scheduleDefine
            $scheduleDefineLast = $this->getScheduleDefine($schedules, $profiles);
            // Get statistics
            $statistics = $this->get_statistics($allCategories, $scheduleDefineLast, $profiles);
            $totalNum = $this->getTotalStatistics($statistics['total']);
            if ($totalNum > 0) {
                include('partials/evergreen_content_statistics.php');
            }
        }
        ?>
        <?php $content = ob_get_clean();
        wp_send_json_success($content);
    }

    /**
     * Clear all schedules
     *
     * @since 1.0.0
     */
    public function ajaxClearData(): void
    {
        global $wpdb, $statistics;
        $allCategories = $wpdb->get_results('SELECT * FROM wp_evergreen_categories');;
        $allCategoriesName = array();
        foreach ($allCategories as $category) {
            $allCategoriesName[$category->id] = $category->name;
        }

        $categories = $wpdb->get_results('SELECT * FROM wp_evergreen_categories WHERE status = 1');

        $categoryIds = array();

        foreach ($categories as $category) {
            $categoryIds[] = $category->id;
        }

        // push data to db
        $schedules_setting = get_option('ecp_schedule_settings');
        $schedules = $schedules_setting['schedules'];

        $ecp_frequency_schedules = get_option('ecp_frequency_schedules');
        $ecp_options = get_option('ecp_options');

        if (isset($ecp_options['ecp_frequency'])) {
            $schedules = $ecp_frequency_schedules[$ecp_options['ecp_frequency']];
        }

        $profiles = $this->buffer->profiles();

        if (isset($_POST['service']) && sanitize_text_field($_POST['service']) && isset($_POST['id']) && sanitize_text_field($_POST['id'])) {
            $schedule = $schedules[sanitize_text_field($_POST['service'])][$_POST['id']];
            $scheduleLast = array();
            foreach ($schedule as $key => $std) {
                $std->times = array();
                $scheduleLast[] = $std;
            }

            $schedules[sanitize_text_field($_POST['service'])][sanitize_text_field($_POST['id'])] = $scheduleLast;
            $schedules_setting['schedules'] = $schedules;

            update_option('ecp_schedule_settings', $schedules_setting, 'yes');

            $this->updateCustomFrequency($schedules);

            $selected_schedules = $schedules[sanitize_text_field($_POST['service'])][$_POST['id']];

            foreach ($profiles as $service => $list_profile) {
                if ($service == $_POST['service']) {
                    foreach ($list_profile as $profile) {
                        if ($profile->id == $_POST['id']) {
                            $selected_profile_ajax = $profile;
                        }
                    }
                }
            }

            ob_start();
            ?>
            <?php $is_emtpy_schedule = true ?>
            <div class="ecp-col-940 ecp-option-container ecp-field-setting no_schedule">
                <?php if (!$is_emtpy_schedule) : ?>
                    <?php foreach ($selected_schedules as $ds_key => $daily_schedule) : ?>
                        <div class="ecp-grid ecp-col-130" style="margin-right: 0.9%">
                            <?php
                            $times = [];
                            foreach ($daily_schedule->times as $time) {
                                if (strlen($time['time_push']) == 4) {
                                    $time['time_push'] = '0' . $time['time_push'];
                                }
                                $times[] = $time;
                            }
                            $daily_schedule->times = $times;
                            sort($daily_schedule->times);
                            foreach ($daily_schedule->times as $key => $value) : ?>
                                <a href="#delete-schedule" class="show-modal-delete" rel="modal:open"
                                   data-day="<?= $daily_schedule->days[0] ?>"
                                   data-id="<?php echo $selected_profile_ajax->_id ?>"
                                   data-service="<?= $selected_profile_ajax->service ?>"
                                   data-value="<?= $value['time_push'] ?>" data-key="<?= $key ?>" data-general="0">
                                    <div class="ecp-grid ecp-col-940 scheduled-item">
                                        <div class="ecp-connected-profile-avatar">
                                            <img class="ecp-profile-circle"
                                                 ng-src="<?php echo $selected_profile_ajax->avatar; ?>"
                                                 img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png"
                                                 src="<?php echo $selected_profile_ajax->avatar; ?>">
                                            <div class="ecp-social-network-icon ecp-<?php echo strtolower($selected_profile_ajax->service); ?>"></div>
                                        </div>
                                        <div class="ecp-text">
                                            <span class="schedule_field schedule_time"><?php _e($value['time_push'], 'evergreen-content-poster'); ?></span><br/>
                                            <span class="schedule_field schedule_category"><?php echo $value['category_id'] ? $allCategoriesName[$value['category_id']] : _e('Random category', 'evergreen content poster') ?></span>
                                            <input type="hidden"
                                                   name="scheduled_daytime[<?php echo $selected_profile_ajax->id; ?>][<?php echo $ds_key; ?>][]"
                                                   value="<?php echo $value['time_push']; ?>"/>
                                            <p class="ecp-remove-schedule hidden"><span
                                                        class="dashicons dashicons-no"></span></p>
                                        </div>

                                        <?php if (!in_array($value['category_id'], $categoryIds) && $value['category_id'] != 0): ?>
                                            <div class="ecp-overlay"><span
                                                        class="dashicons dashicons-controls-pause"></span></div>
                                        <?php endif; ?>
                                    </div>
                                </a>
                            <?php endforeach; ?>
                        </div>
                    <?php endforeach; ?>

                <?php else : ?>
                    <div class="ecp-grid ecp-col-940">
                        <span class="">
                        	<img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-schedule.svg"
                                 width="180" height="124" style="display: block; margin: 3em auto;">
							<p style="text-align: center;"><?php _e('There is no schedule at the moment, please use the form above to create your schedule.', 'evergreen-content-poster'); ?></p>
						</span>
                    </div>
                <?php endif; ?>
            </div>

        <?php } else {

            foreach ($schedules as $service => $schedule) {
                foreach ($schedule as $id => $item) {
                    foreach ($item as $std) {
                        if (isset($std->times) && !empty($std->times)) {
                            $std->times = array();
                        }
                    }
                }
            }
            $schedules_setting['schedules'] = $schedules;
            update_option('ecp_schedule_settings', $schedules_setting, 'yes');

            $this->updateCustomFrequency($schedules);
            $scheduleDefineLast = $this->getScheduleDefine($schedules, $profiles);

            ob_start();
            ?>
            <div class="ecp-col-940 ecp-option-container ecp-field-setting no_schedule">
                <?php
                $is_empty_schedule = true;

                foreach ($scheduleDefineLast as $schedule) {
                    if (!empty($schedule->times)) {
                        $is_empty_schedule = false;
                    }
                }

                ?>
                <?php if (!$is_empty_schedule) : ?>
                    <?php foreach ($scheduleDefineLast as $ds_key => $daily_schedule) : ?>
                        <div class="ecp-grid ecp-col-130" style="margin-right: 0.9%">
                            <?php
                            foreach ($daily_schedule->times as $key => $value) : ?>
                                <a href="#delete-schedule" class="show-modal-delete" rel="modal:open"
                                   data-day="<?= $daily_schedule->days[0] ?>" data-id="<?php echo $value['_id'] ?>"
                                   data-service="<?= $value['service'] ?>" data-value="<?= $value['time'] ?>"
                                   data-key="<?= $value['key'] ?>" data-general="1">
                                    <div class="ecp-grid ecp-col-940 scheduled-item">
                                        <div class="ecp-connected-profile-avatar">
                                            <img class="ecp-profile-circle" ng-src="<?php echo $value['avatar']; ?>"
                                                 img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png"
                                                 src="<?php echo $value['avatar']; ?>">
                                            <div class="ecp-social-network-icon ecp-<?php echo strtolower($value['service']); ?>"></div>
                                        </div>
                                        <div class="ecp-text">
                                            <span class="schedule_field schedule_time"><?php _e($value['time'], 'evergreen-content-poster'); ?></span><br/>
                                            <span class="schedule_field schedule_category"><?php echo $value['category_id'] ? $allCategoriesName[$value['category_id']] : _e('Random category', 'evergreen content poster') ?></span>
                                            <input type="hidden"
                                                   name="scheduled_daytime[<?php echo $value['_id']; ?>][<?php echo $ds_key; ?>][]"
                                                   value="<?php echo $value['time']; ?>"/>
                                            <p class="ecp-remove-schedule hidden"><span
                                                        class="dashicons dashicons-no"></span></p>
                                        </div>

                                        <?php if (!in_array($value['category_id'], $categoryIds) && $value['category_id'] != 0): ?>
                                            <div class="ecp-overlay"><span
                                                        class="dashicons dashicons-controls-pause"></span></div>
                                        <?php endif; ?>
                                    </div>
                                </a>
                            <?php endforeach; ?>
                        </div>
                    <?php endforeach; ?>

                <?php else : ?>
                    <div class="ecp-grid ecp-col-940">
                        <span class="">
                        	<img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-schedule.svg"
                                 width="180" height="124" style="display: block; margin: 3em auto;">
							<p style="text-align: center;"><?php _e('There is no schedule at the moment, please use the form above to create your schedule.', 'evergreen-content-poster'); ?></p>
						</span>
                    </div>
                <?php endif; ?>
            </div>
        <?php }

        if (count($allCategories) > 1) {
            // Get scheduleDefine
            $scheduleDefineLast = $this->getScheduleDefine($schedules, $profiles);
            // Get statistics
            $statistics = $this->get_statistics($allCategories, $scheduleDefineLast, $profiles);
            $totalNum = $this->getTotalStatistics($statistics['total']);
            if ($totalNum > 0) {
                include('partials/evergreen_content_statistics.php');
            }
        }
        ?>
        <?php $content = ob_get_clean();
        wp_send_json_success($content);
    }

    public function load_settings(): void
    {

        $this->buffer_profiles = $this->buffer->profiles();

        $this->buffer_settings = $this->common->general_settings();

        $this->buffer_schedules = $this->common->schedules();

        $this->buffer_token = $this->buffer->get_token();

        $this->timezone = $this->common->timezone();
    }

    /**
     * Get schedules when no choose netwwork
     *
     * @param $schedules
     * @param $profiles
     * @return array
     */
    public function getScheduleDefine($schedules, $profiles)
    {
        // Process the entire network schedule
        $scheduleDefine = array();

        $days = array();
        $scheduleDefineLast = array();
        if (!empty($schedules)) {
            foreach ($schedules as $service => $schedule) {
                foreach ($schedule as $id => $rowSchedule) {
                    foreach ($profiles as $servicePro => $profile) {
                        foreach ($profile as $rowProfile) {
                            if ($service == $servicePro && $id == $rowProfile->_id) {
                                foreach ($rowSchedule as $value) {
                                    if (!in_array($value->days[0], $days)) {
                                        $dayTemp = new stdClass();
                                        $dayTemp->days[0] = $value->days[0];
                                        $dayTemp->times = array();
                                        foreach ($value->times as $key => $time) {
                                            $timeTemp = array();
                                            $timeTemp['time'] = $time['time_push'];
                                            $timeTemp['category_id'] = $time['category_id'] ?? null;
                                            $timeTemp['key'] = $key;
                                            $timeTemp['service'] = $service;
                                            $timeTemp['avatar'] = $rowProfile->avatar;
                                            $timeTemp['_id'] = $rowProfile->_id;

                                            $dayTemp->times[] = $timeTemp;
                                        }

                                        $scheduleDefine[] = $dayTemp;

                                        $days[] = $dayTemp->days[0];
                                    } else {
                                        foreach ($scheduleDefine as $row) {
                                            if ($row->days[0] == $value->days[0]) {
                                                if (count($value->times) > 0) {
                                                    foreach ($value->times as $key => $time) {
                                                        if (!empty($time)) {
                                                            $timeTemp = array();
                                                            $timeTemp['time'] = $time['time_push'];
                                                            $timeTemp['category_id'] = $time['category_id'] ?? null;
                                                            $timeTemp['key'] = $key;
                                                            $timeTemp['service'] = $service;
                                                            $timeTemp['avatar'] = $rowProfile->avatar ?? $rowProfile->avatar_https;
                                                            $timeTemp['_id'] = $rowProfile->_id;

                                                            $row->times[] = $timeTemp;
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }

            foreach ($scheduleDefine as $a) {
                $times = array();
                foreach ($a->times as $time) {
                    if (strlen($time['time']) == 4) {
                        $time['time'] = '0' . $time['time'];
                    }
                    $times[] = $time;
                }

                $a->times = $this->aasort($times, 'time');
                $a->times = array_values($a->times);


                $scheduleDefineLast[] = $a;
            }
        }

        return $scheduleDefineLast;
    }

    /**
     * Sort by time
     *
     * @param $array
     * @param $key
     * @return array
     * @since 1.0.0
     */
    public function aasort(&$array, $key)
    {
        $sorter = array();
        $ret = array();
        reset($array);
        foreach ($array as $ii => $va) {
            $sorter[$ii] = $va[$key];
        }
        asort($sorter);
        foreach ($sorter as $ii => $va) {
            $ret[$ii] = $array[$ii];
        }

        $array = $ret;

        return $array;

    }

    /**
     * Add cron interval
     *
     * @param $schedules
     * @return mixed
     * @since 1.0.0
     */
    public function schedule_add_cron_interval($schedules)
    {
        $schedules['one_minute'] = array(
            'interval' => 60,
            'display' => esc_html__('Every One Minute'));
        $schedules['twice_hourly'] = array(
            'interval' => 1800,
            'display' => esc_html__('Every 30 Minutes')
        );
        return $schedules;
    }

    public function get_statistics($allCategories, $scheduleDefineLast, $profiles)
    {
        $statistics = array();
        $category_statistics = array(
            '0' => __('Random category', 'evergreen-content-poster')
        );
        $statistics['total'] = array();
        $statistics['total'][0]['num'] = 0;
        $statistics['total'][0]['person'] = 0;
        foreach ($allCategories as $category) {
            $category_statistics[$category->id] = $category->name;
            $statistics['total'][$category->id]['num'] = 0;
            $statistics['total'][$category->id]['person'] = 0;
        }

        if (isset($_REQUEST['ecp_profile']) && $_REQUEST['ecp_profile']) {
            foreach ($profiles as $profile) {
                foreach ($profile as $singleProfile) {
                    if ($singleProfile->_id == sanitize_text_field($_REQUEST['ecp_profile'])) {
                        $selected_profile = $singleProfile;
                    }
                }
            }
        }

        $statistics['categories'] = $category_statistics;

        foreach ($scheduleDefineLast as $schedule) {
            $statistics[$schedule->days[0]] = array();

            foreach ($category_statistics as $key => $name) {
                $totalDay[$schedule->days[0]] = 0;
                $statistics[$schedule->days[0]][$key]['num'] = 0;
                $statistics[$schedule->days[0]][$key]['person'] = 0;
                foreach ($schedule->times as $time) {
                    if (isset($_REQUEST['ecp_profile']) && $_REQUEST['ecp_profile'] !== 'false') {
                        if ($time['_id'] == $selected_profile->_id) {
                            $totalDay[$schedule->days[0]]++;
                            if ($time['category_id'] == $key) {
                                $statistics[$schedule->days[0]][$key]['num'] = $statistics[$schedule->days[0]][$key]['num'] + 1;
                                $statistics['total'][$key]['num'] = $statistics['total'][$key]['num'] + 1;
                            }
                            $statistics[$schedule->days[0]][$key]['person'] = round($statistics[$schedule->days[0]][$key]['num'] / $totalDay[$schedule->days[0]], 2);
                        }
                    } else {
                        $totalDay[$schedule->days[0]]++;
                        if ($time['category_id'] == $key) {
                            $statistics[$schedule->days[0]][$key]['num'] = $statistics[$schedule->days[0]][$key]['num'] + 1;
                            $statistics['total'][$key]['num'] = $statistics['total'][$key]['num'] + 1;
                        }
                        $statistics[$schedule->days[0]][$key]['person'] = round($statistics[$schedule->days[0]][$key]['num'] / $totalDay[$schedule->days[0]], 2);
                    }
                }
            }
        }


        $total = 0;
        foreach ($statistics['total'] as $item) {
            $total = $total + $item['num'];
        }
        $totals = array();
        foreach ($statistics['total'] as $category_id => $item) {
            $item['person'] = $total ? round($item['num'] / $total, 2) : 0;
            $totals[$category_id] = $item;
        }

        $statistics['total'] = $totals;

        return $statistics;
    }

    public function getTotalStatistics($totals)
    {
        $total = 0;

        foreach ($totals as $temp) {
            $total = $total + $temp['num'];

        }

        return $total;
    }

    public function load_page(): void
    {
        global $wpdb, $statistics;
        $scheduled = wp_next_scheduled('wp_evergreen_content_schedule_cron_hook');

        $profiles = $this->buffer_profiles;
        $settings = $this->buffer_settings;
        $schedules_setting = $this->buffer_schedules;

        $ecp_frequency_schedules = get_option('ecp_frequency_schedules');

        $token = $this->buffer_token;
        $schedules = $schedules_setting['schedules'] ?? array();

        $allCategories = $wpdb->get_results('SELECT * FROM wp_evergreen_categories');
        $allCategoriesName = array();
        foreach ($allCategories as $category) {
            $allCategoriesName[$category->id] = $category->name;
        }

        $selected_profile = new stdClass();

        $scheduleDefineLast = $this->getScheduleDefine($schedules, $profiles);

        $categories = $wpdb->get_results('SELECT * FROM wp_evergreen_categories WHERE status = 1');

        $statistics = $this->get_statistics($allCategories, $scheduleDefineLast, $profiles);

        $totalNum = $this->getTotalStatistics($statistics['total']);

        $categoryIds = array();

        foreach ($categories as $category) {
            $categoryIds[] = $category->id;
        }

        // Get current step onboarding
        $options = get_option('ecp_options');
        $onboarding_step = 1;
        if (isset($options['onboarding_step']) && $options['onboarding_step'] > 1) {
            if ($onboarding_step < 7) {
                $onboarding_step = $options['onboarding_step'] + 1;
            } else {
                $onboarding_step = 1;
            }
        }
        ?>
        <script>
            const ecpSettings = JSON.parse('<?php echo json_encode($settings); ?>');
            const ecpSchedules = JSON.parse('<?php echo json_encode($schedules); ?>');
        </script>
        <div class="ecp-grid ecp-col-940 ecp-top-menu" ecp-registered="1">
            <div class="ecp-header-wrapper">
                <div class="ecp-grid ecp-col-700">
                    <div class="ecp-header-logo"></div>
                    <ul class="ecp-header-menu">
                        <li class="ecp-active-tab"><a class="ecp-tab-selector" href="#"
                                                      data-link="ecp_settings"><span><?php _e('Settings', 'evergreen-content-poster'); ?></span></a>
                        </li>
                        <li class=""><a class="ecp-tab-selector"
                                        href="<?php echo get_bloginfo('wpurl'); ?>/wp-admin/admin.php?page=evergreen-content-library"
                                        data-link="ecp_content_library"><span><?php _e('Content Library', 'evergreen-content-poster'); ?></span></a>
                        </li>
                    </ul>
                </div>
                <div class="ecp-grid ecp-col-220 ecp-fit">
                    <?php
                    wp_nonce_field('evergreen-settings-save', 'evergreen-settings-save');
                    ?>
                    <button id="save_settings" class="button ecp-navy-button ecp-save-settings"
                            disabled><?php _e('Save Changes', 'evergreen-content-poster'); ?></button>
                </div>
                <div class="ecp-clearfix"></div>
            </div>
            <?php if (isset($_SESSION['show_delete_schedule']) && $_SESSION['show_delete_schedule'] == true) ?>
            <div class="ecp-grid ecp-col-940 ecp-fit ecp-loading-saving <?php if (isset($_SESSION['show_delete_schedule']) && $_SESSION['show_delete_schedule'] == true): ?> show <?php endif; ?>">
                <?php
                if (isset($_SESSION['show_delete_schedule']) && $_SESSION['show_delete_schedule'] == true) {
                    _e($_SESSION['message'], 'evergreen-content-poster');
                    session_destroy();
                } else {
                    _e('Saving Settings', 'evergreen-content-poster');
                }

                ?>

            </div>
            <label class="hidden saving-default"><?php _e('Saving Settings', 'evergreen-content-poster'); ?></label>
            <label class="hidden saving-success"><?php _e('Settings Saved!', 'evergreen-content-poster'); ?></label>
            <label class="hidden saving-error"><?php _e('There was an error saving your settings. Please try again later.', 'evergreen-content-poster'); ?></label>

            <label class="hidden saving-posting-time-success"><?php _e('Successfully added a new posting timeslot', 'evergreen-content-poster'); ?></label>
            <label class="hidden saving-posting-time-error"><?php _e('There is an error trying to add this posting timeslot, please try again', 'evergreen-content-poster'); ?></label>
            <label class="hidden delete-posting-time-success"><?php _e('Successfully deleted posting timeslot', 'evergreen-content-poster'); ?></label>
            <label class="hidden delete-posting-time-error"><?php _e('There is an error trying to delete this posting timeslot, please try again', 'evergreen-content-poster'); ?></label>
            <label class="hidden clear-posting-time-success"><?php _e('Successfully cleared posting timeslot', 'evergreen-content-poster'); ?></label>
            <label class="hidden clear-posting-time-error"><?php _e('There is an error trying to clear this posting timeslot, please try again', 'evergreen-content-poster'); ?></label>
            <label class="hidden ecp-custom-text"><?php _e('Do you want to use your current schedule as a basis to build your own schedule?', 'evergreen-content-poster'); ?></label>
        </div>
        <div class="ecp-wrapper">
            <?php if (EVERGREEN_CONTENT_POSTER_ENABLE_DEBUG == true) : ?>
                <div class="post_buffer button ecp-navy-button ecp-red-button"><?php _e('Post to Buffer', 'evergreen-content-poster'); ?></div>
            <?php endif; ?>
            <div class="ecp-container">

                <div class="ecp-section">

                    <div class="ecp-grid ecp-col-700">

                        <form id="ecp_settings_form" method="post"
                              action="<?php echo esc_html(admin_url('admin-post.php')); ?>">
                            <div class="ecp-admin-tab ecp-grid ecp-col-940" style="display: block;">
                                <?php
                                if (EVERGREEN_CONTENT_POSTER_ENABLE_DEBUG == true) :
                                    var_dump(date('Y-m-d H:i:s', $scheduled));
                                    var_dump(date('Y-m-d H:i:s'));
                                    var_dump(wp_get_schedule('wp_evergreen_content_schedule_cron_hook'));
                                    // echo "<p><a href='/wp-admin/admin.php?page=evergreen-content-configurator#step-" . $onboarding_step . "'>start onboarding</a></p>";
                                endif;
                                ?>
                                <div class="ecp-section ecp-grid ecp-col-860 ecp-fit ecp-option-container">

                                    <?php

                                    $user_id = get_current_user_id();
                                    
                                    if (!$token) : ?>
                                        <div class="ecp-error-container-notification">
                                            <div class="ecp-container-notification__image">
                                                <img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-accounts-connected.svg"
                                                     width="60" height="60">
                                            </div>
                                            <div class="">
                                                <div class="ecp-container-notification__content">
													<h3><?php _e('There are no social media accounts connected yet to the Evergreen Content Poster, let\'s add some socials &#128170;', 'evergreen-content-poster'); ?></h3>
                                                    <p><?php echo sprintf(
                                                        /* translators: %1s is a link start tag to an FAQ article to help troubleshoot the cron issue, %2s is the link closing tag. */
                                                            esc_html__('Before the Evergreen Content Poster can start to share your social media posts we first need to have a connection with your social media profiles.%1sClick %2shere to start connecting your social media profiles to the plugin.%3s', 'evergreen-content-poster'),
                                                            '<br />',
                                                            '<strong><a href="' . esc_url( admin_url( 'admin.php?page=evergreen-content-settings#AccountSettings') ) . '">',
                                                            '</a></strong>'
                                                        ); ?>
                                                    </p>
                                                </div>
                                            </div>
                                        </div>                                    
                                    
									<?php
									endif;
                                    
                                    if (defined('DISABLE_WP_CRON') && DISABLE_WP_CRON == true && !get_user_meta($user_id, 'ecp-wp-cron-notice-dismissed')) { ?>
                                        <div class="ecp-error-container-notification">
                                            <div class="ecp-container-notification__image">
                                                <img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-wp-cron-not-working.svg"
                                                     width="60" height="60">
                                            </div>
                                            <div class="">
                                                <div class="ecp-container-notification__content">
                                                    <h3><?php _e('The WordPress Cron seems to be disabled', 'evergreen-content-poster'); ?></h3>
                                                    <p><?php echo sprintf(
                                                        /* translators: %1s is a link start tag to an FAQ article to help troubleshoot the cron issue, %2s is the link closing tag. */
                                                            esc_html__('The WordPress Cron seems to be disabled on your website. This can cause sharing issues with the Evergreen Content Poster. If sharing is not working, then see %1shere for a potential solution.%2s', 'evergreen-content-poster'),
                                                            '<a href="https://evergreencontentposter.io/#how-can-i-fix-the-evergreen-content-poster-not-posting" target="_blank">',
                                                            '</a>'
                                                        ); ?>
                                                    </p>
                                                </div>
                                                <a href="#" style=""
                                                   class="button dismiss ecp-container__configuration-wizard--dismiss--cron">
                                                    <span class="dashicons dashicons-no-alt"></span>
                                                </a>
                                            </div>
                                        </div>
                                    <?php } ?>


                                    <div class="ecp-container-notification">
                                        <div class="ecp-container-notification__image">
                                            <img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-onboarding-checklist.svg"
                                                 width="60" height="60">
                                        </div>
                                        <?php
                                        $ecp_getting_started_dismissed = 0;
                                        if (get_user_meta($user_id, 'ecp-getting-started-dismissed', true) == 'true') {
                                            $ecp_getting_started_dismissed = 1;
                                        }

                                        ?>
                                        <div class="top-notify-dismiss <?php if (!$ecp_getting_started_dismissed): ?> hidden<?php endif; ?>">
                                            <div class="ecp-container-notification__content">
                                                <h3><?php _e('Evergreen Content Poster configured', 'evergreen-content-poster'); ?></h3>
                                                <p><?php echo sprintf(
                                                    /* translators: %1s is a link start tag to the Onboarding Wizard, %2s is the link closing tag. */
                                                        esc_html__('If you want to double-check your Evergreen Content Poster settings, or change something quickly, you can always %1sreopen the configuration wizard!%2s.', 'evergreen-content-poster'),
                                                        '<a href="' . esc_url(admin_url('admin.php?page=evergreen-content-configurator')) . '">',
                                                        '</a>'
                                                    ); ?>
                                                </p>
                                            </div>
                                        </div>
                                        <div class="top-notify <?php if ($ecp_getting_started_dismissed): ?> hidden<?php endif; ?>">
                                            <div class="ecp-container-notification__content">
                                                <h3><?php _e('First-time Evergreen Content Poster configuration', 'evergreen-content-poster'); ?></h3>
                                                <p><?php echo sprintf(
                                                    /* translators: %1s is a link start tag to the Onboarding Wizard, %2s is the link closing tag. */
                                                        esc_html__('Get started quickly with the Evergreen Content Poster %1sconfiguration wizard!%2s', 'evergreen-content-poster'),
                                                        '<strong><a href="' . esc_url(admin_url('admin.php?page=evergreen-content-configurator')) . '">',
                                                        '</a></strong>'
                                                    ); ?>
                                                </p>
                                            </div>
                                            <a href="#" style=""
                                               class="button dismiss ecp-container__configuration-wizard--dismiss">
                                                <span class="dashicons dashicons-no-alt"></span>
                                            </a>
                                        </div>
                                    </div>

                                </div>
                                <div class="ecp-section ecp-grid ecp-col-940 ecp-fit ecp-option-container ecp-general-settings-title-wrapper">
                                    <h2><?php _e('General Settings', 'evergreen-content-poster'); ?></h2>
                                </div>

                                <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                    <div class="ecp-grid ecp-col-300">
                                        <p class="ecp-input-label"><?php _e('Timezone', 'evergreen-content-poster'); ?></p>
                                        <p class="description"><?php _e('By default we use the timezone settings of your WordPress installation, if you want to change this adapt your timezone settings here.', 'evergreen-content-poster'); ?></p>
                                    </div>
                                    <div class="ecp-grid ecp-col-300">
                                        <select name="eg_timezone" value="" class="ecp-admin-input field-setting"
                                                data-ref="saved_timezone" aria-invalid="false">
                                            <?php echo wp_timezone_choice($settings['eg_timezone'] ?? '') ?>
                                        </select>
                                        <input type="hidden" name="saved_timezone"
                                               value="<?php echo $settings['eg_timezone']; ?>"/>
                                    </div>
                                </div>

                                <div class="ecp-grid  ecp-col-940 ecp-option-container ecp-field-setting">
                                    <div class="ecp-grid ecp-col-300">
                                        <p class="ecp-input-label"><?php _e('Add Posts to the Top/Bottom of the queue', 'evergreen-content-poster'); ?></p>
                                    </div>
                                    <div class="ecp-grid ecp-col-300">
                                        <?php
                                        $select = [
                                            'top' => __('Top', 'evergreen-content-poster'),
                                            'bottom' => __('Bottom', 'evergreen-content-poster')
                                        ];
                                        ?>
                                        <select name="eg_position" class="field-setting" data-ref="saved_position"
                                                aria-invalid="false">
                                            <?php foreach ($select as $key => $text) : ?>
                                                <?php
                                                $selected = ($key == $settings['eg_position']) ? 'selected' : '';
                                                // still missing aria-checked="false" (for not selected) and aria-checked="true" (with selected value)
                                                ?>
                                                <option value="<?php echo $key; ?>" <?php echo $selected; ?>><?php _e($text, 'evergreen-content-poster'); ?></option>
                                            <?php endforeach; ?>
                                        </select>
                                        <input type="hidden" name="saved_position"
                                               value="<?php echo $settings['eg_position']; ?>"/>
                                    </div>
                                </div>

                                <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                    <div class="ecp-grid ecp-col-300">
                                        <p class="ecp-input-label"><?php _e('Posting Order', 'evergreen-content-poster'); ?></p>
                                    </div>
                                    <div class="ecp-grid ecp-col-300">
                                        <?php
                                        $select = [
                                            'random' => __('Random', 'evergreen-content-poster'),
                                            'oldest_first' => __('Posting time (oldest first)', 'evergreen-content-poster')
                                        ];
                                        ?>
                                        <select name="eg_postingorder" data-ref="saved_postingorder"
                                                class="field-setting" aria-invalid="false">
                                            <?php foreach ($select as $key => $text) : ?>
                                                <?php
                                                $selected = ($key == $settings['eg_postingorder']) ? 'selected' : '';
                                                // still missing aria-checked="false" (for not selected) and aria-checked="true" (with selected value)
                                                ?>
                                                <option value="<?php echo $key; ?>" <?php echo $selected; ?>><?php _e($text, 'evergreen-content-poster'); ?></option>
                                            <?php endforeach; ?>
                                        </select>
                                        <input type="hidden" name="saved_postingorder"
                                               value="<?php echo $settings['eg_postingorder']; ?>"/>
                                    </div>
                                </div>

                                <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                    <div class="ecp-grid ecp-col-300">
                                        <p class="ecp-input-label ecp-label-min-days"><?php _e('Minimum number of days not to repeat the same post', 'evergreen-content-poster'); ?></p>
                                        <p class="description"><?php _e('If zero, this won\'t be taken into account and post can be potentially be posted twice on the same day.', 'evergreen-content-poster'); ?></p>
                                    </div>
                                    <div class="ecp-grid ecp-col-300">
                                        <input type="number" name="eg_numberofdays" min="1" max="120" required="true"
                                               value="<?php echo $settings['eg_numberofdays']; ?>"
                                               class="ecp-admin-input field-setting" data-ref="saved_numberofdays"
                                               aria-invalid="false"/>
                                        <input type="hidden" name="saved_numberofdays"
                                               value="<?php echo $settings['eg_numberofdays']; ?>"/>
                                    </div>
                                </div>

                                <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                    <div class="ecp-grid ecp-col-300">
                                        <p class="ecp-input-label"><?php _e('Enable Google Analytics Tracking', 'evergreen-content-poster'); ?></p>
                                        <p class="description"><?php _e('If checked, UTM query tags will be added to URL of shares so that you can better track traffic from Evergreen Content Poster.', 'evergreen-content-poster'); ?></p>
                                    </div>
                                    <div class="ecp-grid ecp-col-300">
                                        <?php
                                        $checked = (isset($settings['utm_tags']) && $settings['utm_tags'] == 'Y') ? 'checked' : '';
                                        $data_status = (isset($settings['utm_tags']) && $settings['utm_tags'] == 'Y') ? 'on' : 'off';
                                        ?>
                                        <input type="checkbox" class="field-setting ecp-hidden" name="utm_tags"
                                               value="Y" <?php echo $checked; ?> data-ref="saved_utm_tags"/>
                                        <input type="hidden" name="saved_utm_tags" name="utm_tags"
                                               value="<?php echo $settings['utm_tags']; ?>"/>
                                        <div class="ecp-checkbox-toggle" data-status="<?php echo $data_status; ?>"
                                             data-field="utm_tags">
                                            <div class="ecp-checkbox-on"><?php _e('ON', 'evergreen-content-poster'); ?></div>
                                            <div class="ecp-checkbox-off"><?php _e('OFF', 'evergreen-content-poster'); ?></div>
                                        </div>
                                    </div>
                                </div>

                            </div>

                            <div class="ecp-section ecp-grid ecp-col-940 ecp-fit ecp-option-container ecp-social-networks-title-wrapper"
                                 id="connected_profiles">
                                <h2><a name="AccountSettings"
                                       style="color: #1b3a51"><?php _e('Account Settings', 'evergreen-content-poster'); ?></a>
                                </h2>
                                <div class="ecp-grid ecp-col-300 ecp-no-bottom-margin">

                                    <?php if (!$token) : ?>
                                        <a href="<?php echo $this->buffer->oauth_url(); ?>"
                                           class="button ecp-navy-button ecp-save-settings"><?php _e('Connect to Buffer', 'evergreen-content-poster'); ?></a>

                                        <p><?php _e('Connect to Buffer to start using Evergreen Content Poster.', 'evergreen-content-poster'); ?><?php echo sprintf(
                                            /* translators: %1$s is a link start tag to Buffer signup page, %2$s is the link closing tag */
                                                esc_html__('If you don\'t have a Buffer account yet, you can create a %1sfree account here%2s.', 'evergreen-content-poster'),
                                                '<a href="https://buffer.com/signup" target="_blank" class="ecp-link">',
                                                '</a>'
                                            ); ?>
                                        </p>
                                    <?php else : ?>
                                        <a href="<?php echo $this->buffer->deauthorize_url($_REQUEST['page']); ?>"
                                           class="button ecp-green-button ecp-save-settings buffer-connected"
                                           data-connected="<?php _e('Connected to Buffer', 'evergreen-content-poster'); ?>"
                                           data-disconnect="<?php _e('Disconnect from Buffer', 'evergreen-content-poster'); ?>"><?php _e('Connected to Buffer', 'evergreen-content-poster'); ?></a>
                                    <?php endif; ?>
                                </div>
                            </div>

                            <?php if ($token) : ?>

                                <?php if (!empty($profiles)) : ?>
                                    <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                        <div class="ecp-grid ecp-col-300 ecp-no-bottom-margin">
                                            <p><?php _e('Connected social networks', 'evergreen-content-poster'); ?></p>
                                        </div>
                                    </div>
                                <?php else : ?>
                                    <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                        <div class="ecp-grid ecp-col-300">
                                            <p><?php _e('No profiles added to Buffer yet...', 'evergreen-content-poster'); ?></p>
                                            <p><?php _e('Add a profile to start using the Evergreen Content Poster', 'evergreen-content-poster'); ?></p>
                                        </div>
                                    </div>
                                <?php endif; ?>

                                <?php if (!empty($profiles)) : ?>
                                    <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                        <?php foreach ($profiles as $service => $profile_list) : ?>
                                            <?php
                                            foreach ($profile_list as $key => $single_profile) :
                                                $avatar = EVERGREEN_CONTENT_POSTER_PATH . '/admin/img/ecp-profile-unknown.png';
                                                if (!empty($single_profile->avatar))
                                                    $avatar = $single_profile->avatar;

                                                $profile_username = !empty($single_profile->formatted_username) ? $single_profile->formatted_username : ucwords($single_profile->service_type) . ($key + 1);
                                                if (strlen($profile_username) > 18) {
                                                    $profile_username = substr($profile_username, 0, 15) . '...';
                                                }

                                                $service_type = $single_profile->service . ' ' . ucwords($single_profile->service_type);
                                                if (strlen($service_type) > 17) {
                                                    $service_type = substr($service_type, 0, 14) . '...';
                                                }

                                                $cssClass = '';
                                                if (isset($_REQUEST['ecp_profile']) && $single_profile->id == sanitize_text_field($_REQUEST['ecp_profile'])) {
                                                    $cssClass = 'active';

                                                    $selected_profile = $single_profile;
                                                    $selected_schedules = $schedules[$single_profile->service][$single_profile->id];
                                                }
                                                ?>
                                                <div class="ecp-grid ecp-col-140">
                                                    <a href="<?php echo get_bloginfo('wpurl'); ?>/wp-admin/admin.php?page=evergreen-content-settings&ecp_profile=<?php echo $single_profile->id; ?>&edit_schedule=Y#connected_profiles"
                                                       class="ecp-profile-select">
                                                        <div class="ecp-connected-profile <?php echo $cssClass; ?>">
                                                            <div class="ecp-connected-profile-avatar">
                                                                <img class="ecp-profile-circle"
                                                                     ng-src="<?php echo $avatar; ?>"
                                                                     img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png"
                                                                     src="<?php echo $avatar; ?>">
                                                                <div class="ecp-social-network-icon ecp-<?php echo strtolower($single_profile->service); ?>"></div>
                                                            </div>
                                                            <div class="ecp-connected-profile-name">
                                                                <span class="ecp-connected-profile-username"><?php _e($profile_username, 'evergreen-content-poster'); ?></span>
                                                                <br/>
                                                                <span class="ecp-connected-profile-network"><?php _e($service_type, 'evergreen-content-poster'); ?></span>
                                                            </div>
                                                        </div>
                                                    </a>
                                                </div>
                                            <?php endforeach; ?>
                                        <?php endforeach; ?>

                                    </div>
                                <?php endif; ?>

                                <div class="ecp-section ecp-grid ecp-col-940 ecp-fit ecp-option-container .ecp-schedule-settings-title-wrapper">
                                    <h2><?php _e('Schedule Settings', 'evergreen-content-poster'); ?></h2>
                                </div>

                                <div class="ecp-hidden">
                                    <input type="hidden" name="saved_posting_schedule"
                                           value="<?php echo $settings['ecp_posting_schedule']; ?>"/>
                                    <?php
                                    $schedules_radios = [
                                        'daily' => 'daily_posts',
                                        'queue' => 'empty_queue',
                                        'timestamp' => 'timestamp',
                                    ];
                                    foreach ($schedules_radios as $key => $value) {
                                        $checked = '';
                                        if ($settings['ecp_posting_schedule'] == $value)
                                            $checked = 'checked';
                                        ?>
                                        <input type="radio" class="posting-schedule-<?php echo $key; ?>"
                                               name="ecp_posting_schedule"
                                               value="<?php echo $value; ?>" <?php echo $checked; ?> />
                                        <?php
                                    }
                                    ?>

                                    <!--                                    <input type="radio" class="posting-schedule-queue" name="ecp_posting_schedule" value="empty_queue" />-->
                                    <!--                                    <input type="radio" class="posting-schedule-daily" name="ecp_posting_schedule" value="timestamp" />-->
                                </div>

                                <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                    <div class="tabs">
                                        <input type="radio" name="tabs" class="" id="tabone" checked="checked"/>
                                        <label class="ecp-padding-10"
                                               for="tabone"><?php _e('Post number of posts daily', 'evergreen-content-poster'); ?></label>
                                        <div class="tab">

                                            <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                                <div class="ecp-grid ecp-col-300 ecp-no-bottom-margin">
                                                    <p class="ecp-input-label"><?php _e('#1 Post number of posts daily', 'evergreen-content-poster'); ?></p>
                                                    <p class="description"><?php _e('Share X number of posts to your social media profiles evenly spread out during the day.', 'evergreen-content-poster'); ?></p>
                                                </div>

                                                <?php
                                                $isScheduleActive = ('daily_posts' == $settings['ecp_posting_schedule']) ? true : false;
                                                $buttonClass = '';
                                                $spanClass = 'ecp-hidden';
                                                if ($isScheduleActive) {
                                                    $buttonClass = 'ecp-hidden';
                                                    $spanClass = '';
                                                }
                                                ?>
                                                <div class="ecp-grid ecp-col-300">
                                                    <button class="button ecp-navy-button ecp-activate-button <?php echo $buttonClass; ?> "
                                                            data-radio="posting-schedule-daily"><?php _e('Activate', 'evergreen-content-poster'); ?></button>
                                                    <span class="active active-scheduler <?php echo $spanClass; ?> "><?php _e('Currently Active', 'evergreen-content-poster'); ?></span>
                                                </div>
                                            </div>

                                            <?php foreach ($profiles as $service => $profile): ?>
                                                <?php foreach ($profile as $value): ?>
                                                    <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                                        <div class="ecp-grid ecp-col-300">
                                                            <div class="ecp-connected-profile-avatar">
                                                                <img class="ecp-profile-circle"
                                                                     ng-src="<?php echo $value->avatar ?? ''; ?>"
                                                                     img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png"
                                                                     src="<?php echo $value->avatar ?? ''; ?>">
                                                                <div class="ecp-social-network-icon ecp-<?php echo strtolower($value->service); ?>"></div>
                                                            </div>
                                                            <p class="ecp-input-label">
                                                                &nbsp;<?php _e('Posts per day', 'evergreen-content-poster'); ?></p>
                                                        </div>
                                                        <div class="ecp-grid ecp-col-300"><input
                                                                    data-radio="posting-schedule-daily" type="number"
                                                                    min="0" max="1440" required="true"
                                                                    name="post_per_day_<?php echo $value->id ?>"
                                                                    value="<?= isset($this->buffer_settings['post_per_day_' . $value->id]) ? $this->buffer_settings['post_per_day_' . $value->id] : '0' ?>"
                                                                    id="post_per_day_<?php echo $value->id ?>"
                                                                    class="ecp-admin-input post_per_day_change"
                                                                    data-ref="saved_post_per_day" aria-invalid="false"/>
                                                        </div>
                                                    </div>
                                                <?php endforeach; ?>
                                            <?php endforeach; ?>
                                        </div>

                                        <input type="radio" name="tabs" class="" id="tabtwo"/>
                                        <label class="ecp-padding-10"
                                               for="tabtwo"><?php _e('Post only when Buffer queue gets empty', 'evergreen-content-poster'); ?></label>
                                        <div class="tab">
                                            <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                                <div class="ecp-grid ecp-col-300">
                                                    <p class="ecp-input-label"><?php _e('#2 Post only when Buffer queue gets empty', 'evergreen-content-poster'); ?></p>
                                                    <p class="description"><?php _e('Get posts to your Buffer queue every time it is empty', 'evergreen-content-poster'); ?></p>
                                                </div>

                                                <?php
                                                $isScheduleActive = ('empty_queue' == $settings['ecp_posting_schedule']) ? true : false;
                                                $buttonClass = '';
                                                $spanClass = 'ecp-hidden';
                                                if ($isScheduleActive) {
                                                    $buttonClass = 'ecp-hidden';
                                                    $spanClass = '';
                                                }
                                                ?>
                                                <div class="ecp-grid ecp-col-300">
                                                    <button class="button ecp-navy-button ecp-activate-button <?php echo $buttonClass; ?> "
                                                            data-radio="posting-schedule-queue"><?php _e('Activate', 'evergreen-content-poster'); ?></button>
                                                    <span class="active active-scheduler <?php echo $spanClass; ?> "><?php _e('Currently Active', 'evergreen-content-poster'); ?></span>
                                                </div>
                                            </div>

                                            <?php foreach ($profiles as $service => $profile): ?>
                                                <?php foreach ($profile as $value):
                                                    $profile_username = !empty($value->formatted_username) ? $value->formatted_username : ucwords($value->service_type) . ($key + 1);
                                                    if (strlen($profile_username) > 18) {
                                                        $profile_username = substr($profile_username, 0, 15) . '...';
                                                    }

                                                    $service_type = $value->service . ' ' . ucwords($value->service_type);
                                                    if (strlen($service_type) > 17) {
                                                        $service_type = substr($service_type, 0, 14) . '...';
                                                    }
                                                    ?>
                                                    <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                                        <div class="ecp-grid ecp-col-300">
                                                            <div class="ecp-connected-profile-avatar">
                                                                <img class="ecp-profile-circle"
                                                                     ng-src="<?php echo $value->avatar ?? ''; ?>"
                                                                     img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png"
                                                                     src="<?php echo $value->avatar ?? ''; ?>">
                                                                <div class="ecp-social-network-icon ecp-<?php echo strtolower($value->service); ?>"></div>
                                                            </div>
                                                            <div class="ecp-connected-profile-name">
                                                                <span class="ecp-connected-profile-username">
                                                                    <?php _e($profile_username, 'evergreen-content-poster'); ?>
                                                                </span>
                                                                <br/>
                                                                <span class="ecp-connected-profile-network"><?php _e($service_type, 'evergreen-content-poster'); ?></span>
                                                            </div>
                                                        </div>
                                                        <div class="ecp-grid ecp-col-300">
                                                            <?php
                                                            $checked = (isset($settings['empty_queue_status_' . $value->id]) && $settings['empty_queue_status_' . $value->id] == 'Y') ? 'checked' : '';
                                                            $data_status = (isset($settings['empty_queue_status_' . $value->id]) && $settings['empty_queue_status_' . $value->id] == 'Y') ? 'on' : 'off';
                                                            ?>
                                                            <input type="checkbox" class="field-setting ecp-hidden"
                                                                   name="empty_queue_status_<?php echo $value->id ?>"
                                                                   value="Y" <?php echo $checked; ?>
                                                                   data-ref="saved_empty_queue_status_<?php echo $value->id ?>"/>
                                                            <input type="hidden"
                                                                   name="saved_empty_queue_status_<?php echo $value->id ?>"
                                                                   value="<?php echo isset($settings['empty_queue_status_' . $value->id]) ? $settings['empty_queue_status_' . $value->id] : 'N'; ?>"/>
                                                            <div class="ecp-checkbox-toggle"
                                                                 data-status="<?php echo $data_status; ?>"
                                                                 data-field="empty_queue_status_<?php echo $value->id ?>">
                                                                <div class="ecp-checkbox-on"><?php _e('ON', 'evergreen-content-poster'); ?></div>
                                                                <div class="ecp-checkbox-off"><?php _e('OFF', 'evergreen-content-poster'); ?></div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                <?php endforeach; ?>
                                            <?php endforeach; ?>
                                        </div>

                                        <input type="radio" name="tabs" class="" id="tabthree"/>
                                        <label class="ecp-padding-10"
                                               for="tabthree"><?php _e('Post according to schedule', 'evergreen-content-poster'); ?></label>
                                        <div class="tab">
                                            <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                                <div class="ecp-grid ecp-col-300">
                                                    <p class="ecp-input-label"><?php _e('#3 Schedule', 'evergreen-content-poster'); ?></p>
                                                    <p class="description"><?php _e('Send posts at specific times using a custom schedule', 'evergreen-content-poster'); ?></p>
                                                    <p class="description"><?php _e('Not sure when it is best to share your content, or are you looking for a quick way to create one? Use one of the preset schedules to post according to general best practices for each platform.', 'evergreen-content-poster'); ?></p>
                                                </div>

                                                <?php
                                                $isScheduleActive = ('timestamp' == $settings['ecp_posting_schedule']) ? true : false;
                                                $buttonClass = '';
                                                $spanClass = 'ecp-hidden';
                                                if ($isScheduleActive) {
                                                    $buttonClass = 'ecp-hidden';
                                                    $spanClass = '';
                                                }
                                                ?>

                                                <div class="ecp-grid ecp-col-300">
                                                    <button class="button ecp-navy-button ecp-activate-button <?php echo $buttonClass; ?> "
                                                            data-radio="posting-schedule-timestamp"><?php _e('Activate', 'evergreen-content-poster'); ?></button>
                                                    <span class="active active-scheduler <?php echo $spanClass; ?> "><?php _e('Currently Active', 'evergreen-content-poster'); ?></span>
                                                </div>
                                            </div>

                                            <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                                <p>
                                                    <strong><?php _e('How often do you want to post?', 'evergreen-content-poster'); ?></strong>
                                                </p>

                                                <form id="ecp-frequency-form" action="">
                                                    <input type="hidden" id="isset_custom_frequency"
                                                           value="<?php echo isset($ecp_frequency_schedules['custom']) && !empty($ecp_frequency_schedules['custom']) ? 1 : 0 ?>">
                                                    <div class="radio ecp-checkbox-primary">
                                                        <input <?php $arr = (array) $selected_profile;
                                                        if (!empty($arr)) { ?> data-id="<?php echo $selected_profile->id ?>" data-service="<?php echo $selected_profile->service ?>" <?php } ?>
                                                                id="ecp-post-freq-seldom" type="radio" value="seldom"
                                                                class=""
                                                                name="ecp-frequency" <?php if (isset($options['ecp_frequency']) && $options['ecp_frequency'] == 'seldom'): ?> checked<?php endif; ?>>
                                                        <label for="ecp-post-freq-seldom"><?php _e('Now and again', 'evergreen-content-poster'); ?></label>
                                                    </div>
                                                    <div class="radio ecp-checkbox-primary">
                                                        <input <?php $arr = (array) $selected_profile;
                                                        if (!empty($arr)) { ?> data-id="<?php echo $selected_profile->id ?>" data-service="<?php echo $selected_profile->service ?>" <?php } ?>
                                                                id="ecp-post-freq-regularly" type="radio"
                                                                value="regularly" class=""
                                                                name="ecp-frequency" <?php if (isset($options['ecp_frequency']) && $options['ecp_frequency'] == 'regularly'): ?> checked<?php endif; ?>>
                                                        <label for="ecp-post-freq-regularly"><?php _e('Regularly', 'evergreen-content-poster'); ?></label>
                                                    </div>
                                                    <div class="radio ecp-checkbox-primary">
                                                        <input <?php $arr = (array) $selected_profile;
                                                        if (!empty($arr)) { ?> data-id="<?php echo $selected_profile->id ?>" data-service="<?php echo $selected_profile->service ?>" <?php } ?>
                                                                id="ecp-post-freq-often" type="radio" value="often"
                                                                class=""
                                                                name="ecp-frequency" <?php if (isset($options['ecp_frequency']) && $options['ecp_frequency'] == 'often'): ?> checked<?php endif; ?>>
                                                        <label for="ecp-post-freq-often"><?php _e('Often', 'evergreen-content-poster'); ?></label>
                                                    </div>
                                                    <div class="radio ecp-checkbox-primary">
                                                        <input <?php $arr = (array) $selected_profile;
                                                        if (!empty($arr)) { ?> data-id="<?php echo $selected_profile->id ?>" data-service="<?php echo $selected_profile->service ?>" <?php } ?>
                                                                id="ecp-post-freq-custom" type="radio" value="custom"
                                                                class=""
                                                                name="ecp-frequency" <?php if (isset($options['ecp_frequency']) && $options['ecp_frequency'] == 'custom'): ?> checked<?php endif; ?>>
                                                        <label for="ecp-post-freq-custom"><?php _e('Custom', 'evergreen-content-poster'); ?></label>
                                                        <!--<span ng-show="selectedProfiles.postFrequency === 'custom'" uib-popover-html="'<span><?php _e('You\'re now using a custom schedule. You can also replace it with one of our presets from above, based on best practices.', 'evergreen-content-poster'); ?></span><br/> <br/><span><?php _e('Keep in mind that the preset will take the place of your current schedule if you do.', 'evergreen-content-poster'); ?></span>'" popover-trigger="mouseenter" popover-append-to-body="true" class="ng-hide">
                                                        <i class="fa fa-info-circle" aria-hidden="true"></i>-->
                                                        </span>
                                                    </div>
                                                </form>
                                            </div>

                                            <div class="<?php if (!isset($options['ecp_frequency']) || $options['ecp_frequency'] != 'custom'): ?> hidden <?php endif; ?> add-schedule-block ecp-grid ecp-col-940 ecp-option-container ecp-field-setting" <?php if (!empty($schedule->times)) : echo "style:'margin-bottom:0;'"; endif; ?> >

                                                <input type="hidden" name="ecp_schedule_days" id="ecp_schedule_days"
                                                       class="ecp_schedule_days" value="every_day">
                                                <div class="ecp-grid ecp-col-160">
                                                    <div class="ecp-grid-right ecp-day-dropdown">
                                                        <a href="javascript:void(0)"
                                                           class="ecp-col-940 button ecp-show-days"><?php _e('Every Day', 'evergreen-content-poster'); ?>
                                                            <span class="ecp-grid-right dashicons dashicons-arrow-down-alt2 ecp-arrow-down"></span>
                                                        </a>
                                                        <ul class="ecp-day-list">
                                                            <?php
                                                            $days_define = array(
                                                                'every_day' => 'Every Day',
                                                                'weekdays' => 'Weekdays',
                                                                'weekends' => 'Weekends',
                                                                '0' => 'Monday',
                                                                '1' => 'Tuesday',
                                                                '2' => 'Wednesday',
                                                                '3' => 'Thursday',
                                                                '4' => 'Friday',
                                                                '5' => 'Saturday',
                                                                '6' => 'Sunday'
                                                            );
                                                            foreach ($days_define as $key => $value) {
                                                                ?>
                                                                <li>
                                                                    <div class="ecp-grid ecp-col-940">
                                                                        <a href="javascript:void(0)"
                                                                           data-name="<?php _e($value, 'evergreen-content-poster'); ?>"
                                                                           data-day="<?php echo $key ?>"
                                                                           class="button ecp-day-single-setting">
                                                                            <div class="ecp-connected-profilex">
                                                                                <div class="ecp-connected-profile-avatar">
                                                                                    <span class="ecp-connected-profile-day"><?php _e($value, 'evergreen-content-poster'); ?></span>
                                                                                </div>
                                                                            </div>
                                                                        </a>
                                                                    </div>
                                                                </li>
                                                            <?php } ?>
                                                        </ul>
                                                    </div>
                                                </div>

                                                <div class="ecp-grid ecp-col-60">
                                                    <select name="ecp_schedule_hours" id="ecp_schedule_hours"
                                                            class="ecp_schedule_hours" aria-invalid="false">
                                                        <?php foreach (range(0, 23) as $hour) : ?>
                                                            <?php
                                                            if ($hour < 10) {
                                                                $hour = str_pad($hour, 2, '0', STR_PAD_LEFT);
                                                            }

                                                            $selected = '';
                                                            if (empty($schedules['hour']) && 12 == $hour)
                                                                $selected = 'selected';
                                                            ?>
                                                            <option value="<?php echo $hour; ?>" <?php echo $selected; ?>
                                                                    aria-checked="true"><?php _e((string) $hour, 'evergreen-content-poster'); ?></option>
                                                        <?php endforeach; ?>
                                                    </select>
                                                </div>

                                                <div class="ecp-grid ecp-col-60">
                                                    <select name="ecp_schedule_minutes" id="ecp_schedule_minutes"
                                                            class="ecp_schedule_minutes" aria-invalid="false">
                                                        <?php foreach (range(0, 59) as $minute) : ?>
                                                            <?php
                                                            if ($minute < 10) {
                                                                $minute = str_pad($minute, 2, '0', STR_PAD_LEFT);
                                                            }

                                                            $selected = '';
                                                            if (isset($settings['ecp_schedule_minutes']) && $minute == $settings['ecp_schedule_minutes'])
                                                                $selected = 'selected';
                                                            ?>
                                                            <option value="<?php echo $minute; ?>" <?php echo $selected; ?>
                                                                    aria-checked="true"><?php _e((string) $minute, 'evergreen-content-poster'); ?></option>
                                                        <?php endforeach; ?>
                                                    </select>
                                                </div>

                                                <div class="ecp-grid ecp-col-160">
                                                    <div class="ecp-grid-right ecp-network-dropdown">
                                                        <a href="javascript:void(0)"
                                                           class="ecp-col-940 button ecp-show-networks"><?php _e('Select Social Network', 'evergreen-content-poster'); ?>
                                                            <span class="ecp-grid-right dashicons dashicons-arrow-down-alt2"></span></a>
                                                        <ul class="ecp-network-list">
                                                            <li>
                                                                <div class="ecp-grid ecp-col-940">
                                                                    <a href="javascript:void(0)"
                                                                       data-username="<?php _e('All networks', 'evergreen-content-poster'); ?>"
                                                                       data-profile="<?php echo 'all_networks' ?>"
                                                                       class="button ecp-network-single-setting">
                                                                        <div class="ecp-connected-profilex">
                                                                            <div class="ecp-connected-profile-avatar">
                                                                                <span class="ecp-connected-profile-network"><?php _e('All networks', 'evergreen-content-poster'); ?></span>
                                                                            </div>
                                                                        </div>
                                                                    </a>
                                                                </div>
                                                            </li>
                                                            <?php foreach ($this->buffer->profiles() as $service => $profile_list) : ?>
                                                                <?php
                                                                foreach ($profile_list as $key => $single_profile) :
                                                                    $avatar = EVERGREEN_CONTENT_POSTER_PATH . '/admin/img/ecp-profile-unknown.png';
                                                                    if (!empty($single_profile->avatar))
                                                                        $avatar = $single_profile->avatar;

                                                                    $profile_username = !empty($single_profile->formatted_username) ? $single_profile->formatted_username : ucwords($single_profile->service_type) . ($key + 1);
                                                                    if (strlen($profile_username) > 18) {
                                                                        $profile_username = substr($profile_username, 0, 15) . '...';
                                                                    }

                                                                    $service_type = ucwords($single_profile->service . ' ' . ucwords($single_profile->service_type));
                                                                    if (strlen($service_type) > 17) {
                                                                        $service_type = substr($service_type, 0, 14) . '...';
                                                                    }
                                                                    ?>
                                                                    <li>
                                                                        <div class="ecp-grid ecp-col-940">
                                                                            <a href="javascript:void(0)"
                                                                               data-username="<?php echo $single_profile->formatted_username; ?>"
                                                                               data-profile="<?php echo $single_profile->id; ?>"
                                                                               data-service="<?php echo ucwords($single_profile->service) . '-' . ucwords($single_profile->service_type); ?>"
                                                                               data-avatar="<?= $avatar ?>"
                                                                               data-social="<?php echo ucwords($single_profile->service) ?>"
                                                                               class="button ecp-network-single-setting">
                                                                                <div class="ecp-connected-profilex">
                                                                                    <div class="ecp-connected-profile-avatar">
                                                                                        <img class="ecp-profile-circle-medium"
                                                                                             ng-src="<?php echo $avatar; ?>"
                                                                                             img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png"
                                                                                             src="<?php echo $avatar; ?>">
                                                                                        <div class="ecp-social-network-icon-medium ecp-<?php echo strtolower($single_profile->service); ?>"></div>
                                                                                        <span class="ecp-connected-profile-network"><?php _e($service_type, 'evergreen-content-poster'); ?></span>
                                                                                    </div>
                                                                                </div>
                                                                            </a>
                                                                        </div>
                                                                    </li>
                                                                <?php
                                                                endforeach;
                                                                ?>
                                                            <?php endforeach; ?>
                                                        </ul>
                                                    </div>
                                                </div>
                                                <input type="hidden" id="ecp_schedule_network" value=""
                                                       name="ecp_schedule_network" class="ecp_schedule_network">

                                                <div class="ecp-grid ecp-col-160">
                                                    <input type="hidden" name="ecp_schedule_categories"
                                                           id="ecp_schedule_categories" class="ecp_schedule_cateories"
                                                           value="">
                                                    <div class="ecp-grid-right ecp-categories-dropdown">
                                                        <a href="javascript:void(0)"
                                                           class="ecp-col-940 button ecp-show-category"><?php _e('Select Category', 'evergreen-content-poster'); ?>
                                                            <span class="ecp-grid-right dashicons dashicons-arrow-down-alt2 ecp-arrow-down"></span>
                                                        </a>
                                                        <ul class="ecp-categories-list">
                                                            <?php
                                                            foreach ($allCategories as $category) :
                                                                if (strlen($category->name) > 17) {
                                                                    $category->name = substr($category->name, 0, 14) . '...';
                                                                }
                                                                ?>
                                                                <li>
                                                                    <div class="ecp-grid ecp-col-940">
                                                                        <a href="javascript:void(0)"
                                                                           data-id="<?php echo $category->id ?>"
                                                                           data-name="<?php echo $category->name ?>"
                                                                           class="button ecp-categories-single-setting">
                                                                            <div class="ecp-connected-profilex">
                                                                                <div class="ecp-connected-profile-avatar">
                                                                                    <span class="ecp-connected-profile-categories"><?php echo $category->name ?></span>
                                                                                </div>
                                                                            </div>
                                                                        </a>
                                                                    </div>
                                                                </li>
                                                            <?php
                                                            endforeach;
                                                            ?>
                                                            <li>
                                                                <div class="ecp-grid ecp-col-940">
                                                                    <a href="javascript:void(0)" data-id="0"
                                                                       data-name="<?php _e('Random category', 'evergreen-content-poster'); ?>"
                                                                       class="button ecp-categories-single-setting">
                                                                        <div class="ecp-connected-profilex">
                                                                            <div class="ecp-connected-profile-avatar">
                                                                                <span class="ecp-connected-profile-categories"><?php _e('Random category', 'evergreen-content-poster'); ?></span>
                                                                            </div>
                                                                        </div>
                                                                    </a>
                                                                </div>
                                                            </li>
                                                        </ul>
                                                    </div>
                                                </div>

                                                <div class="ecp-add-schedule-custom">
                                                    <div class="ecp-grid ecp-col-220">
                                                        <button class="button ecp-navy-button ecp-save-settings ecp-add-schedule" <?php $arr = (array) $selected_profile;
                                                        if (!empty($arr)) { ?> data-id="<?php echo $selected_profile->id ?>" data-service="<?php echo $selected_profile->service ?>" <?php } ?>
                                                                style="margin: 4px 0;"><?php _e('Add Posting Time', 'evergreen-content-poster'); ?></button>
                                                    </div>
                                                </div>
                                            </div>

                                            <script>
                                                jQuery(function ($) {
                                                    $(document).on('click', '.ecp-activate-button', function (e) {
                                                        e.preventDefault();
                                                        $(this).removeClass('ecp-navy-button');
                                                        $(this).addClass('ecp-red-button');
                                                        $(this).css({
                                                            "float": 'left',
                                                            "text-transform": "lowercase",
                                                            "margin-left": "10%"
                                                        });
                                                        let radioTarget = $(this).data('radio');
                                                        $('.' + radioTarget).trigger('click');

                                                        let savedValField = document.querySelector('input[name="saved_posting_schedule"]');
                                                        let newValField = document.querySelector('input[name="ecp_posting_schedule"]:checked');

                                                        toggleSaveSetting(false);
                                                        $('input[name="saved_posting_schedule"]').val(newValField.value)
                                                        toggleSaveSetting(true);

                                                        return false;
                                                    });

                                                    $('.ecp-add-schedule').on('click', function (e) {
                                                        e.preventDefault();

                                                        let network = document.querySelector('.ecp_schedule_network');
                                                        let network_new = document.querySelector('.ecp-show-networks');

                                                        network_new.classList.remove('ecp-input-error');
                                                        if (network.value == '0') {
                                                            network.classList.add('ecp-input-error');

                                                            return;
                                                        }

                                                    });
                                                    $('a.ecp-profile-select').on('click', function (evt) {
                                                        // evt.preventDefault();

                                                        const profileBtn = this;

                                                        const connectedProfiles = document.querySelectorAll('.ecp-connected-profile');
                                                        for (var i = 0; i <= connectedProfiles.length - 1; i++) {
                                                            connectedProfiles[i].classList.remove = 'active';
                                                        }
                                                        profileBtn.querySelector('.ecp-connected-profile').classList.add = 'active';

                                                    });

                                                    // trigger and show correct tab
                                                    var activeSchedule = '<?php echo $settings['ecp_posting_schedule']; ?>';

                                                    if ('timestamp' == activeSchedule)
                                                        document.querySelector('#tabthree').click();
                                                    if ('daily_posts' == activeSchedule)
                                                        document.querySelector('#tabone').click();
                                                    if ('empty_queue' == activeSchedule)
                                                        document.querySelector('#tabtwo').click();
                                                });
                                            </script>

                                            <?php
                                            $is_empty_schedule_clear = true;
                                            $arrProfile = (array) $selected_profile;
                                            if (empty($arrProfile)) {
                                                foreach ($scheduleDefineLast as $schedule) {
                                                    if (!empty($schedule->times)) {
                                                        $is_empty_schedule_clear = false;
                                                    }
                                                }
                                            } else {
                                                foreach ($selected_schedules as $schedule) {
                                                    if (!empty($schedule->times)) {
                                                        $is_empty_schedule_clear = false;
                                                    }
                                                }
                                            }

                                            $categoriesInactive = $wpdb->get_results('SELECT * FROM wp_evergreen_categories WHERE status != 1');
                                            ?>
                                            <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting clear-schedule-box <?php if ($is_empty_schedule_clear): ?> hidden <?php endif; ?>">
                                                <div class="ecp-grid ecp-col-300">
                                                    <a href="#clear-schedule" class="ecp-clear-schedule-class"
                                                       rel="modal:open"><?php _e('Clear Schedule', 'evergreen-content-poster'); ?></a>
                                                    <?php if (!empty((array) $categoriesInactive)): ?>
                                                        <p><?php _e('At the moment the following categories are inactive and content of these categories will not be posted to your social media channels:', 'evergreen-content-poster'); ?></p>
                                                        <ul>
                                                            <?php foreach ($categoriesInactive as $categoryIn): ?>
                                                                <li><b><?php echo $categoryIn->name ?>
                                                                        <em><?php _e('[inactive]', 'evergreen-content-poster'); ?></em></b>
                                                                </li>
                                                            <?php endforeach; ?>
                                                        </ul>
                                                    <?php endif; ?>

                                                    <div id="clear-schedule" class="modal all-modal">
                                                        <p style="border-bottom: 1px solid #a4a4a4; padding: 20px 0"><?php _e('Are you sure you want to clear your entire posting schedule?', 'evergreen-content-poster') ?></p>
                                                        <a href="#" style="padding: 10px 30px;"
                                                           class="button ecp-navy-button ecp-clear-schedule jquery-modal-close" <?php $arr = (array) $selected_profile;
                                                        if (!empty($arr)) { ?> data-id="<?= $selected_profile->id ?>" data-service="<?= $selected_profile->service ?>" <?php } ?>>Ok</a>
                                                        <a href="#"
                                                           style="color:#000; text-decoration:none;margin-right:20px;padding: 10px 30px;border: 1px solid #1b3a51;float: right"
                                                           class="ecp-button jquery-modal-close"><?php _e('Cancel', 'evergreen-content-poster') ?></a>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                                <ul class="ecp-schedule">
                                                    <?php
                                                    $daysWeek = array(
                                                        '0' => 'Sunday',
                                                        '1' => 'Monday',
                                                        '2' => 'Tuesday',
                                                        '3' => 'Wednesday',
                                                        '4' => 'Thursday',
                                                        '5' => 'Friday',
                                                        '6' => 'Saturday'

                                                    );
                                                    foreach ($daysWeek as $key => $value): ?>
                                                        <li>
                                                            <div class="ecp-schedule_day">
                                                                <div class="ecp-schedule-day-header">
                                                                    <?php _e($value, 'evergreen-content-poster'); ?>
                                                                </div>
                                                            </div>
                                                        </li>
                                                    <?php endforeach; ?>
                                                </ul>


                                                <div id="ecp-schedule-body">
                                                    <?php if (!empty((array) $selected_profile)) { ?>
                                                        <div class="ecp-col-940 ecp-option-container ecp-field-setting no_schedule">
                                                            <?php
                                                            $is_empty_schedule = true;
                                                            if (isset($_REQUEST['ecp_profile'])) {
                                                                foreach ($selected_schedules as $schedule) {
                                                                    if (!empty($schedule->times)) {
                                                                        $is_empty_schedule = false;
                                                                    }
                                                                }
                                                            }
                                                            ?>
                                                            <?php if (!$is_empty_schedule) : ?>
                                                                <?php
                                                                foreach ($selected_schedules as $ds_key => $daily_schedule) : ?>
                                                                    <div class="ecp-grid ecp-col-130"
                                                                         style="margin-right: 0.9%">
                                                                        <?php
                                                                        $times = array();
                                                                        foreach ($daily_schedule->times as $time) {
                                                                            if (strlen($time['time_push']) == 4) {
                                                                                $time['time_push'] = '0' . $time['time_push'];
                                                                            }
                                                                            $times[] = $time;
                                                                        }
                                                                        $daily_schedule->times = $times;
                                                                        sort($daily_schedule->times);
                                                                        foreach ($daily_schedule->times as $key => $value) : ?>
                                                                            <a href="#delete-schedule"
                                                                               class="show-modal-delete"
                                                                               rel="modal:open"
                                                                               data-day="<?= $daily_schedule->days[0] ?>"
                                                                               data-id="<?php echo $selected_profile->_id ?>"
                                                                               data-service="<?= $selected_profile->service ?>"
                                                                               data-value="<?= $value['time_push'] ?>"
                                                                               data-key="<?= $key ?>" data-general="0">
                                                                                <div class="ecp-grid ecp-col-940 scheduled-item">
                                                                                    <div class="ecp-connected-profile-avatar">
                                                                                        <img class="ecp-profile-circle"
                                                                                             ng-src="<?php echo $selected_profile->avatar; ?>"
                                                                                             img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png"
                                                                                             src="<?php echo $selected_profile->avatar; ?>">
                                                                                        <div class="ecp-social-network-icon ecp-<?php echo strtolower($selected_profile->service); ?>"></div>
                                                                                    </div>
                                                                                    <div class="ecp-text">
                                                                                        <span class="schedule_field schedule_time"><?php _e($value['time_push'], 'evergreen-content-poster'); ?></span><br/>
                                                                                        <span class="schedule_field schedule_category"><?php echo $value['category_id'] ? $allCategoriesName[$value['category_id']] : _e('Random category', 'evergreen content poster') ?></span>
                                                                                        <input type="hidden"
                                                                                               name="scheduled_daytime[<?php echo $selected_profile->id; ?>][<?php echo $ds_key; ?>][]"
                                                                                               value="<?php echo $value['time_push']; ?>"/>
                                                                                        <p class="ecp-remove-schedule hidden">
                                                                                            <span class="dashicons dashicons-no"></span>
                                                                                        </p>
                                                                                    </div>

                                                                                    <?php if (!in_array($value['category_id'], $categoryIds) && $value['category_id'] != 0): ?>
                                                                                        <div class="ecp-overlay"><span
                                                                                                    class="dashicons dashicons-controls-pause"></span>
                                                                                        </div>
                                                                                    <?php endif; ?>
                                                                                </div>
                                                                            </a>
                                                                        <?php endforeach; ?>
                                                                    </div>
                                                                <?php endforeach; ?>

                                                            <?php else : ?>
                                                                <div class="ecp-grid ecp-col-940">
											                        <span class="">
											                        	<img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-schedule.svg"
                                                                             width="180" height="124"
                                                                             style="display: block; margin: 3em auto;">
																		<p style="text-align: center;"><?php _e('There is no schedule at the moment, please use the form above to create your schedule.', 'evergreen-content-poster'); ?></p>
																	</span>
                                                                </div>
                                                            <?php endif; ?>
                                                        </div>
                                                    <?php } else { ?>
                                                        <div class="ecp-col-940 ecp-option-container ecp-field-setting no_schedule">
                                                            <?php
                                                            $is_empty_schedule = true;

                                                            foreach ($scheduleDefineLast as $schedule) {
                                                                if (!empty($schedule->times)) {
                                                                    $is_empty_schedule = false;
                                                                }
                                                            }

                                                            ?>
                                                            <?php if (!$is_empty_schedule) : ?>
                                                                <?php foreach ($scheduleDefineLast as $ds_key => $daily_schedule) : ?>
                                                                    <div class="ecp-grid ecp-col-130"
                                                                         style="margin-right: 0.9%">
                                                                        <?php
                                                                        foreach ($daily_schedule->times as $key => $value) : ?>
                                                                            <a href="#delete-schedule"
                                                                               class="show-modal-delete"
                                                                               rel="modal:open"
                                                                               data-day="<?= $daily_schedule->days[0] ?>"
                                                                               data-id="<?php echo $value['_id'] ?>"
                                                                               data-service="<?= $value['service'] ?>"
                                                                               data-value="<?= $value['time'] ?>"
                                                                               data-key="<?= $value['key'] ?>"
                                                                               data-general="1">
                                                                                <div class="ecp-grid ecp-col-940 scheduled-item">
                                                                                    <div class="ecp-connected-profile-avatar">
                                                                                        <img class="ecp-profile-circle"
                                                                                             ng-src="<?php echo $value['avatar']; ?>"
                                                                                             img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png"
                                                                                             src="<?php echo $value['avatar']; ?>">
                                                                                        <div class="ecp-social-network-icon ecp-<?php echo strtolower($value['service']); ?>"></div>
                                                                                    </div>
                                                                                    <div class="ecp-text">
                                                                                        <span class="schedule_field schedule_time"><?php _e($value['time'], 'evergreen-content-poster'); ?></span><br/>
                                                                                        <span class="schedule_field schedule_category"><?php echo $value['category_id'] ? $allCategoriesName[$value['category_id']] : _e('Random category', 'evergreen content poster') ?></span>
                                                                                        <input type="hidden"
                                                                                               name="scheduled_daytime[<?php echo $value['_id']; ?>][<?php echo $ds_key; ?>][]"
                                                                                               value="<?php echo $value['time']; ?>"/>
                                                                                        <p class="ecp-remove-schedule hidden">
                                                                                            <span class="dashicons dashicons-no"></span>
                                                                                        </p>
                                                                                    </div>

                                                                                    <?php if (!in_array($value['category_id'], $categoryIds) && $value['category_id'] != 0): ?>
                                                                                        <div class="ecp-overlay"><span
                                                                                                    class="dashicons dashicons-controls-pause"></span>
                                                                                        </div>
                                                                                    <?php endif; ?>
                                                                                </div>
                                                                            </a>
                                                                        <?php endforeach; ?>
                                                                    </div>
                                                                <?php endforeach; ?>

                                                            <?php else : ?>
                                                                <div class="ecp-grid ecp-col-940">
											                        <span class="">
											                        	<img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-schedule.svg"
                                                                             width="180" height="124"
                                                                             style="display: block; margin: 3em auto;">
																		<p style="text-align: center;"><?php _e('There is no schedule at the moment, please use the form above to create your schedule.', 'evergreen-content-poster'); ?></p>
																	</span>
                                                                </div>
                                                            <?php endif; ?>
                                                        </div>
                                                    <?php }
                                                    if (count($allCategories) > 1 && $totalNum > 0) {
                                                        include('partials/evergreen_content_statistics.php');
                                                    }
                                                    ?>
                                                </div>

                                            </div>

                                        </div><!-- end tab -->
                                    </div>
                                </div>

                            <?php endif; // endif $token
                            ?>

                        </form>

                    </div><!-- end ecp-grid ecp-col-700 -->

                    <div class="ecp-admin-sidebar ecp-grid ecp-col-220 ecp-fit">
                        <div id="ecp-admin-sidebar">
                            <div id="ecp-love" class="ecp-component dark-text text-center">
                                <p class="ecp-component-title"><?php _e('Love the Plugin?', 'evergreen-content-poster'); ?>
                                    <br/>
                                    <span style="font-size:18px;font-weight:normal;"><?php _e('How about rating us?', 'evergreen-content-poster'); ?></span>
                                </p>
                                <div class="ecp-component-icon">
                                    <a class="ecp-rating-link" target="_blank" data-ecp-rating-value="5"
                                       href="https://wordpress.org/support/plugin/evergreen-content-poster/reviews/?rate=5"><span
                                                class="dashicons dashicons-star-empty"></span></a>
                                    <a class="ecp-rating-link" target="_blank" data-ecp-rating-value="4"
                                       href="https://wordpress.org/support/plugin/evergreen-content-poster/reviews/?rate=4"><span
                                                class="dashicons dashicons-star-empty"></span></a>
                                    <a class="ecp-rating-link" target="_blank" data-ecp-rating-value="3"
                                       href="https://wordpress.org/support/plugin/evergreen-content-poster/reviews/?rate=3"><span
                                                class="dashicons dashicons-star-empty"></span></a>
                                    <a class="ecp-rating-link" target="_blank" data-ecp-rating-value="2"
                                       href="https://wordpress.org/support/plugin/evergreen-content-poster/reviews/?rate=2"><span
                                                class="dashicons dashicons-star-empty"></span></a>
                                    <a class="ecp-rating-link" target="_blank" data-ecp-rating-value="1"
                                       href="https://wordpress.org/support/plugin/evergreen-content-poster/reviews/?rate=1"><span
                                                class="dashicons dashicons-star-empty"></span></a>
                                </div>
                                <p><?php _e('Would you mind giving us an honest review in the WordPress listings? It would mean the world to us.', 'evergreen-content-poster'); ?></p>
                            </div>
                            <div id="ecp-support-cta">
                                <p><?php _e('We\'re sorry you\'re not having a great experience. How can we help you fix that?', 'evergreen-content-poster'); ?></p>
                                <p><?php _e('You can email us or, even better, send us a support request so we can address your needs as quickly and effectively as possible.', 'evergreen-content-poster'); ?></p>
                                <p><a target="_blank" class="ecp-component-cta ecp-link-nojs"
                                      href="https://usergrowth.io/contact/?utm_source=plugin%20feedback&utm_medium=software&utm_campaign=Evergreen%20Content%20Poster"><?php _e('Contact Support', 'evergreen-content-poster'); ?></a>
                                </p>
                                <p><?php _e('If you still want to rate our plugin right now, you can do that by clicking here:', 'evergreen-content-poster'); ?>
                                    <a href="#" class="ecp-link-nojs" target="_blank"
                                       id="ecp-review-link"><?php _e('leave a review', 'evergreen-content-poster'); ?></a>
                                </p>
                                <p>
                                    <span class="ecp-close-modal"><?php _e('Nevermind, close this box', 'evergreen-content-poster'); ?></span>
                                </p>
                            </div>
                            <script>
                                if (typeof jQuery != 'function') {
                                    console.log('Evergreen Content Poster requires jQuery. Please ensure that your theme does not restrict access to everyone\'s favorite JS library.');
                                } else {
                                    jQuery(document).ready(function () {
                                        var originalContent = jQuery('#ecp-love').html();
                                        updateListeners();

                                        function replace(el, html) {
                                            el.slideToggle(300, function () {
                                                el.html(html);
                                                updateListeners();
                                                el.slideToggle('slow');
                                            });
                                        }

                                        /**
                                         * Content is moved into different parent containers,
                                         * so update to fit new selectors.
                                         *
                                         */
                                        function updateListeners() {
                                            jQuery('#ecp-love .ecp-rating-link').on('click', function (e) {
                                                var value = parseInt(jQuery(this).data('ecp-rating-value'), 10);
                                                if (isNaN(value) || value > 3) return;

                                                e.preventDefault();

                                                var href = jQuery(this).attr('href');
                                                jQuery('#ecp-support-cta #ecp-review-link').attr('href', href);

                                                replace(jQuery('#ecp-love'), jQuery('#ecp-support-cta').html());
                                            });


                                            jQuery('.ecp-close-modal').on('click', function () {
                                                replace(jQuery('#ecp-love'), originalContent);
                                            });
                                        }
                                    });
                                }
                            </script>
                            <div id="ecp-idea" class="ecp-component dark-text text-center">
                                <div class="ecp-component-icon">
                                    <span class="dashicons dashicons-lightbulb"></span>
                                </div>
                                <p class="ecp-component-title"><?php _e('Have an idea?', 'evergreen-content-poster'); ?></p>
                                <p><?php _e('Are you missing a feature? Do you know a way to make the plugin even better?', 'evergreen-content-poster'); ?></p>
                                <p><?php _e('Leave a comment and upvote features on our public roadmap', 'evergreen-content-poster'); ?></p>
                                <a href="https://trello.com/b/QUUOK2NB/evergreen-content-poster-public-roadmap"
                                   class="button ecp-navy-button" target="_blank"
                                   style="float:none; text-transform: uppercase; letter-spacing: 2px; font-weight: bold; cursor: pointer;"><?php _e('Share your idea', 'evergreen-content-poster'); ?></a>
                            </div>

                            <div id="ecp-help" class="ecp-component dark-text text-center">
                                <div class="ecp-component-icon">
                                    <span class="dashicons dashicons-sos"></span>
                                </div>
                                <p class="ecp-component-title"><?php _e('Need Help?', 'evergreen-content-poster'); ?></p>
                                <p><?php _e('Something not working correctly and want to contact support?', 'evergreen-content-poster'); ?></p>
                                <p><?php _e('Copy your System Status by clicking the button below and include this in an email to support@evergreencontentposter.io', 'evergreen-content-poster'); ?></p>
                                <p><?php _e('Optionally you can also include a log of the messages you successfully or unsuccessfully shared.', 'evergreen-content-poster'); ?></p>
                                <button class="ecp-component-cta ecp-system-status"><?php _e('Get system status', 'evergreen-content-poster'); ?></button>
                                <button class="ecp-component-cta ecp-status-logfile"><?php _e('Get sharing logfile', 'evergreen-content-poster'); ?></button>
                            </div>
                        </div><!-- end ecp-admin-sidebar ecp-col-220 -->
                        <?php
                        $debug_bar = new Evergreen_Content_Poster();
                        $debugHTML = $debug_bar->ecp_do_admin_sidebar();

                        echo $debugHTML;
                        ?>
                    </div>

                </div><!-- end ecp-section -->

            </div><!-- end ecp-container -->
            <div id="delete-schedule" class="modal all-modal">
                <p style="border-bottom: 1px solid #a4a4a4; padding: 20px 0"><?php _e('Are you sure you want to delete this timeslot?', 'evergreen-content-poster') ?></p>
                <a id="ecp-delete-schedule-modal" href="#" style="padding: 10px 30px;"
                   class="button ecp-navy-button ecp-remove-schedule-action jquery-modal-close">Ok</a>
                <a href="#"
                   style="color:#000; text-decoration:none;margin-right:20px;padding: 10px 30px;border: 1px solid #1b3a51;float: right"
                   class="ecp-button jquery-modal-close"><?php _e('Cancel', 'evergreen-content-poster') ?></a>
            </div>
        </div><!-- end .ecp-wrapper -->
        <?php
    }

}