<?php
/**
 * The logging class.
 *
 * This is used to log the items pushed to the social networks into a logging table
 * for potential debugging and knowing when to do another push of your content
 *
 *
 * @link       https://usergrowth.io/
 * @since      1.0.0
 * @package    Evergreen_Content_poster
 * @subpackage Evergreen_Content_Poster/includes
 * @author     usergrowth <info@usergrowth.io>
 */

class Evergreen_Content_Poster_Log
{
    /**
     * Holds the DB table name
     *
     * @since   1.0.0
     *
     * @var     string
     */
    private $table;

    /**
     * Holds items added to the debug log using add_to_debug_log(),
     *
     * @since   1.0.0
     *
     * @var     array
     */
    private $debug_log = array();

    /**
     * Constructor
     *
     * @since   3.0.0
     */
    public function __construct()
    {
        // Define the database table name
        $this->table = 'evergreen_content' . '_logs';
    }


    /**
     * Adds a log entry for the given Post ID
     *
     * @since   1.0.0
     *
     * @param   int     $post_id    Post ID
     * @param   array   $log        Log
     *      enum            $action             Action (publish,update,repost,bulk_publish)
     *      datetime        $request_sent       Request Sent to API
     *      string          $profile_id         Profile ID
     *      string          $profile_name       Profile Name
     *      enum            $result             Result (success,test_mode,pending,error)
     *      string          $result_message     Result Message
     *      string          $status_text        Status Text
     *      datetime        $status_created_at  Status Created At on API
     *      datetime        $status_due_at      Status Scheduled for Publication to Profile
     */
    public function add( $post_id, $log ): void
    {

        global $wpdb;

        // Enable error output if WP_DEBUG is enabled.
        $wpdb->show_errors();

        // Add Post ID to log
        $log['post_id'] = absint( $post_id );

        // Insert Log
        $result = $wpdb->insert(
            $wpdb->prefix . $this->table,
            $log
        );
    }
}